@@ -1,25 +1,14 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2015, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
-#
-#  SLEPc is free software: you can redistribute it and/or modify it under  the
-#  terms of version 3 of the GNU Lesser General Public License as published by
-#  the Free Software Foundation.
-#
-#  SLEPc  is  distributed in the hope that it will be useful, but WITHOUT  ANY
-#  WARRANTY;  without even the implied warranty of MERCHANTABILITY or  FITNESS
-#  FOR  A  PARTICULAR PURPOSE. See the GNU Lesser General Public  License  for
-#  more details.
-#
-#  You  should have received a copy of the GNU Lesser General  Public  License
-#  along with SLEPc. If not, see <http://www.gnu.org/licenses/>.
+#  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #
 
-import sys
+import os, sys
 
 class ArgDB:
 
@@ -41,6 +30,10 @@ class ArgDB:
       elif name.startswith('--with'):
         if name.find('=') == -1: argv[l] += '=1'
     self.argdb = argv[1:]
+    self.useda = []
+
+  def UsedArgs(self):
+    return ' '.join(self.useda)
 
   def PopString(self,keyword):
     string = ''
@@ -52,6 +45,7 @@ class ArgDB:
           string = s.split('=')[1]
           found = 1
           numhits = numhits + 1
+          self.useda.append(self.argdb[i])
           del self.argdb[i]
           break
       if not found:
@@ -65,9 +59,10 @@ class ArgDB:
       found = 0
       for i, s in enumerate(self.argdb):
         if s.startswith('--'+keyword+'='):
-          string = s.split('=')[1].rstrip('/')
+          string = os.path.expanduser(s.split('=')[1].rstrip('/'))
           found = 1
           numhits = numhits + 1
+          self.useda.append(self.argdb[i])
           del self.argdb[i]
           break
       if not found:
@@ -87,6 +82,7 @@ class ArgDB:
           except IndexError: pass
           found = 1
           numhits = numhits + 1
+          self.useda.append(self.argdb[i])
           del self.argdb[i]
           break
       if not found:
@@ -103,6 +99,7 @@ class ArgDB:
           value = not s.endswith('=0')
           found = 1
           numhits = numhits + 1
+          self.useda.append(self.argdb[i])
           del self.argdb[i]
           break
       if not found:
