@@ -2,7 +2,7 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -123,10 +123,10 @@ if 'LC_LOCAL' in os.environ and os.environ['LC_LOCAL'] != '' and os.environ['LC_
 if 'LANG' in os.environ and os.environ['LANG'] != '' and os.environ['LANG'] != 'en_US' and os.environ['LANG'] != 'en_US.UTF-8': os.environ['LANG'] = 'en_US.UTF-8'
 
 # Check python version
-if not hasattr(sys, 'version_info') or not sys.version_info[0] == 2 or not sys.version_info[1] >= 6:
+if sys.version_info < (2,6):
   print('*******************************************************************************')
-  print('*       Python2 version 2.6 or higher is required to run ./configure          *')
-  print('*          Try: "python2.7 ./configure" or "python2.6 ./configure"            *')
+  print('*        Python version 2.6+ or 3.4+ is required to run ./configure           *')
+  print('*           Try: "python2.7 ./configure" or "python3 ./configure"             *')
   print('*******************************************************************************')
   sys.exit(4)
 
@@ -203,7 +203,7 @@ libdir  = CreateDir(archdir,'lib',log)
 confdir = CreateDirTwo(libdir,'slepc','conf',log)
 
 # Open log file
-log.Open(os.path.join(confdir,'configure.log'))
+log.Open(confdir,'configure.log')
 log.write('='*80)
 log.write('Starting Configure Run at '+time.ctime(time.time()))
 log.write('Configure Options: '+' '.join(sys.argv[1:]))
@@ -265,15 +265,15 @@ else:
 
 # Write initial part of file slepcvariables
 slepcvars.write('SLEPC_CONFIGURE_OPTIONS = '+argdb.UsedArgs()+'\n')
-slepcvars.write('SLEPC_DESTDIR = '+slepc.prefixdir+'\n')
+slepcvars.write('SLEPC_INSTALLDIR = '+slepc.prefixdir+'\n')
 if emptyarch:
   slepcvars.write('INSTALLED_PETSC = 1\n')
 if slepc.datadir:
   slepcvars.write('DATAFILESPATH = '+slepc.datadir+'\n')
 
 # Write initial part of file slepcconf.h
-slepcconf.write('#if !defined(__SLEPCCONF_H)\n')
-slepcconf.write('#define __SLEPCCONF_H\n\n')
+slepcconf.write('#if !defined(SLEPCCONF_H)\n')
+slepcconf.write('#define SLEPCCONF_H\n\n')
 AddDefine(slepcconf,'PETSC_DIR',petsc.dir)
 AddDefine(slepcconf,'PETSC_ARCH',petsc.arch)
 AddDefine(slepcconf,'DIR',slepc.dir)
