@@ -18,7 +18,7 @@ class Installer:
     if len(args)<6:
       print('********************************************************************')
       print('Installation script error - not enough arguments:')
-      print('./config/install.py SLEPC_DIR PETSC_DIR SLEPC_DESTDIR -destDir=DESTDIR PETSC_ARCH LIB_SUFFIX RANLIB')
+      print('./config/install.py SLEPC_DIR PETSC_DIR SLEPC_INSTALLDIR -destDir=DESTDIR PETSC_ARCH LIB_SUFFIX RANLIB')
       print('********************************************************************')
       sys.exit(1)
     self.rootDir     = args[0]
@@ -45,12 +45,12 @@ class Installer:
       for l in f.readlines():
         r = l.split('=',1)
         if len(r)!=2: continue
-        if r[0].strip() == 'SLEPC_DESTDIR':
+        if r[0].strip() == 'SLEPC_INSTALLDIR':
           break
       f.close()
     except:
       print('********************************************************************')
-      print('Error reading SLEPC_DESTDIR from slepcvariables')
+      print('Error reading SLEPC_INSTALLDIR from slepcvariables')
       print('********************************************************************')
       sys.exit(1)
     return r[1].strip()
@@ -73,6 +73,7 @@ class Installer:
     self.installBinDir     = os.path.join(self.installDir, 'lib','slepc','bin')
     self.rootShareDir      = os.path.join(self.rootDir, 'share')
     self.destShareDir      = os.path.join(self.destDir, 'share')
+    self.rootSrcDir        = os.path.join(self.rootDir, 'src')
     return
 
   def checkDestdir(self):
@@ -134,16 +135,27 @@ class Installer:
            self.copyfile(srcname,dst)
 
   def fixExamplesMakefile(self, src):
-    '''Change ./${PETSC_ARCH} in makefile in root petsc directory with ${SLEPC_DIR}'''
+    '''Change ./${PETSC_ARCH} in makefile in root slepc directory with ${SLEPC_DIR}'''
     lines   = []
     oldFile = open(src, 'r')
-    for line in oldFile.readlines():
-      # paths generated by configure could be different link-path than whats used by user, so fix both
-      line = line.replace('./${PETSC_ARCH}','${SLEPC_DIR}')
-      lines.append(line)
+    alllines=oldFile.read()
     oldFile.close()
+    newlines=alllines.split('\n')[0]+'\n'  # Firstline
+    # Hardcode SLEPC_DIR, PETSC_DIR and PETSC_ARCH to avoid users doing the wrong thing
+    newlines+='SLEPC_DIR='+self.installDir+'\n'
+    newlines+='PETSC_DIR='+self.petscDir+'\n'
+    newlines+='PETSC_ARCH=\n'
+    for line in alllines.split('\n')[1:]:
+      if line.startswith('TESTLOGFILE'):
+        newlines+='TESTLOGFILE = $(TESTDIR)/examples-install.log\n'
+      elif line.startswith('CONFIGDIR'):
+        newlines+='CONFIGDIR:=$(SLEPC_DIR)/$(PETSC_ARCH)/share/slepc/examples/config\n'
+      elif line.startswith('$(generatedtest)') and 'slepcvariables' in line:
+        newlines+='all: test\n\n'+line+'\n'
+      else:
+        newlines+=line+'\n'
     newFile = open(src, 'w')
-    newFile.write(''.join(lines))
+    newFile.write(newlines)
     newFile.close()
     return
 
@@ -184,9 +196,7 @@ class Installer:
     self.copies.extend(self.copyfile('gmakefile.test',dst))
     newConfigDir=os.path.join(dst,'config')  # Am not renaming at present
     if not os.path.isdir(newConfigDir): os.mkdir(newConfigDir)
-    testConfFiles="gmakegentest.py gmakegen.py testparse.py example_template.py".split()
-    testConfFiles+="petsc_harness.sh report_tests.py".split()
-    testConfFiles+=["cmakegen.py"]
+    testConfFiles="cmakegen.py".split()
     for tf in testConfFiles:
       self.copies.extend(self.copyfile(os.path.join('config',tf),newConfigDir))
     return
@@ -313,7 +323,7 @@ for dir in dirs:
     return
 
   def installConf(self):
-    self.copies.extend(self.copytree(self.rootConfDir, self.destConfDir, exclude = ['gmakegen.py','install.py','bfort-base.txt','bfort-mpi.txt','bfort-petsc.txt','bfort-slepc.txt']))
+    self.copies.extend(self.copytree(self.rootConfDir, self.destConfDir, exclude = ['install.py','bfort-base.txt','bfort-mpi.txt','bfort-petsc.txt','bfort-slepc.txt']))
     self.copies.extend(self.copytree(self.archConfDir, self.destConfDir, exclude = ['configure.log','error.log','files','gmake.log','make.log','test.log']))
     return
 
@@ -327,12 +337,13 @@ for dir in dirs:
   def installShare(self):
     self.copies.extend(self.copytree(self.rootShareDir, self.destShareDir))
     examplesdir=os.path.join(self.destShareDir,'slepc','examples')
-    if os.path.exists(os.path.join(self.destShareDir,'slepc','examples')):
-      shutil.rmtree(os.path.join(self.destShareDir,'slepc','examples'))
-    os.mkdir(os.path.join(self.destShareDir,'slepc','examples'))
-    self.copyExamples(self.rootDir,os.path.join(self.destShareDir,'slepc','examples'))
+    if os.path.exists(examplesdir):
+      shutil.rmtree(examplesdir)
+    os.mkdir(examplesdir)
+    os.mkdir(os.path.join(examplesdir,'src'))
+    self.copyExamples(self.rootSrcDir,os.path.join(examplesdir,'src'))
     self.copyConfig(self.rootDir,examplesdir)
-    self.fixExamplesMakefile(os.path.join(self.destShareDir,'slepc','examples','makefile'))
+    self.fixExamplesMakefile(os.path.join(examplesdir,'gmakefile.test'))
     return
 
   def copyLib(self, src, dst):
