@@ -1,21 +1,11 @@
+from __future__ import print_function
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2015, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
-#
-#  SLEPc is free software: you can redistribute it and/or modify it under  the
-#  terms of version 3 of the GNU Lesser General Public License as published by
-#  the Free Software Foundation.
-#
-#  SLEPc  is  distributed in the hope that it will be useful, but WITHOUT  ANY
-#  WARRANTY;  without even the implied warranty of MERCHANTABILITY or  FITNESS
-#  FOR  A  PARTICULAR PURPOSE. See the GNU Lesser General Public  License  for
-#  more details.
-#
-#  You  should have received a copy of the GNU Lesser General  Public  License
-#  along with SLEPc. If not, see <http://www.gnu.org/licenses/>.
+#  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #
 
@@ -23,23 +13,28 @@ import os, sys
 
 class Log:
 
-  def Open(self,filename):
+  def Open(self,confdir,fname):
+    filename = os.path.join(confdir,fname)
     self.fd = open(filename,'w')
     try:
       self.filename = os.path.relpath(filename)  # needs python-2.6
     except AttributeError:
       self.filename = filename
+    try: # symbolic link to log file in current directory
+      if os.path.isfile(fname): os.remove(fname)
+      os.symlink(filename,fname)
+    except: pass
 
   def Println(self,string):
-    print string
+    print(string)
     self.fd.write(string+'\n')
 
   def Print(self,string):
-    print string,
+    print(string, end=' ')
     self.fd.write(string+' ')
 
   def NewSection(self,string):
-    print 'done\n'+string,
+    print('done\n'+string, end=' ')
     sys.stdout.flush()
     self.fd.write('='*80+'\n'+string+'\n')
 
@@ -47,7 +42,7 @@ class Log:
     self.fd.write(string+'\n')
 
   def Exit(self,string):
-    print '\n'+string
+    print('\n'+string)
     if hasattr(self,'fd'):
       self.fd.write('\n'+string+'\n')
       self.fd.close()
