@@ -2,15 +2,27 @@ from __future__ import print_function
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #
 
-import os, sys, commands, tempfile, shutil, urllib, urlparse, tarfile
+import os, sys, tempfile, shutil, tarfile
 import log, argdb
+try:
+  from urllib import urlretrieve
+except ImportError:
+  from urllib.request import urlretrieve
+try:
+  import urlparse
+except ImportError:
+  from urllib import parse as urlparse
+if sys.version_info < (3,):
+  import commands
+else:
+  import subprocess
 
 class Package:
 
@@ -27,6 +39,15 @@ class Package:
     self.supports64bint  = False
     self.fortran         = False
 
+  def RunCommand(self,instr):
+    try:
+      self.log.write('- '*35+'\nRunning command:\n'+instr+'\n'+'- '*35)
+    except AttributeError: pass
+    if sys.version_info < (3,):
+      return commands.getstatusoutput(instr)
+    else:
+      return subprocess.getstatusoutput(instr)
+
   def ProcessArgs(self,argdb):
     self.requested = False
     self.havepackage = False
@@ -110,7 +131,7 @@ class Package:
       if os.path.exists(localFile):
         os.remove(localFile)
       try:
-        urllib.urlretrieve(url, localFile)
+        urlretrieve(url, localFile)
       except Exception as e:
         filename = os.path.basename(urlparse.urlparse(url)[2])
         failureMessage = '''\
@@ -137,7 +158,7 @@ Unable to download package %s from: %s
           tar.close()
           os.remove(localFile)
         else:
-          result,output = commands.getstatusoutput('cd '+externdir+'; gunzip '+self.archive+'; tar -xf '+self.archive.split('.gz')[0])
+          result,output = self.RunCommand('cd '+externdir+'; gunzip '+self.archive+'; tar -xf '+self.archive.split('.gz')[0])
           os.remove(localFile.split('.gz')[0])
       except RuntimeError as e:
         self.log.Exit('Error uncompressing '+self.archive+': '+str(e))
@@ -170,7 +191,7 @@ Unable to download package %s from: %s
     else:
       return []
 
-  def LinkWithOutput(self,functions,callbacks,flags):
+  def LinkWithOutput(self,functions,callbacks,flags,givencode=''):
 
     # Create temporary directory and makefile
     try:
@@ -191,29 +212,32 @@ Unable to download package %s from: %s
       self.log.Exit('ERROR: Cannot create makefile in temporary directory')
 
     # Create source file
-    code = '#include "petscsnes.h"\n'
-    for f in functions:
-      code += 'PETSC_EXTERN int\n' + f + '();\n'
+    if givencode == '':
+      code = '#include "petscsnes.h"\n'
+      for f in functions:
+        code += 'PETSC_EXTERN int\n' + f + '();\n'
 
-    for c in callbacks:
-      code += 'int '+ c + '() { return 0; } \n'
+      for c in callbacks:
+        code += 'int '+ c + '() { return 0; } \n'
 
-    code += 'int main() {\n'
-    code += 'Vec v; Mat m; KSP k;\n'
-    code += 'PetscInitializeNoArguments();\n'
-    code += 'VecCreate(PETSC_COMM_WORLD,&v);\n'
-    code += 'MatCreate(PETSC_COMM_WORLD,&m);\n'
-    code += 'KSPCreate(PETSC_COMM_WORLD,&k);\n'
-    for f in functions:
-      code += f + '();\n'
-    code += 'return 0;\n}\n'
+      code += 'int main() {\n'
+      code += 'Vec v; Mat m; KSP k;\n'
+      code += 'PetscInitializeNoArguments();\n'
+      code += 'VecCreate(PETSC_COMM_WORLD,&v);\n'
+      code += 'MatCreate(PETSC_COMM_WORLD,&m);\n'
+      code += 'KSPCreate(PETSC_COMM_WORLD,&k);\n'
+      for f in functions:
+        code += f + '();\n'
+      code += 'return 0;\n}\n'
+    else:
+      code = givencode
 
     cfile = open(os.path.join(tmpdir,'checklink.c'),'w')
     cfile.write(code)
     cfile.close()
 
     # Try to compile test program
-    (result, output) = commands.getstatusoutput('cd ' + tmpdir + ';' + self.make + ' checklink TESTFLAGS="'+' '.join(flags)+'"')
+    (result, output) = self.RunCommand('cd ' + tmpdir + ';' + self.make + ' checklink TESTFLAGS="'+' '.join(flags)+'"')
     shutil.rmtree(tmpdir)
 
     if result:
