@@ -1,15 +1,14 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #
 
-import os, commands
-import log, package
+import os, log, package
 
 class Arpack(package.Package):
 
@@ -18,7 +17,7 @@ class Arpack(package.Package):
     self.packagename    = 'arpack'
     self.installable    = True
     self.downloadable   = True
-    self.version        = '3.3.0'
+    self.version        = '3.6.3'
     self.url            = 'https://github.com/opencollab/arpack-ng/archive/'+self.version+'.tar.gz'
     self.archive        = 'arpack-ng-'+self.version+'.tar.gz'
     self.dirname        = 'arpack-ng-'+self.version
@@ -76,17 +75,17 @@ class Arpack(package.Package):
     self.Download(externdir,builddir)
 
     # Check for autoreconf
-    result,output = commands.getstatusoutput('autoreconf --help')
+    result,output = self.RunCommand('autoreconf --help')
     if result:
       self.log.Exit('ERROR: --download-arpack requires that the command autoreconf is available on your PATH.')
 
     # Build package
-    confopt = '--prefix='+archdir+' F77="'+petsc.fc+'" FFLAGS="'+petsc.fc_flags.replace('-Wall','').replace('-Wshadow','')+'"'
+    confopt = '--prefix='+archdir+' CC="'+petsc.cc+'" CFLAGS="'+petsc.cc_flags+'" F77="'+petsc.fc+'" FFLAGS="'+petsc.fc_flags.replace('-Wall','').replace('-Wshadow','')+'"'
     if not petsc.mpiuni:
       confopt = confopt+' --enable-mpi'
     if not petsc.buildsharedlib:
       confopt = confopt+' --disable-shared'
-    result,output = commands.getstatusoutput('cd '+builddir+'&& sh bootstrap && ./configure '+confopt+' && '+petsc.make+' && '+petsc.make+' install')
+    result,output = self.RunCommand('cd '+builddir+'&& sh bootstrap && ./configure '+confopt+' && '+petsc.make+' && '+petsc.make+' install')
     self.log.write(output)
     if result:
       self.log.Exit('ERROR: installation of ARPACK failed.')
