@@ -1,21 +1,10 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2015, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
-#
-#  SLEPc is free software: you can redistribute it and/or modify it under  the
-#  terms of version 3 of the GNU Lesser General Public License as published by
-#  the Free Software Foundation.
-#
-#  SLEPc  is  distributed in the hope that it will be useful, but WITHOUT  ANY
-#  WARRANTY;  without even the implied warranty of MERCHANTABILITY or  FITNESS
-#  FOR  A  PARTICULAR PURPOSE. See the GNU Lesser General Public  License  for
-#  more details.
-#
-#  You  should have received a copy of the GNU Lesser General  Public  License
-#  along with SLEPc. If not, see <http://www.gnu.org/licenses/>.
+#  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #
 
@@ -24,34 +13,50 @@ import log, package
 class Lapack(package.Package):
 
   def __init__(self,argdb,log):
-    self.packagename  = 'lapack'
-    self.downloadable = False
-    self.log          = log
+    package.Package.__init__(self,argdb,log)
+    self.packagename = 'lapack'
 
   def ShowInfo(self):
     if hasattr(self,'missing'):
-      log.Println('LAPACK missing functions:')
-      log.Print('  ')
-      for i in self.missing: log.Print(i)
-      log.Println('')
-      log.Println('')
-      log.Println('WARNING: Some SLEPc functionality will not be available')
-      log.Println('PLEASE reconfigure and recompile PETSc with a full LAPACK implementation')
+      self.log.Println('LAPACK missing functions:')
+      self.log.Print('  ')
+      for i in self.missing: self.log.Print(i)
+      self.log.Println('')
+      self.log.Println('')
+      self.log.Println('WARNING: Some SLEPc functionality will not be available')
+      self.log.Println('PLEASE reconfigure and recompile PETSc with a full LAPACK implementation')
 
   def Process(self,conf,vars,cmake,petsc,archdir=''):
     self.make = petsc.make
-    self.slflag = petsc.slflag
+    self.mangling = petsc.blaslapackmangling
+    if petsc.buildsharedlib:
+      self.slflag = petsc.slflag
     self.log.NewSection('Checking LAPACK library...')
     self.Check(conf,vars,cmake,petsc)
 
+  def LinkBlasLapack(self,functions,callbacks,flags,petsc):
+    code = ''
+    for f in functions:
+      if petsc.language == 'c++':
+        code += 'extern "C" void ' + f + '();\n'
+      else:
+        code += 'extern void ' + f + '();\n'
+    code += 'int main() {\n'
+    for f in functions:
+      code += f + '();\n'
+    code += 'return 0;\n}\n'
+    (result, output) = self.LinkWithOutput(functions,callbacks,flags,code)
+    self.log.write(output)
+    return result
+
   def Check(self,conf,vars,cmake,petsc):
 
     # LAPACK standard functions
-    l = ['laev2','gehrd','lanhs','lange','getri','trexc','trevc','geevx','ggevx','gelqf','gesdd','tgexc','tgevc','pbtrf','stedc','hsein','larfg','larf','trsen','tgsen','lacpy','lascl','lansy','laset']
+    l = ['laev2','gehrd','lanhs','lange','trexc','trevc','geevx','gees','ggev','ggevx','gelqf','geqp3','gesdd','tgexc','tgevc','pbtrf','stedc','hsein','larfg','larf','lacpy','lascl','lansy','laset','trsyl','trtri']
 
     # LAPACK functions with different real and complex versions
     if petsc.scalar == 'real':
-      l += ['orghr','syevr','syevd','sytrd','sygvd','ormlq','orgqr','orgtr']
+      l += ['orghr','syevr','syevd','sytrd','sygvd','ormlq','orgtr']
       if petsc.precision == 'single':
         prefix = 's'
       elif petsc.precision == '__float128':
@@ -59,7 +64,7 @@ class Lapack(package.Package):
       else:
         prefix = 'd'
     else:
-      l += ['unghr','heevr','heevd','hetrd','hegvd','unmlq','ungqr','ungtr']
+      l += ['unghr','heevr','heevd','hetrd','hegvd','unmlq','ungtr']
       if petsc.precision == 'single':
         prefix = 'c'
       elif petsc.precision == '__float128':
@@ -73,7 +78,7 @@ class Lapack(package.Package):
       functions.append(prefix + i)
 
     # in this case, the real name represents both versions
-    namesubst = {'unghr':'orghr', 'heevr':'syevr', 'heevd':'syevd', 'hetrd':'sytrd', 'hegvd':'sygvd', 'unmlq':'ormlq', 'ungqr':'orgqr', 'ungtr':'orgtr'}
+    namesubst = {'unghr':'orghr', 'heevr':'syevr', 'heevd':'syevd', 'hetrd':'sytrd', 'hegvd':'sygvd', 'unmlq':'ormlq', 'ungtr':'orgtr'}
 
     # LAPACK functions which are always used in real version
     if petsc.precision == 'single':
@@ -84,34 +89,32 @@ class Lapack(package.Package):
       functions += ['dstevr','dbdsdc','dlamch','dlag2','dlasv2','dlartg','dlaln2','dlaed4','dlamrg','dlapy2']
 
     # check for all functions at once
-    all = []
+    allf = []
     for i in functions:
-      f =  '#if defined(PETSC_BLASLAPACK_UNDERSCORE)\n'
-      f += i + '_\n'
-      f += '#elif defined(PETSC_BLASLAPACK_CAPS) || defined(PETSC_BLASLAPACK_STDCALL)\n'
-      f += i.upper() + '\n'
-      f += '#else\n'
-      f += i + '\n'
-      f += '#endif\n'
-      all.append(f)
+      if self.mangling == 'underscore':
+        f = i + '_'
+      elif self.mangling == 'caps' or self.mangling == 'stdcall':
+        f = i.upper()
+      else:
+        f = i
+      allf.append(f)
 
     self.log.write('=== Checking all LAPACK functions...')
-    if self.Link(all,[],[]):
+    if self.LinkBlasLapack(allf,[],[],petsc):
       return
 
     # check functions one by one
     self.missing = []
     for i in functions:
-      f =  '#if defined(PETSC_BLASLAPACK_UNDERSCORE)\n'
-      f += i + '_\n'
-      f += '#elif defined(PETSC_BLASLAPACK_CAPS) || defined(PETSC_BLASLAPACK_STDCALL)\n'
-      f += i.upper() + '\n'
-      f += '#else\n'
-      f += i + '\n'
-      f += '#endif\n'
+      if self.mangling == 'underscore':
+        f = i + '_\n'
+      elif self.mangling == 'caps' or self.mangling == 'stdcall':
+        f = i.upper() + '\n'
+      else:
+        f = i + '\n'
 
       self.log.write('=== Checking LAPACK '+i+' function...')
-      if not self.Link([f],[],[]):
+      if not self.LinkBlasLapack([f],[],[],petsc):
         self.missing.append(i)
         # some complex functions are represented by their real names
         if i[1:] in namesubst:
