@@ -1,14 +1,14 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #
 
-import package, os, sys, commands
+import package, os, sys
 
 class PETSc(package.Package):
 
@@ -55,12 +55,12 @@ class PETSc(package.Package):
     # Check whether this is a working copy of the repository
     self.isrepo = False
     if os.path.exists(os.path.join(self.dir,'.git')):
-      (status, output) = commands.getstatusoutput('cd '+self.dir+';git rev-parse')
+      (status, output) = self.RunCommand('cd '+self.dir+';git rev-parse')
       if not status:
         self.isrepo = True
-        (status, self.gitrev) = commands.getstatusoutput('cd '+self.dir+';git log -1 --pretty=format:%H')
-        (status, self.gitdate) = commands.getstatusoutput('cd '+self.dir+';git log -1 --pretty=format:%ci')
-        (status, self.branch) = commands.getstatusoutput('cd '+self.dir+';git describe --contains --all HEAD')
+        (status, self.gitrev) = self.RunCommand('cd '+self.dir+';git log -1 --pretty=format:%H')
+        (status, self.gitdate) = self.RunCommand('cd '+self.dir+';git log -1 --pretty=format:%ci')
+        (status, self.branch) = self.RunCommand('cd '+self.dir+';git describe --contains --all HEAD')
 
   def LoadConf(self):
     if 'PETSC_ARCH' in os.environ and os.environ['PETSC_ARCH']:
@@ -133,7 +133,7 @@ class PETSc(package.Package):
     self.mpiuni = False
     self.debug = False
     self.singlelib = False
-    self.blaslapackunderscore = False
+    self.blaslapackmangling = ''
     self.blaslapackint64 = False
     self.fortran = False
     try:
@@ -149,7 +149,11 @@ class PETSc(package.Package):
         elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_USE_SINGLE_LIBRARY' and l[2]=='1':
           self.singlelib = True
         elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_BLASLAPACK_UNDERSCORE' and l[2]=='1':
-          self.blaslapackunderscore = True
+          self.blaslapackmangling = 'underscore'
+        elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_BLASLAPACK_CAPS' and l[2]=='1':
+          self.blaslapackmangling = 'caps'
+        elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_BLASLAPACK_STDCALL' and l[2]=='1':
+          self.blaslapackmangling = 'stdcall'
         elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_HAVE_64BIT_BLAS_INDICES' and l[2]=='1':
           self.blaslapackint64 = True
         elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_HAVE_FORTRAN' and l[2]=='1':
