@@ -1,15 +1,14 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #
 
-import os, commands, shutil
-import log, package
+import os, shutil, log, package
 
 class Primme(package.Package):
 
@@ -88,7 +87,7 @@ class Primme(package.Package):
     if hasattr(petsc,'fc'):
       g.write('F77         = '+petsc.fc+'\n')
     g.write('DEFINES     = ')
-    if petsc.blaslapackunderscore:
+    if petsc.blaslapackmangling == 'underscore':
       g.write('-DF77UNDERSCORE ')
     if petsc.blaslapackint64:
       g.write('-DPRIMME_BLASINT_SIZE=64')
@@ -99,7 +98,7 @@ class Primme(package.Package):
     g.close()
 
     # Build package
-    result,output = commands.getstatusoutput('cd '+builddir+'&&'+petsc.make+' clean &&'+petsc.make)
+    result,output = self.RunCommand('cd '+builddir+'&&'+petsc.make+' clean &&'+petsc.make)
     self.log.write(output)
     if result:
       self.log.Exit('ERROR: installation of PRIMME failed.')
