@@ -2,16 +2,16 @@ from __future__ import print_function
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #
 
-import argdb, os, sys, commands
+import argdb, os, sys, package
 
-class SLEPc:
+class SLEPc(package.Package):
 
   def __init__(self,argdb,log):
     self.log       = log
@@ -64,14 +64,14 @@ class SLEPc:
     # Check whether this is a working copy of the repository
     self.isrepo = False
     if os.path.exists(os.path.join(self.dir,'src','docs')) and os.path.exists(os.path.join(self.dir,'.git')):
-      (status, output) = commands.getstatusoutput('git rev-parse')
+      (status, output) = self.RunCommand('git rev-parse')
       if status:
         print('WARNING: SLEPC_DIR appears to be a git working copy, but git is not found in PATH')
       else:
         self.isrepo = True
-        (status, self.gitrev) = commands.getstatusoutput('git describe')
+        (status, self.gitrev) = self.RunCommand('git describe')
         if not self.gitrev:
-          (status, self.gitrev) = commands.getstatusoutput('git log -1 --pretty=format:%H')
-        (status, self.gitdate) = commands.getstatusoutput('git log -1 --pretty=format:%ci')
-        (status, self.branch) = commands.getstatusoutput('git describe --contains --all HEAD')
+          (status, self.gitrev) = self.RunCommand('git log -1 --pretty=format:%H')
+        (status, self.gitdate) = self.RunCommand('git log -1 --pretty=format:%ci')
+        (status, self.branch) = self.RunCommand('git describe --contains --all HEAD')
 
