@@ -1,15 +1,14 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #
 
-import os, commands
-import log, package
+import os, log, package
 
 class Trlan(package.Package):
 
@@ -62,7 +61,7 @@ class Trlan(package.Package):
       target = 'lib'
     else:
       target = 'plib'
-    result,output = commands.getstatusoutput('cd '+builddir+'&&'+petsc.make+' clean &&'+petsc.make+' '+target)
+    result,output = self.RunCommand('cd '+builddir+'&&'+petsc.make+' clean &&'+petsc.make+' '+target)
     self.log.write(output)
     if result:
       self.log.Exit('ERROR: installation of TRLAN failed.')
