@@ -1,7 +1,7 @@
 !
 !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 !  SLEPc - Scalable Library for Eigenvalue Problem Computations
-!  Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+!  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 !
 !  This file is part of SLEPc.
 !  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -9,8 +9,8 @@
 !
 !  Include file for Fortran use of the EPS object in SLEPc
 !
-#if !defined(__SLEPCEPSDEF_H)
-#define __SLEPCEPSDEF_H
+#if !defined(SLEPCEPSDEF_H)
+#define SLEPCEPSDEF_H
 
 #include "slepc/finclude/slepcsys.h"
 #include "slepc/finclude/slepcst.h"
