@@ -1,22 +1,22 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
 
-#if !defined(_NEPIMPL)
-#define _NEPIMPL
+#if !defined(SLEPCNEPIMPL_H)
+#define SLEPCNEPIMPL_H
 
 #include <slepcnep.h>
 #include <slepc/private/slepcimpl.h>
 
-PETSC_EXTERN PetscBool NEPRegisterAllCalled;
-PETSC_EXTERN PetscErrorCode NEPRegisterAll(void);
-PETSC_EXTERN PetscLogEvent NEP_SetUp,NEP_Solve,NEP_Refine,NEP_FunctionEval,NEP_JacobianEval,NEP_DerivativesEval;
+SLEPC_EXTERN PetscBool NEPRegisterAllCalled;
+SLEPC_EXTERN PetscErrorCode NEPRegisterAll(void);
+SLEPC_EXTERN PetscLogEvent NEP_SetUp,NEP_Solve,NEP_Refine,NEP_FunctionEval,NEP_JacobianEval,NEP_DerivativesEval,NEP_Resolvent;
 
 typedef struct _NEPOps *NEPOps;
 
@@ -74,6 +74,7 @@ struct _p_NEP {
   PetscInt       rits;             /* number of iterations of the refinement method */
   NEPRefineScheme scheme;          /* scheme for solving linear systems within refinement */
   PetscBool      trackall;         /* whether all the residuals must be computed */
+  PetscBool      twosided;         /* whether to compute left eigenvectors (two-sided solver) */
 
   /*-------------- User-provided functions and contexts -----------------*/
   PetscErrorCode (*computefunction)(NEP,PetscScalar,Mat,Mat,void*);
@@ -98,6 +99,7 @@ struct _p_NEP {
   /*----------------- Child objects and working data -------------------*/
   DS             ds;               /* direct solver object */
   BV             V;                /* set of basis vectors and computed eigenvectors */
+  BV             W;                /* left basis vectors (if left eigenvectors requested) */
   RG             rg;               /* optional region for filtering */
   SlepcSC        sc;               /* sorting criterion data */
   Mat            function;         /* function matrix */
@@ -125,6 +127,9 @@ struct _p_NEP {
   PetscInt       n,nloc;           /* problem dimensions (global, local) */
   PetscReal      *nrma;            /* computed matrix norms */
   NEPUserInterface fui;            /* how the user has defined the nonlinear operator */
+  PetscBool      useds;            /* whether the solver uses the DS object or not */
+  PetscBool      hasts;            /* whether the solver has two-sided variant */
+  Mat            resolvent;        /* shell matrix to be used in NEPApplyResolvent */
   NEPConvergedReason reason;
 };
 
@@ -168,12 +173,12 @@ struct _p_NEP {
 
 #endif
 
-PETSC_INTERN PetscErrorCode NEPSetDimensions_Default(NEP,PetscInt,PetscInt*,PetscInt*);
-PETSC_INTERN PetscErrorCode NEPComputeVectors(NEP);
-PETSC_INTERN PetscErrorCode NEPReset_Problem(NEP);
-PETSC_INTERN PetscErrorCode NEPGetDefaultShift(NEP,PetscScalar*);
-PETSC_INTERN PetscErrorCode NEPComputeVectors_Schur(NEP);
-PETSC_INTERN PetscErrorCode NEPComputeResidualNorm_Private(NEP,PetscScalar,Vec,Vec*,PetscReal*);
-PETSC_INTERN PetscErrorCode NEPNewtonRefinementSimple(NEP,PetscInt*,PetscReal,PetscInt);
+SLEPC_INTERN PetscErrorCode NEPSetDimensions_Default(NEP,PetscInt,PetscInt*,PetscInt*);
+SLEPC_INTERN PetscErrorCode NEPComputeVectors(NEP);
+SLEPC_INTERN PetscErrorCode NEPReset_Problem(NEP);
+SLEPC_INTERN PetscErrorCode NEPGetDefaultShift(NEP,PetscScalar*);
+SLEPC_INTERN PetscErrorCode NEPComputeVectors_Schur(NEP);
+SLEPC_INTERN PetscErrorCode NEPComputeResidualNorm_Private(NEP,PetscBool,PetscScalar,Vec,Vec*,PetscReal*);
+SLEPC_INTERN PetscErrorCode NEPNewtonRefinementSimple(NEP,PetscInt*,PetscReal,PetscInt);
 
 #endif
