@@ -1,20 +1,20 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
 
-#if !defined(_SLEPCIMPL)
-#define _SLEPCIMPL
+#if !defined(SLEPCIMPL_H)
+#define SLEPCIMPL_H
 
 #include <slepcsys.h>
 #include <petsc/private/petscimpl.h>
 
-PETSC_INTERN PetscBool SlepcBeganPetsc;
+SLEPC_INTERN PetscBool SlepcBeganPetsc;
 
 /*@C
     SlepcHeaderCreate - Creates a SLEPc object
@@ -79,11 +79,11 @@ PETSC_STATIC_INLINE PetscErrorCode SlepcPrintEigenvalueASCII(PetscScalar eigr,Pe
 }
 
 /* Private functions that are shared by several classes */
-PETSC_EXTERN PetscErrorCode SlepcBasisReference_Private(PetscInt,Vec*,PetscInt*,Vec**);
-PETSC_EXTERN PetscErrorCode SlepcBasisDestroy_Private(PetscInt*,Vec**);
+SLEPC_EXTERN PetscErrorCode SlepcBasisReference_Private(PetscInt,Vec*,PetscInt*,Vec**);
+SLEPC_EXTERN PetscErrorCode SlepcBasisDestroy_Private(PetscInt*,Vec**);
 
-PETSC_INTERN PetscErrorCode SlepcCitationsInitialize(void);
-PETSC_INTERN PetscErrorCode SlepcInitialize_DynamicLibraries(void);
-PETSC_INTERN PetscErrorCode SlepcInitialize_Packages(void);
+SLEPC_INTERN PetscErrorCode SlepcCitationsInitialize(void);
+SLEPC_INTERN PetscErrorCode SlepcInitialize_DynamicLibraries(void);
+SLEPC_INTERN PetscErrorCode SlepcInitialize_Packages(void);
 
 #endif
