@@ -1,22 +1,22 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
 
-#if !defined(_STIMPL)
-#define _STIMPL
+#if !defined(SLEPCSTIMPL_H)
+#define SLEPCSTIMPL_H
 
 #include <slepcst.h>
 #include <slepc/private/slepcimpl.h>
 
-PETSC_EXTERN PetscBool STRegisterAllCalled;
-PETSC_EXTERN PetscErrorCode STRegisterAll(void);
-PETSC_EXTERN PetscLogEvent ST_SetUp,ST_Apply,ST_ApplyTranspose,ST_MatSetUp,ST_MatMult,ST_MatMultTranspose,ST_MatSolve,ST_MatSolveTranspose;
+SLEPC_EXTERN PetscBool STRegisterAllCalled;
+SLEPC_EXTERN PetscErrorCode STRegisterAll(void);
+SLEPC_EXTERN PetscLogEvent ST_SetUp,ST_Apply,ST_ApplyTranspose,ST_MatSetUp,ST_MatMult,ST_MatMultTranspose,ST_MatSolve,ST_MatSolveTranspose;
 
 typedef struct _STOps *STOps;
 
@@ -85,16 +85,16 @@ struct _p_ST {
 
 #endif
 
-PETSC_INTERN PetscErrorCode STGetBilinearForm_Default(ST,Mat*);
-PETSC_INTERN PetscErrorCode STCheckNullSpace_Default(ST,BV);
-PETSC_INTERN PetscErrorCode STMatShellCreate(ST,PetscScalar,PetscInt,PetscInt*,PetscScalar*,Mat*);
-PETSC_INTERN PetscErrorCode STMatShellShift(Mat,PetscScalar);
-PETSC_INTERN PetscErrorCode STMatSetHermitian(ST,Mat);
-PETSC_INTERN PetscErrorCode STCheckFactorPackage(ST);
-PETSC_INTERN PetscErrorCode STMatMAXPY_Private(ST,PetscScalar,PetscScalar,PetscInt,PetscScalar*,PetscBool,Mat*);
-PETSC_INTERN PetscErrorCode STCoeffs_Monomial(ST,PetscScalar*);
-PETSC_INTERN PetscErrorCode STSetDefaultKSP(ST);
-PETSC_INTERN PetscErrorCode STSetDefaultKSP_Default(ST);
-PETSC_INTERN PetscErrorCode STIsInjective_Shell(ST,PetscBool*);
+SLEPC_INTERN PetscErrorCode STGetBilinearForm_Default(ST,Mat*);
+SLEPC_INTERN PetscErrorCode STCheckNullSpace_Default(ST,BV);
+SLEPC_INTERN PetscErrorCode STMatShellCreate(ST,PetscScalar,PetscInt,PetscInt*,PetscScalar*,Mat*);
+SLEPC_INTERN PetscErrorCode STMatShellShift(Mat,PetscScalar);
+SLEPC_INTERN PetscErrorCode STMatSetHermitian(ST,Mat);
+SLEPC_INTERN PetscErrorCode STCheckFactorPackage(ST);
+SLEPC_INTERN PetscErrorCode STMatMAXPY_Private(ST,PetscScalar,PetscScalar,PetscInt,PetscScalar*,PetscBool,Mat*);
+SLEPC_INTERN PetscErrorCode STCoeffs_Monomial(ST,PetscScalar*);
+SLEPC_INTERN PetscErrorCode STSetDefaultKSP(ST);
+SLEPC_INTERN PetscErrorCode STSetDefaultKSP_Default(ST);
+SLEPC_INTERN PetscErrorCode STIsInjective_Shell(ST,PetscBool*);
 
 #endif
