@@ -1,20 +1,20 @@
-#if !defined(__SLEPCVERSION_H)
-#define __SLEPCVERSION_H
+#if !defined(SLEPCVERSION_H)
+#define SLEPCVERSION_H
 
 #define SLEPC_VERSION_RELEASE    1
 #define SLEPC_VERSION_MAJOR      3
-#define SLEPC_VERSION_MINOR      10
+#define SLEPC_VERSION_MINOR      11
 #define SLEPC_VERSION_SUBMINOR   2
 #define SLEPC_VERSION_PATCH      0
-#define SLEPC_RELEASE_DATE       "September 18, 2018"
-#define SLEPC_VERSION_DATE       "feb 11, 2019"
+#define SLEPC_RELEASE_DATE       "March 29, 2019"
+#define SLEPC_VERSION_DATE       "Jul 30, 2019"
 
 #if !defined (SLEPC_VERSION_GIT)
-#define SLEPC_VERSION_GIT        "v3.10.2"
+#define SLEPC_VERSION_GIT        "v3.11.2"
 #endif
 
 #if !defined(SLEPC_VERSION_DATE_GIT)
-#define SLEPC_VERSION_DATE_GIT   "2019-02-11 17:30:05 +0100"
+#define SLEPC_VERSION_DATE_GIT   "2019-07-30 18:33:02 +0200"
 #endif
 
 #define SLEPC_VERSION_EQ(MAJOR,MINOR,SUBMINOR) \
