@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -166,7 +166,7 @@ int main(int argc,char **argv)
    test:
       suffix: 4
       requires: !single
-      args: -n 18 -eps_type power -eps_nev 3 -st_type sinvert -eps_target 1.15 -eps_power_shift_type {{constant rayleigh wilkinson}}
+      args: -n 18 -eps_type power -eps_nev 3 -st_type sinvert -eps_target 1.149 -eps_power_shift_type {{constant rayleigh wilkinson}}
 
    testset:
       args: -n 18 -eps_nev 3 -eps_smallest_real -eps_max_it 500 -st_pc_type icc
@@ -192,7 +192,7 @@ int main(int argc,char **argv)
 
    testset:
       args: -n 18 -eps_nev 4 -eps_max_it 1500 -mat_type aijcusparse
-      requires: veccuda
+      requires: cuda
       output_file: output/test1_1.out
       test:
          suffix: 7
@@ -209,7 +209,7 @@ int main(int argc,char **argv)
 
    testset:
       args: -n 18 -eps_nev 3 -eps_smallest_real -eps_max_it 500 -st_pc_type sor -mat_type aijcusparse
-      requires: veccuda
+      requires: cuda
       output_file: output/test1_5.out
       test:
          suffix: 8_rqcg
@@ -221,7 +221,7 @@ int main(int argc,char **argv)
    testset:
       nsize: 2
       args: -n 18 -eps_nev 7 -eps_ncv 32 -ds_parallel synchronized
-      requires: veccuda
+      requires: cuda
       filter: grep -v "orthogonality"
       output_file: output/test1_9.out
       test:
