@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -146,7 +146,7 @@ int main(int argc,char **argv)
 
    testset:
       args: -eps_nev 4 -mat_type aijcusparse
-      requires: veccuda !single
+      requires: cuda !single
       output_file: output/test2_1.out
       test:
          suffix: 4_cuda
