@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -14,7 +14,7 @@
 #include <blopex_lobpcg.h>
 #include "petsc-interface.h"
 
-PETSC_INTERN PetscInt slepc_blopex_useconstr;
+SLEPC_INTERN PetscInt slepc_blopex_useconstr;
 
 extern int
 SLEPCSetupInterpreter(mv_InterfaceInterpreter *ii);
