@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -91,7 +91,7 @@ PetscErrorCode EPSInitializePackage()
   This one registers all the EPS methods that are in the basic SLEPc libslepceps
   library.
  */
-PETSC_EXTERN PetscErrorCode PetscDLLibraryRegister_slepceps()
+SLEPC_EXTERN PetscErrorCode PetscDLLibraryRegister_slepceps()
 {
   PetscErrorCode ierr;
 
