@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -68,6 +68,7 @@ PetscErrorCode EPSCreate(MPI_Comm comm,EPS *outeps)
   eps->trueres         = PETSC_FALSE;
   eps->trackall        = PETSC_FALSE;
   eps->purify          = PETSC_TRUE;
+  eps->twosided        = PETSC_FALSE;
 
   eps->converged       = EPSConvergedRelative;
   eps->convergeduser   = NULL;
@@ -83,7 +84,9 @@ PetscErrorCode EPSCreate(MPI_Comm comm,EPS *outeps)
 
   eps->st              = NULL;
   eps->ds              = NULL;
+  eps->dsts            = NULL;
   eps->V               = NULL;
+  eps->W               = NULL;
   eps->rg              = NULL;
   eps->D               = NULL;
   eps->IS              = NULL;
@@ -106,6 +109,7 @@ PetscErrorCode EPSCreate(MPI_Comm comm,EPS *outeps)
   eps->nrma            = 0.0;
   eps->nrmb            = 0.0;
   eps->useds           = PETSC_FALSE;
+  eps->hasts           = PETSC_FALSE;
   eps->isgeneralized   = PETSC_FALSE;
   eps->ispositive      = PETSC_FALSE;
   eps->ishermitian     = PETSC_FALSE;
@@ -259,6 +263,7 @@ PetscErrorCode EPSReset(EPS eps)
   if (eps->st) { ierr = STReset(eps->st);CHKERRQ(ierr); }
   ierr = VecDestroy(&eps->D);CHKERRQ(ierr);
   ierr = BVDestroy(&eps->V);CHKERRQ(ierr);
+  ierr = BVDestroy(&eps->W);CHKERRQ(ierr);
   ierr = VecDestroyVecs(eps->nwork,&eps->work);CHKERRQ(ierr);
   eps->nwork = 0;
   eps->state = EPS_STATE_INITIAL;
@@ -296,6 +301,7 @@ PetscErrorCode EPSDestroy(EPS *eps)
   ierr = STDestroy(&(*eps)->st);CHKERRQ(ierr);
   ierr = RGDestroy(&(*eps)->rg);CHKERRQ(ierr);
   ierr = DSDestroy(&(*eps)->ds);CHKERRQ(ierr);
+  ierr = DSDestroy(&(*eps)->dsts);CHKERRQ(ierr);
   ierr = PetscFree((*eps)->sc);CHKERRQ(ierr);
   /* just in case the initial vectors have not been used */
   ierr = SlepcBasisDestroy_Private(&(*eps)->nds,&(*eps)->defl);CHKERRQ(ierr);
@@ -500,7 +506,9 @@ PetscErrorCode EPSGetST(EPS eps,ST *st)
   PetscValidPointer(st,2);
   if (!eps->st) {
     ierr = STCreate(PetscObjectComm((PetscObject)eps),&eps->st);CHKERRQ(ierr);
+    ierr = PetscObjectIncrementTabLevel((PetscObject)eps->st,(PetscObject)eps,0);CHKERRQ(ierr);
     ierr = PetscLogObjectParent((PetscObject)eps,(PetscObject)eps->st);CHKERRQ(ierr);
+    ierr = PetscObjectSetOptions((PetscObject)eps->st,((PetscObject)eps)->options);CHKERRQ(ierr);
   }
   *st = eps->st;
   PetscFunctionReturn(0);
@@ -515,10 +523,6 @@ PetscErrorCode EPSGetST(EPS eps,ST *st)
 +  eps - eigensolver context obtained from EPSCreate()
 -  V   - the basis vectors object
 
-   Note:
-   Use EPSGetBV() to retrieve the basis vectors context (for example,
-   to free them at the end of the computations).
-
    Level: advanced
 
 .seealso: EPSGetBV()
@@ -562,7 +566,9 @@ PetscErrorCode EPSGetBV(EPS eps,BV *V)
   PetscValidPointer(V,2);
   if (!eps->V) {
     ierr = BVCreate(PetscObjectComm((PetscObject)eps),&eps->V);CHKERRQ(ierr);
+    ierr = PetscObjectIncrementTabLevel((PetscObject)eps->V,(PetscObject)eps,0);CHKERRQ(ierr);
     ierr = PetscLogObjectParent((PetscObject)eps,(PetscObject)eps->V);CHKERRQ(ierr);
+    ierr = PetscObjectSetOptions((PetscObject)eps->V,((PetscObject)eps)->options);CHKERRQ(ierr);
   }
   *V = eps->V;
   PetscFunctionReturn(0);
@@ -624,7 +630,9 @@ PetscErrorCode EPSGetRG(EPS eps,RG *rg)
   PetscValidPointer(rg,2);
   if (!eps->rg) {
     ierr = RGCreate(PetscObjectComm((PetscObject)eps),&eps->rg);CHKERRQ(ierr);
+    ierr = PetscObjectIncrementTabLevel((PetscObject)eps->rg,(PetscObject)eps,0);CHKERRQ(ierr);
     ierr = PetscLogObjectParent((PetscObject)eps,(PetscObject)eps->rg);CHKERRQ(ierr);
+    ierr = PetscObjectSetOptions((PetscObject)eps->rg,((PetscObject)eps)->options);CHKERRQ(ierr);
   }
   *rg = eps->rg;
   PetscFunctionReturn(0);
@@ -686,7 +694,9 @@ PetscErrorCode EPSGetDS(EPS eps,DS *ds)
   PetscValidPointer(ds,2);
   if (!eps->ds) {
     ierr = DSCreate(PetscObjectComm((PetscObject)eps),&eps->ds);CHKERRQ(ierr);
+    ierr = PetscObjectIncrementTabLevel((PetscObject)eps->ds,(PetscObject)eps,0);CHKERRQ(ierr);
     ierr = PetscLogObjectParent((PetscObject)eps,(PetscObject)eps->ds);CHKERRQ(ierr);
+    ierr = PetscObjectSetOptions((PetscObject)eps->ds,((PetscObject)eps)->options);CHKERRQ(ierr);
   }
   *ds = eps->ds;
   PetscFunctionReturn(0);
