@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -54,7 +54,7 @@ PetscErrorCode EPSSetDefaultST_Precond(EPS eps)
 
 /*
    This is done by preconditioned eigensolvers that can also use the KSP.
-   It sets STPRECOND with the default KSP (GMRES).
+   It sets STPRECOND with the default KSP (GMRES) and maxit=5.
 */
 PetscErrorCode EPSSetDefaultST_GMRES(EPS eps)
 {
@@ -67,7 +67,10 @@ PetscErrorCode EPSSetDefaultST_GMRES(EPS eps)
     ierr = STPrecondSetKSPHasMat(eps->st,PETSC_TRUE);CHKERRQ(ierr);
   }
   ierr = STGetKSP(eps->st,&ksp);CHKERRQ(ierr);
-  ierr = KSPSetTolerances(ksp,PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT,5);CHKERRQ(ierr);
+  if (!((PetscObject)ksp)->type_name) {
+    ierr = KSPSetType(ksp,KSPGMRES);CHKERRQ(ierr);
+    ierr = KSPSetTolerances(ksp,PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT,5);CHKERRQ(ierr);
+  }
   PetscFunctionReturn(0);
 }
 
@@ -122,6 +125,11 @@ PetscErrorCode EPSSetUp(EPS eps)
 
   ierr = STSetTransform(eps->st,PETSC_TRUE);CHKERRQ(ierr);
   if (eps->useds && !eps->ds) { ierr = EPSGetDS(eps,&eps->ds);CHKERRQ(ierr); }
+  if (eps->twosided) {
+    if (!eps->hasts) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support computing left eigenvectors (no two-sided variant)");
+    if (eps->ishermitian) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Two-sided methods are not intended for symmetric problems");
+    if (!eps->dsts) { ierr = DSDuplicate(eps->ds,&eps->dsts);CHKERRQ(ierr); }
+  }
   if (!eps->rg) { ierr = EPSGetRG(eps,&eps->rg);CHKERRQ(ierr); }
   if (!((PetscObject)eps->rg)->type_name) {
     ierr = RGSetType(eps->rg,RGINTERVAL);CHKERRQ(ierr);
@@ -234,29 +242,31 @@ PetscErrorCode EPSSetUp(EPS eps)
   eps->sc->map    = NULL;
   eps->sc->mapobj = NULL;
 
-  if (eps->useds) {
-    /* fill sorting criterion for DS */
+  /* fill sorting criterion for DS */
+  if (eps->useds && eps->which!=EPS_ALL) {
     ierr = DSGetSlepcSC(eps->ds,&sc);CHKERRQ(ierr);
     ierr = RGIsTrivial(eps->rg,&istrivial);CHKERRQ(ierr);
-    if (eps->which!=EPS_ALL) {
-      sc->rg            = istrivial? NULL: eps->rg;
-      sc->comparison    = eps->sc->comparison;
-      sc->comparisonctx = eps->sc->comparisonctx;
-      sc->map           = SlepcMap_ST;
-      sc->mapobj        = (PetscObject)eps->st;
+    sc->rg            = istrivial? NULL: eps->rg;
+    sc->comparison    = eps->sc->comparison;
+    sc->comparisonctx = eps->sc->comparisonctx;
+    sc->map           = SlepcMap_ST;
+    sc->mapobj        = (PetscObject)eps->st;
+    if (eps->twosided) {
+      ierr = DSSetSlepcSC(eps->dsts,sc);CHKERRQ(ierr);
     }
   }
 
   /* Build balancing matrix if required */
-  if (!eps->ishermitian && (eps->balance==EPS_BALANCE_ONESIDE || eps->balance==EPS_BALANCE_TWOSIDE)) {
-    if (!eps->D) {
-      ierr = BVCreateVec(eps->V,&eps->D);CHKERRQ(ierr);
-      ierr = PetscLogObjectParent((PetscObject)eps,(PetscObject)eps->D);CHKERRQ(ierr);
-    } else {
-      ierr = VecSet(eps->D,1.0);CHKERRQ(ierr);
+  if (eps->balance!=EPS_BALANCE_USER) {
+    ierr = STSetBalanceMatrix(eps->st,NULL);CHKERRQ(ierr);
+    if (!eps->ishermitian && (eps->balance==EPS_BALANCE_ONESIDE || eps->balance==EPS_BALANCE_TWOSIDE)) {
+      if (!eps->D) {
+        ierr = BVCreateVec(eps->V,&eps->D);CHKERRQ(ierr);
+        ierr = PetscLogObjectParent((PetscObject)eps,(PetscObject)eps->D);CHKERRQ(ierr);
+      }
+      ierr = EPSBuildBalance_Krylov(eps);CHKERRQ(ierr);
+      ierr = STSetBalanceMatrix(eps->st,eps->D);CHKERRQ(ierr);
     }
-    ierr = EPSBuildBalance_Krylov(eps);CHKERRQ(ierr);
-    ierr = STSetBalanceMatrix(eps->st,eps->D);CHKERRQ(ierr);
   }
 
   /* Setup ST */
@@ -506,7 +516,7 @@ PetscErrorCode EPSSetDimensions_Default(EPS eps,PetscInt nev,PetscInt *ncv,Petsc
            working basis slightly larger than ncv
 
    Developers Note:
-   This is PETSC_EXTERN because it may be required by user plugin EPS
+   This is SLEPC_EXTERN because it may be required by user plugin EPS
    implementations.
 
    Level: developer
@@ -554,6 +564,12 @@ PetscErrorCode EPSAllocateSolution(EPS eps,PetscInt extra)
   } else {
     ierr = BVResize(eps->V,requested,PETSC_FALSE);CHKERRQ(ierr);
   }
+
+  /* allocate W */
+  if (eps->twosided) {
+    ierr = BVDestroy(&eps->W);CHKERRQ(ierr);
+    ierr = BVDuplicate(eps->V,&eps->W);CHKERRQ(ierr);
+  }
   PetscFunctionReturn(0);
 }
 
