@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -12,6 +12,7 @@
 */
 
 #include <slepc/private/epsimpl.h>   /*I "slepceps.h" I*/
+#include <slepc/private/bvimpl.h>    /*I "slepcbv.h" I*/
 #include <petscdraw.h>
 
 PetscErrorCode EPSComputeVectors(EPS eps)
@@ -384,7 +385,7 @@ PetscErrorCode EPSGetInvariantSubspace(EPS eps,Vec *v)
 
    Level: beginner
 
-.seealso: EPSGetEigenvalue(), EPSGetEigenvector(), EPSSolve(),
+.seealso: EPSGetEigenvalue(), EPSGetEigenvector(), EPSGetLeftEigenvector(), EPSSolve(),
           EPSGetConverged(), EPSSetWhichEigenpairs(), EPSGetInvariantSubspace()
 @*/
 PetscErrorCode EPSGetEigenpair(EPS eps,PetscInt i,PetscScalar *eigr,PetscScalar *eigi,Vec Vr,Vec Vi)
@@ -465,7 +466,8 @@ PetscErrorCode EPSGetEigenvalue(EPS eps,PetscInt i,PetscScalar *eigr,PetscScalar
 
    If the corresponding eigenvalue is real, then Vi is set to zero. If PETSc is
    configured with complex scalars the eigenvector is stored
-   directly in Vr (Vi is set to zero). In both cases, the user can pass NULL in Vi.
+   directly in Vr (Vi is set to zero). In any case, the user can pass NULL in Vr
+   or Vi if one of them is not required.
 
    The index i should be a value between 0 and nconv-1 (see EPSGetConverged()).
    Eigenpairs are indexed according to the ordering criterion established
@@ -477,7 +479,7 @@ PetscErrorCode EPSGetEigenvalue(EPS eps,PetscInt i,PetscScalar *eigr,PetscScalar
 
    Level: beginner
 
-.seealso: EPSSolve(), EPSGetConverged(), EPSSetWhichEigenpairs(), EPSGetEigenpair()
+.seealso: EPSSolve(), EPSGetConverged(), EPSSetWhichEigenpairs(), EPSGetEigenpair(), EPSGetLeftEigenvector()
 @*/
 PetscErrorCode EPSGetEigenvector(EPS eps,PetscInt i,Vec Vr,Vec Vi)
 {
@@ -487,33 +489,65 @@ PetscErrorCode EPSGetEigenvector(EPS eps,PetscInt i,Vec Vr,Vec Vi)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidLogicalCollectiveInt(eps,i,2);
-  PetscValidHeaderSpecific(Vr,VEC_CLASSID,3);
-  PetscCheckSameComm(eps,1,Vr,3);
+  if (Vr) { PetscValidHeaderSpecific(Vr,VEC_CLASSID,3); PetscCheckSameComm(eps,1,Vr,3); }
   if (Vi) { PetscValidHeaderSpecific(Vi,VEC_CLASSID,4); PetscCheckSameComm(eps,1,Vi,4); }
   EPSCheckSolved(eps,1);
   if (i<0 || i>=eps->nconv) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Argument 2 out of range");
   ierr = EPSComputeVectors(eps);CHKERRQ(ierr);
   k = eps->perm[i];
-#if defined(PETSC_USE_COMPLEX)
-  ierr = BVCopyVec(eps->V,k,Vr);CHKERRQ(ierr);
-  if (Vi) { ierr = VecSet(Vi,0.0);CHKERRQ(ierr); }
-#else
-  if (eps->eigi[k] > 0) { /* first value of conjugate pair */
-    ierr = BVCopyVec(eps->V,k,Vr);CHKERRQ(ierr);
-    if (Vi) {
-      ierr = BVCopyVec(eps->V,k+1,Vi);CHKERRQ(ierr);
-    }
-  } else if (eps->eigi[k] < 0) { /* second value of conjugate pair */
-    ierr = BVCopyVec(eps->V,k-1,Vr);CHKERRQ(ierr);
-    if (Vi) {
-      ierr = BVCopyVec(eps->V,k,Vi);CHKERRQ(ierr);
-      ierr = VecScale(Vi,-1.0);CHKERRQ(ierr);
-    }
-  } else { /* real eigenvalue */
-    ierr = BVCopyVec(eps->V,k,Vr);CHKERRQ(ierr);
-    if (Vi) { ierr = VecSet(Vi,0.0);CHKERRQ(ierr); }
-  }
-#endif
+  ierr = BV_GetEigenvector(eps->V,k,eps->eigi[k],Vr,Vi);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+/*@
+   EPSGetLeftEigenvector - Gets the i-th left eigenvector as computed by EPSSolve().
+
+   Logically Collective on EPS
+
+   Input Parameters:
++  eps - eigensolver context
+-  i   - index of the solution
+
+   Output Parameters:
++  Wr   - real part of left eigenvector
+-  Wi   - imaginary part of left eigenvector
+
+   Notes:
+   The caller must provide valid Vec objects, i.e., they must be created
+   by the calling program with e.g. MatCreateVecs().
+
+   If the corresponding eigenvalue is real, then Wi is set to zero. If PETSc is
+   configured with complex scalars the eigenvector is stored directly in Wr
+   (Wi is set to zero). In any case, the user can pass NULL in Wr or Wi if
+   one of them is not required.
+
+   The index i should be a value between 0 and nconv-1 (see EPSGetConverged()).
+   Eigensolutions are indexed according to the ordering criterion established
+   with EPSSetWhichEigenpairs().
+
+   Left eigenvectors are available only if the twosided flag was set, see
+   EPSSetTwoSided().
+
+   Level: intermediate
+
+.seealso: EPSGetEigenvector(), EPSGetConverged(), EPSSetWhichEigenpairs(), EPSSetTwoSided()
+@*/
+PetscErrorCode EPSGetLeftEigenvector(EPS eps,PetscInt i,Vec Wr,Vec Wi)
+{
+  PetscErrorCode ierr;
+  PetscInt       k;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
+  PetscValidLogicalCollectiveInt(eps,i,2);
+  if (Wr) { PetscValidHeaderSpecific(Wr,VEC_CLASSID,3); PetscCheckSameComm(eps,1,Wr,3); }
+  if (Wi) { PetscValidHeaderSpecific(Wi,VEC_CLASSID,4); PetscCheckSameComm(eps,1,Wi,4); }
+  EPSCheckSolved(eps,1);
+  if (!eps->twosided) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONGSTATE,"Must request left vectors with EPSSetTwoSided");
+  if (i<0 || i>=eps->nconv) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Argument 2 out of range");
+  ierr = EPSComputeVectors(eps);CHKERRQ(ierr);
+  k = eps->perm[i];
+  ierr = BV_GetEigenvector(eps->W,k,eps->eigi[k],Wr,Wi);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -555,20 +589,23 @@ PetscErrorCode EPSGetErrorEstimate(EPS eps,PetscInt i,PetscReal *errest)
    associated with an eigenpair.
 
    Input Parameters:
+     trans - whether A' must be used instead of A
      kr,ki - eigenvalue
      xr,xi - eigenvector
      z     - three work vectors (the second one not referenced in complex scalars)
 */
-PetscErrorCode EPSComputeResidualNorm_Private(EPS eps,PetscScalar kr,PetscScalar ki,Vec xr,Vec xi,Vec *z,PetscReal *norm)
+PetscErrorCode EPSComputeResidualNorm_Private(EPS eps,PetscBool trans,PetscScalar kr,PetscScalar ki,Vec xr,Vec xi,Vec *z,PetscReal *norm)
 {
   PetscErrorCode ierr;
   PetscInt       nmat;
   Mat            A,B;
   Vec            u,w;
+  PetscScalar    alpha;
 #if !defined(PETSC_USE_COMPLEX)
   Vec            v;
   PetscReal      ni,nr;
 #endif
+  PetscErrorCode (*matmult)(Mat,Vec,Vec) = trans? MatMultHermitianTranspose: MatMult;
 
   PetscFunctionBegin;
   u = z[0]; w = z[2];
@@ -580,29 +617,30 @@ PetscErrorCode EPSComputeResidualNorm_Private(EPS eps,PetscScalar kr,PetscScalar
   v = z[1];
   if (ki == 0 || PetscAbsScalar(ki) < PetscAbsScalar(kr*PETSC_MACHINE_EPSILON)) {
 #endif
-    ierr = MatMult(A,xr,u);CHKERRQ(ierr);                             /* u=A*x */
+    ierr = (*matmult)(A,xr,u);CHKERRQ(ierr);                          /* u=A*x */
     if (PetscAbsScalar(kr) > PETSC_MACHINE_EPSILON) {
-      if (nmat>1) { ierr = MatMult(B,xr,w);CHKERRQ(ierr); }
+      if (nmat>1) { ierr = (*matmult)(B,xr,w);CHKERRQ(ierr); }
       else { ierr = VecCopy(xr,w);CHKERRQ(ierr); }                    /* w=B*x */
-      ierr = VecAXPY(u,-kr,w);CHKERRQ(ierr);                          /* u=A*x-k*B*x */
+      alpha = trans? -PetscConj(kr): -kr;
+      ierr = VecAXPY(u,alpha,w);CHKERRQ(ierr);                        /* u=A*x-k*B*x */
     }
     ierr = VecNorm(u,NORM_2,norm);CHKERRQ(ierr);
 #if !defined(PETSC_USE_COMPLEX)
   } else {
-    ierr = MatMult(A,xr,u);CHKERRQ(ierr);                             /* u=A*xr */
+    ierr = (*matmult)(A,xr,u);CHKERRQ(ierr);                          /* u=A*xr */
     if (SlepcAbsEigenvalue(kr,ki) > PETSC_MACHINE_EPSILON) {
-      if (nmat>1) { ierr = MatMult(B,xr,v);CHKERRQ(ierr); }
+      if (nmat>1) { ierr = (*matmult)(B,xr,v);CHKERRQ(ierr); }
       else { ierr = VecCopy(xr,v);CHKERRQ(ierr); }                    /* v=B*xr */
       ierr = VecAXPY(u,-kr,v);CHKERRQ(ierr);                          /* u=A*xr-kr*B*xr */
-      if (nmat>1) { ierr = MatMult(B,xi,w);CHKERRQ(ierr); }
+      if (nmat>1) { ierr = (*matmult)(B,xi,w);CHKERRQ(ierr); }
       else { ierr = VecCopy(xi,w);CHKERRQ(ierr); }                    /* w=B*xi */
-      ierr = VecAXPY(u,ki,w);CHKERRQ(ierr);                           /* u=A*xr-kr*B*xr+ki*B*xi */
+      ierr = VecAXPY(u,trans?-ki:ki,w);CHKERRQ(ierr);                 /* u=A*xr-kr*B*xr+ki*B*xi */
     }
     ierr = VecNorm(u,NORM_2,&nr);CHKERRQ(ierr);
-    ierr = MatMult(A,xi,u);CHKERRQ(ierr);                             /* u=A*xi */
+    ierr = (*matmult)(A,xi,u);CHKERRQ(ierr);                          /* u=A*xi */
     if (SlepcAbsEigenvalue(kr,ki) > PETSC_MACHINE_EPSILON) {
       ierr = VecAXPY(u,-kr,w);CHKERRQ(ierr);                          /* u=A*xi-kr*B*xi */
-      ierr = VecAXPY(u,-ki,v);CHKERRQ(ierr);                          /* u=A*xi-kr*B*xi-ki*B*xr */
+      ierr = VecAXPY(u,trans?ki:-ki,v);CHKERRQ(ierr);                 /* u=A*xi-kr*B*xi-ki*B*xr */
     }
     ierr = VecNorm(u,NORM_2,&ni);CHKERRQ(ierr);
     *norm = SlepcAbsEigenvalue(nr,ni);
@@ -638,7 +676,7 @@ PetscErrorCode EPSComputeError(EPS eps,PetscInt i,EPSErrorType type,PetscReal *e
   PetscErrorCode ierr;
   Mat            A,B;
   Vec            xr,xi,w[3];
-  PetscReal      t,vecnorm=1.0;
+  PetscReal      t,vecnorm=1.0,errorl;
   PetscScalar    kr,ki;
   PetscBool      flg;
 
@@ -663,15 +701,22 @@ PetscErrorCode EPSComputeError(EPS eps,PetscInt i,EPSErrorType type,PetscReal *e
   w[0] = eps->work[1];
   w[2] = eps->work[2];
 
-  /* compute residual norms */
+  /* compute residual norm */
   ierr = EPSGetEigenpair(eps,i,&kr,&ki,xr,xi);CHKERRQ(ierr);
-  ierr = EPSComputeResidualNorm_Private(eps,kr,ki,xr,xi,w,error);CHKERRQ(ierr);
+  ierr = EPSComputeResidualNorm_Private(eps,PETSC_FALSE,kr,ki,xr,xi,w,error);CHKERRQ(ierr);
 
   /* compute 2-norm of eigenvector */
   if (eps->problem_type==EPS_GHEP) {
     ierr = VecNorm(xr,NORM_2,&vecnorm);CHKERRQ(ierr);
   }
 
+  /* if two-sided, compute left residual norm and take the maximum */
+  if (eps->twosided) {
+    ierr = EPSGetLeftEigenvector(eps,i,xr,xi);CHKERRQ(ierr);
+    ierr = EPSComputeResidualNorm_Private(eps,PETSC_TRUE,kr,ki,xr,xi,w,&errorl);CHKERRQ(ierr);
+    *error = PetscMax(*error,errorl);
+  }
+
   /* compute error */
   switch (type) {
     case EPS_ERROR_ABSOLUTE:
