@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -180,7 +180,7 @@ PetscErrorCode MFNSolve_Expokit(MFN mfn,Vec b,Vec x)
   PetscFunctionReturn(0);
 }
 
-PETSC_EXTERN PetscErrorCode MFNCreate_Expokit(MFN mfn)
+SLEPC_EXTERN PetscErrorCode MFNCreate_Expokit(MFN mfn)
 {
   PetscFunctionBegin;
   mfn->ops->solve          = MFNSolve_Expokit;
