@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -53,7 +53,7 @@ PetscErrorCode MFNSolve(MFN mfn,Vec b,Vec x)
   PetscCheckSameComm(mfn,1,b,2);
   if (b!=x) PetscValidHeaderSpecific(x,VEC_CLASSID,3);
   if (b!=x) PetscCheckSameComm(mfn,1,x,3);
-  VecLocked(x,3);
+  ierr = VecSetErrorIfLocked(x,3);CHKERRQ(ierr);
 
   /* call setup */
   ierr = MFNSetUp(mfn);CHKERRQ(ierr);
@@ -67,9 +67,9 @@ PetscErrorCode MFNSolve(MFN mfn,Vec b,Vec x)
 
   /* call solver */
   ierr = PetscLogEventBegin(MFN_Solve,mfn,b,x,0);CHKERRQ(ierr);
-  if (b!=x) { ierr = VecLockPush(b);CHKERRQ(ierr); }
+  if (b!=x) { ierr = VecLockReadPush(b);CHKERRQ(ierr); }
   ierr = (*mfn->ops->solve)(mfn,b,x);CHKERRQ(ierr);
-  if (b!=x) { ierr = VecLockPop(b);CHKERRQ(ierr); }
+  if (b!=x) { ierr = VecLockReadPop(b);CHKERRQ(ierr); }
   ierr = PetscLogEventEnd(MFN_Solve,mfn,b,x,0);CHKERRQ(ierr);
 
   if (!mfn->reason) SETERRQ(PetscObjectComm((PetscObject)mfn),PETSC_ERR_PLIB,"Internal error, solver returned without setting converged reason");
