@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -90,7 +90,7 @@ int main(int argc,char **argv)
   ierr = MatSetSizes(J,PETSC_DECIDE,PETSC_DECIDE,n,n);CHKERRQ(ierr);
   ierr = MatSetFromOptions(J);CHKERRQ(ierr);
   ierr = MatSeqAIJSetPreallocation(J,3,NULL);CHKERRQ(ierr);
-  ierr = MatMPIAIJSetPreallocation(F,3,NULL,1,NULL);CHKERRQ(ierr);
+  ierr = MatMPIAIJSetPreallocation(J,3,NULL,1,NULL);CHKERRQ(ierr);
   ierr = MatSetUp(J);CHKERRQ(ierr);
 
   /*
@@ -429,4 +429,33 @@ PetscErrorCode FixSign(Vec x)
       filter: sed -e "s/[0-9]\.[0-9]*e-\([0-9]*\)/removed/g" -e "s/ Number of NEP iterations = \([0-9]*\)/ Number of NEP iterations = /"
       requires: !single
 
+   testset:
+      args: -nep_type nleigs -nep_target 10 -nep_nev 4
+      test:
+         suffix: 2
+         filter: sed -e "s/[0-9]\.[0-9]*e-\([0-9]*\)/removed/g" -e "s/0\.\([0-9]*\)/removed/g" -e "s/ Number of NEP iterations = \([0-9]*\)/ Number of NEP iterations = /"
+         args: -rg_interval_endpoints 4,900
+         requires: !single !complex
+      test:
+         suffix: 2_complex
+         filter: sed -e "s/[+-]0.[0-9]*i//" -e "s/[0-9]\.[0-9]*e-\([0-9]*\)/removed/g" -e "s/0\.\([0-9]*\)/removed/g" -e "s/ Number of NEP iterations = \([0-9]*\)/ Number of NEP iterations = /"
+         output_file: output/ex20_2.out
+         args: -rg_interval_endpoints 4,900,-.1,.1
+         requires: !single complex
+
+   testset:
+      args: -nep_type nleigs -nep_target 10 -nep_nev 4 -nep_two_sided {{0 1}} -nep_nleigs_full_basis
+      test:
+         suffix: 3
+         filter: sed -e "s/[0-9]\.[0-9]*e-\([0-9]*\)/removed/g" -e "s/0\.\([0-9]*\)/removed/g" -e "s/ Number of NEP iterations = \([0-9]*\)/ Number of NEP iterations = /"
+         output_file: output/ex20_2.out
+         args: -rg_interval_endpoints 4,900
+         requires: !single !complex
+      test:
+         suffix: 3_complex
+         filter: sed -e "s/[+-]0.[0-9]*i//" -e "s/[0-9]\.[0-9]*e-\([0-9]*\)/removed/g" -e "s/0\.\([0-9]*\)/removed/g" -e "s/ Number of NEP iterations = \([0-9]*\)/ Number of NEP iterations = /"
+         output_file: output/ex20_2.out
+         args: -rg_interval_endpoints 4,900,-.1,.1
+         requires: !single complex
+
 TEST*/
