@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -16,7 +16,7 @@
 PetscFunctionList NEPList = 0;
 PetscBool         NEPRegisterAllCalled = PETSC_FALSE;
 PetscClassId      NEP_CLASSID = 0;
-PetscLogEvent     NEP_SetUp = 0,NEP_Solve = 0,NEP_Refine = 0,NEP_FunctionEval = 0,NEP_JacobianEval = 0,NEP_DerivativesEval = 0;
+PetscLogEvent     NEP_SetUp = 0,NEP_Solve = 0,NEP_Refine = 0,NEP_FunctionEval = 0,NEP_JacobianEval = 0,NEP_DerivativesEval = 0,NEP_Resolvent = 0;
 
 /*@
    NEPCreate - Creates the default NEP context.
@@ -61,6 +61,7 @@ PetscErrorCode NEPCreate(MPI_Comm comm,NEP *outnep)
   nep->rits            = PETSC_DEFAULT;
   nep->scheme          = (NEPRefineScheme)0;
   nep->trackall        = PETSC_FALSE;
+  nep->twosided        = PETSC_FALSE;
 
   nep->computefunction = NULL;
   nep->computejacobian = NULL;
@@ -80,6 +81,7 @@ PetscErrorCode NEPCreate(MPI_Comm comm,NEP *outnep)
 
   nep->ds              = NULL;
   nep->V               = NULL;
+  nep->W               = NULL;
   nep->rg              = NULL;
   nep->function        = NULL;
   nep->function_pre    = NULL;
@@ -105,6 +107,9 @@ PetscErrorCode NEPCreate(MPI_Comm comm,NEP *outnep)
   nep->nloc            = 0;
   nep->nrma            = NULL;
   nep->fui             = (NEPUserInterface)0;
+  nep->useds           = PETSC_FALSE;
+  nep->hasts           = PETSC_FALSE;
+  nep->resolvent       = NULL;
   nep->reason          = NEP_CONVERGED_ITERATING;
 
   ierr = PetscNewLog(nep,&nep->sc);CHKERRQ(ierr);
@@ -273,7 +278,9 @@ PetscErrorCode NEPReset(NEP nep)
   if (nep->refineksp) { ierr = KSPReset(nep->refineksp);CHKERRQ(ierr); }
   ierr = NEPReset_Problem(nep);CHKERRQ(ierr);
   ierr = BVDestroy(&nep->V);CHKERRQ(ierr);
+  ierr = BVDestroy(&nep->W);CHKERRQ(ierr);
   ierr = VecDestroyVecs(nep->nwork,&nep->work);CHKERRQ(ierr);
+  ierr = MatDestroy(&nep->resolvent);CHKERRQ(ierr);
   nep->nwork = 0;
   nep->state = NEP_STATE_INITIAL;
   PetscFunctionReturn(0);
@@ -376,7 +383,9 @@ PetscErrorCode NEPGetBV(NEP nep,BV *bv)
   PetscValidPointer(bv,2);
   if (!nep->V) {
     ierr = BVCreate(PetscObjectComm((PetscObject)nep),&nep->V);CHKERRQ(ierr);
+    ierr = PetscObjectIncrementTabLevel((PetscObject)nep->V,(PetscObject)nep,0);CHKERRQ(ierr);
     ierr = PetscLogObjectParent((PetscObject)nep,(PetscObject)nep->V);CHKERRQ(ierr);
+    ierr = PetscObjectSetOptions((PetscObject)nep->V,((PetscObject)nep)->options);CHKERRQ(ierr);
   }
   *bv = nep->V;
   PetscFunctionReturn(0);
@@ -439,7 +448,9 @@ PetscErrorCode NEPGetRG(NEP nep,RG *rg)
   PetscValidPointer(rg,2);
   if (!nep->rg) {
     ierr = RGCreate(PetscObjectComm((PetscObject)nep),&nep->rg);CHKERRQ(ierr);
+    ierr = PetscObjectIncrementTabLevel((PetscObject)nep->rg,(PetscObject)nep,0);CHKERRQ(ierr);
     ierr = PetscLogObjectParent((PetscObject)nep,(PetscObject)nep->rg);CHKERRQ(ierr);
+    ierr = PetscObjectSetOptions((PetscObject)nep->rg,((PetscObject)nep)->options);CHKERRQ(ierr);
   }
   *rg = nep->rg;
   PetscFunctionReturn(0);
@@ -502,7 +513,9 @@ PetscErrorCode NEPGetDS(NEP nep,DS *ds)
   PetscValidPointer(ds,2);
   if (!nep->ds) {
     ierr = DSCreate(PetscObjectComm((PetscObject)nep),&nep->ds);CHKERRQ(ierr);
+    ierr = PetscObjectIncrementTabLevel((PetscObject)nep->ds,(PetscObject)nep,0);CHKERRQ(ierr);
     ierr = PetscLogObjectParent((PetscObject)nep,(PetscObject)nep->ds);CHKERRQ(ierr);
+    ierr = PetscObjectSetOptions((PetscObject)nep->ds,((PetscObject)nep)->options);CHKERRQ(ierr);
   }
   *ds = nep->ds;
   PetscFunctionReturn(0);
@@ -540,7 +553,9 @@ PetscErrorCode NEPRefineGetKSP(NEP nep,KSP *ksp)
       ierr = PetscLogObjectMemory((PetscObject)nep,sizeof(PetscSubcomm));CHKERRQ(ierr);
     }
     ierr = KSPCreate((nep->npart==1)?PetscObjectComm((PetscObject)nep):PetscSubcommChild(nep->refinesubc),&nep->refineksp);CHKERRQ(ierr);
+    ierr = PetscObjectIncrementTabLevel((PetscObject)nep->refineksp,(PetscObject)nep,0);CHKERRQ(ierr);
     ierr = PetscLogObjectParent((PetscObject)nep,(PetscObject)nep->refineksp);CHKERRQ(ierr);
+    ierr = PetscObjectSetOptions((PetscObject)nep->refineksp,((PetscObject)nep)->options);CHKERRQ(ierr);
     ierr = KSPSetOptionsPrefix(*ksp,((PetscObject)nep)->prefix);CHKERRQ(ierr);
     ierr = KSPAppendOptionsPrefix(*ksp,"nep_refine_");CHKERRQ(ierr);
     ierr = KSPSetTolerances(nep->refineksp,SLEPC_DEFAULT_TOL,PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT);CHKERRQ(ierr);
