@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -56,11 +56,12 @@ PetscErrorCode NEPSetUp(NEP nep)
   if (!((PetscObject)nep)->type_name) {
     ierr = NEPSetType(nep,NEPRII);CHKERRQ(ierr);
   }
-  if (!nep->ds) { ierr = NEPGetDS(nep,&nep->ds);CHKERRQ(ierr); }
+  if (nep->useds && !nep->ds) { ierr = NEPGetDS(nep,&nep->ds);CHKERRQ(ierr); }
   if (!nep->rg) { ierr = NEPGetRG(nep,&nep->rg);CHKERRQ(ierr); }
   if (!((PetscObject)nep->rg)->type_name) {
     ierr = RGSetType(nep->rg,RGINTERVAL);CHKERRQ(ierr);
   }
+  if (nep->twosided && !nep->hasts) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"This solver does not support computing left eigenvectors (no two-sided variant)");
 
   /* set problem dimensions */
   switch (nep->fui) {
@@ -186,13 +187,15 @@ PetscErrorCode NEPSetUp(NEP nep)
   nep->sc->mapobj = NULL;
 
   /* fill sorting criterion for DS */
-  ierr = DSGetSlepcSC(nep->ds,&sc);CHKERRQ(ierr);
-  sc->comparison    = nep->sc->comparison;
-  sc->comparisonctx = nep->sc->comparisonctx;
-  ierr = PetscObjectTypeCompare((PetscObject)nep,NEPNLEIGS,&flg);CHKERRQ(ierr);
-  if (!flg) {
-    sc->map    = NULL;
-    sc->mapobj = NULL;
+  if (nep->useds) {
+    ierr = DSGetSlepcSC(nep->ds,&sc);CHKERRQ(ierr);
+    sc->comparison    = nep->sc->comparison;
+    sc->comparisonctx = nep->sc->comparisonctx;
+    ierr = PetscObjectTypeCompare((PetscObject)nep,NEPNLEIGS,&flg);CHKERRQ(ierr);
+    if (!flg) {
+      sc->map    = NULL;
+      sc->mapobj = NULL;
+    }
   }
   if (nep->nev > nep->ncv) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"nev bigger than ncv");
 
@@ -282,7 +285,7 @@ PetscErrorCode NEPSetDimensions_Default(NEP nep,PetscInt nev,PetscInt *ncv,Petsc
            working basis slightly larger than ncv
 
    Developers Note:
-   This is PETSC_EXTERN because it may be required by user plugin NEP
+   This is SLEPC_EXTERN because it may be required by user plugin NEP
    implementations.
 
    Level: developer
@@ -326,6 +329,12 @@ PetscErrorCode NEPAllocateSolution(NEP nep,PetscInt extra)
   } else {
     ierr = BVResize(nep->V,requested,PETSC_FALSE);CHKERRQ(ierr);
   }
+
+  /* allocate W */
+  if (nep->twosided) {
+    ierr = BVDestroy(&nep->W);CHKERRQ(ierr);
+    ierr = BVDuplicate(nep->V,&nep->W);CHKERRQ(ierr);
+  }
   PetscFunctionReturn(0);
 }
 
