@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -136,20 +136,22 @@ int main(int argc,char **argv)
 /*TEST
 
    testset:
-      args: -st_transform -pep_nev 4 -pep_tol 1e-7 -n 24 -st_type sinvert -terse
+      args: -pep_nev 4 -pep_tol 1e-7 -n 24 -terse
       output_file: output/acoustic_wave_1d_1.out
       requires: !complex !single
       test:
          suffix: 1
-         args: -pep_type {{toar qarnoldi linear}}
+         args: -st_type sinvert -st_transform -pep_type {{toar qarnoldi linear}}
       test:
          suffix: 1_stoar
-         args: -pep_type stoar -pep_hermitian -pep_stoar_locking 0
+         args: -st_type sinvert -st_transform -pep_type stoar -pep_hermitian -pep_stoar_locking 0
       test:
          suffix: 2
-         args: -pep_type toar -pep_extract {{none norm residual}}
+         args: -st_type sinvert -st_transform -pep_type toar -pep_extract {{none norm residual}}
       test:
          suffix: 3
-         args: -pep_type linear -pep_extract {{none norm residual}}
-
+         args: -st_type sinvert -pep_type linear -pep_extract {{none norm residual}}
+      test:
+         suffix: 4
+         args: -pep_type jd
 TEST*/
