@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -155,20 +155,24 @@ int main(int argc,char **argv)
          args: -pep_type qarnoldi -pep_qarnoldi_restart 0.4
 
    testset:
-      args: -n 100 -pep_nev 4 -terse
+      args: -n 24 -pep_nev 4 -pep_ncv 9 -pep_target -.62 -terse 
       output_file: output/sleeper_2.out
       test:
          suffix: 2_toar
-         args: -pep_type toar -pep_toar_restart .35 -pep_ncv 10 -pep_max_it 2000 -st_type sinvert
+         args: -pep_type toar -pep_toar_restart .3 -st_type sinvert
          requires: !single
       test:
          suffix: 2_jd
-         args: -pep_type jd -pep_target -.61
-         requires: complex
+         args: -pep_type jd -pep_jd_restart .3 -pep_jd_projection orthogonal
 
    test:
       suffix: 3
-      args: -n 270 -pep_type stoar -pep_hermitian -st_type sinvert -pep_nev 2 -pep_target -.89 -terse
+      args: -n 275 -pep_type stoar -pep_hermitian -st_type sinvert -pep_nev 2 -pep_target -.89 -terse
       requires: !single
 
+   test:
+      suffix: 4
+      args: -n 270 -pep_type stoar -pep_hermitian -pep_interval -3,-2.51 -st_type sinvert -st_pc_type cholesky -terse
+      requires: !complex !single
+
 TEST*/
