@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -154,8 +154,8 @@ int main(int argc,char **argv)
 
    test:
       suffix: 2
-      args: -pep_type jd -pep_nev 4 -n 24 -pep_ncv 18 -pep_target -50 -terse
-      requires: complex
+      args: -pep_type jd -pep_jd_minimality_index 1 -pep_nev 4 -n 24 -pep_ncv 18 -pep_target -50 -terse
+      requires: !single
 
    test:
       suffix: 3
@@ -172,4 +172,8 @@ int main(int argc,char **argv)
       args: -n 300 -pep_hyperbolic -pep_interval -.506,-.3 -pep_type stoar -st_type sinvert -st_pc_type cholesky -pep_stoar_nev 10 -terse
       requires: !single !complex
 
+   test:
+      suffix: 6
+      args: -n 24 -pep_ncv 18 -pep_target -.5 -terse -pep_type jd -pep_jd_restart .6 -pep_jd_fix .001
+      requires: !single
 TEST*/
