@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -188,7 +188,7 @@ int main(int argc,char **argv)
          requires: !single
       test:
          suffix: 2_jd
-         args: -pep_type jd -st_type precond
+         args: -pep_type jd -st_type precond -pep_max_it 200
          requires: complex
 
    test:
@@ -260,7 +260,7 @@ int main(int argc,char **argv)
 
    testset:
       nsize: 2
-      args: -st_type sinvert -pep_target -0.43 -pep_nev 4 -pep_refine_partitions 2 -st_ksp_type bcgs -st_pc_type bjacobi -pep_scale diagonal -pep_scale_its 4
+      args: -st_type sinvert -pep_target -0.49 -pep_nev 4 -pep_refine_partitions 2 -st_ksp_type bcgs -st_pc_type bjacobi -pep_scale diagonal -pep_scale_its 4
       output_file: output/test2_2.out
       requires: !single
       test:
@@ -286,7 +286,7 @@ int main(int argc,char **argv)
    testset:
       args: -pep_nev 4 -initv -mat_type aijcusparse
       output_file: output/test2_1.out
-      requires: veccuda
+      requires: cuda
       test:
          suffix: 11_cuda
          args: -pep_type {{toar linear}}
@@ -301,6 +301,6 @@ int main(int argc,char **argv)
       suffix: 12
       nsize: 2
       args: -pep_type jd -ds_parallel synchronized -pep_target -0.43 -pep_nev 4 -pep_ncv 20
-      requires: complex
+      requires: !single
 
 TEST*/
