@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -182,5 +182,9 @@ int main(int argc,char **argv)
          suffix: 1_stoar
          args: -pep_type stoar
          requires: !single
+      test:
+         suffix: 1_stoar_t
+         args: -pep_type stoar -st_transform
+         requires: !single
 
 TEST*/
