@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -19,8 +19,8 @@
    References:
 
        [1] C. Campos and J.E. Roman, "Inertia-based spectrum slicing
-           for symmetric quadratic eigenvalue problems", in preparation,
-           2018.
+           for symmetric quadratic eigenvalue problems", submitted,
+           2019.
 */
 
 #include <slepc/private/pepimpl.h>         /*I "slepcpep.h" I*/
@@ -45,7 +45,7 @@ static const char citation[] =
 static PetscErrorCode PEPQSliceResetSR(PEP pep)
 {
   PetscErrorCode ierr;
-  PEP_TOAR       *ctx=(PEP_TOAR*)pep->data;
+  PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
   PEP_SR         sr=ctx->sr;
   PEP_shift      s;
   PetscInt       i;
@@ -75,7 +75,7 @@ static PetscErrorCode PEPQSliceResetSR(PEP pep)
 PetscErrorCode PEPReset_STOAR_QSlice(PEP pep)
 {
   PetscErrorCode ierr;
-  PEP_TOAR       *ctx=(PEP_TOAR*)pep->data;
+  PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
 
   PetscFunctionBegin;
   ierr = PEPQSliceResetSR(pep);CHKERRQ(ierr);
@@ -91,7 +91,7 @@ PetscErrorCode PEPReset_STOAR_QSlice(PEP pep)
 static PetscErrorCode PEPQSliceAllocateSolution(PEP pep)
 {
   PetscErrorCode ierr;
-  PEP_TOAR       *ctx=(PEP_TOAR*)pep->data;
+  PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
   PetscInt       k;
   PetscLogDouble cnt;
   BVType         type;
@@ -136,18 +136,47 @@ static PetscErrorCode ConvergedPositive(EPS eps,PetscScalar eigr,PetscScalar eig
   PetscFunctionReturn(0);
 }
 
+static PetscErrorCode PEPQSliceMatGetInertia(PEP pep,PetscReal shift,PetscInt *inertia,PetscInt *zeros)
+{
+  KSP            ksp,kspr;
+  PC             pc;
+  Mat            F;
+  PetscBool      flg;
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  if (!pep->solvematcoeffs) {
+    ierr = PetscMalloc1(pep->nmat,&pep->solvematcoeffs);CHKERRQ(ierr);
+  }
+  if (shift==PETSC_MAX_REAL) { /* Inertia of matrix A[2] */
+    pep->solvematcoeffs[0] = 0.0; pep->solvematcoeffs[1] = 0.0; pep->solvematcoeffs[2] = 1.0;
+  } else {
+    ierr = PEPEvaluateBasis(pep,shift,0,pep->solvematcoeffs,NULL);CHKERRQ(ierr);
+  }
+  ierr = STSetUp(pep->st);CHKERRQ(ierr);
+  ierr = STMatSetUp(pep->st,pep->sfactor,pep->solvematcoeffs);CHKERRQ(ierr);
+  ierr = STGetKSP(pep->st,&ksp);CHKERRQ(ierr);
+  ierr = KSPGetPC(ksp,&pc);CHKERRQ(ierr);
+  ierr = PetscObjectTypeCompare((PetscObject)pc,PCREDUNDANT,&flg);CHKERRQ(ierr);
+  if (flg) {
+    ierr = PCRedundantGetKSP(pc,&kspr);CHKERRQ(ierr);
+    ierr = KSPGetPC(kspr,&pc);CHKERRQ(ierr);
+  }
+  ierr = PCFactorGetMatrix(pc,&F);CHKERRQ(ierr);
+  ierr = MatGetInertia(F,inertia,zeros,NULL);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 static PetscErrorCode PEPQSliceGetInertia(PEP pep,PetscReal shift,PetscInt *inertia,PetscInt *zeros,PetscInt correction)
 {
   PetscErrorCode ierr;
-  KSP            ksp,kspr;
-  PC             pc;
-  Mat            F,P;
-  PetscBool      flg;
+  KSP            ksp;
+  Mat            P;
   PetscReal      nzshift=0.0;
   PetscScalar    dot;
   PetscRandom    rand;
   PetscInt       nconv;
-  PEP_TOAR       *ctx=(PEP_TOAR*)pep->data;
+  PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
   PEP_SR         sr=ctx->sr;
 
   PetscFunctionBegin;
@@ -161,23 +190,13 @@ static PetscErrorCode PEPQSliceGetInertia(PEP pep,PetscReal shift,PetscInt *iner
        The goal is that the nonzero pattern is the same in all cases and reuse
        the symbolic factorizations */
     nzshift = (shift==0.0)? 10.0/PETSC_MAX_REAL: shift;
+    ierr = PEPQSliceMatGetInertia(pep,nzshift,inertia,zeros);CHKERRQ(ierr);
     ierr = STSetShift(pep->st,nzshift);CHKERRQ(ierr);
-    ierr = PEPEvaluateBasis(pep,nzshift,0,pep->solvematcoeffs,NULL);CHKERRQ(ierr);
-    ierr = STSetUp(pep->st);CHKERRQ(ierr);
-    ierr = STMatSetUp(pep->st,pep->sfactor,pep->solvematcoeffs);CHKERRQ(ierr);
-    ierr = STGetKSP(pep->st,&ksp);CHKERRQ(ierr);
-    ierr = KSPGetPC(ksp,&pc);CHKERRQ(ierr);
-    ierr = PetscObjectTypeCompare((PetscObject)pc,PCREDUNDANT,&flg);CHKERRQ(ierr);
-    if (flg) {
-      ierr = PCRedundantGetKSP(pc,&kspr);CHKERRQ(ierr);
-      ierr = KSPGetPC(kspr,&pc);CHKERRQ(ierr);
-    }
-    ierr = PCFactorGetMatrix(pc,&F);CHKERRQ(ierr);
-    ierr = MatGetInertia(F,inertia,zeros,NULL);CHKERRQ(ierr);
   }
   if (!correction) {
     if (shift >= PETSC_MAX_REAL) *inertia = 2*pep->n;
-    else if (shift>PETSC_MIN_REAL) { 
+    else if (shift>PETSC_MIN_REAL) {
+      ierr = STGetKSP(pep->st,&ksp);CHKERRQ(ierr);
       ierr = KSPGetOperators(ksp,&P,NULL);CHKERRQ(ierr);
       if (*inertia!=pep->n && !sr->v[0]) {
         ierr = MatCreateVecs(P,&sr->v[0],NULL);CHKERRQ(ierr);
@@ -191,13 +210,13 @@ static PetscErrorCode PEPQSliceGetInertia(PEP pep,PetscReal shift,PetscInt *iner
           ierr = EPSCreate(PetscObjectComm((PetscObject)pep),&sr->eps);CHKERRQ(ierr);
           ierr = EPSSetProblemType(sr->eps,EPS_HEP);CHKERRQ(ierr);
           ierr = EPSSetWhichEigenpairs(sr->eps,EPS_LARGEST_REAL);CHKERRQ(ierr);
-          ierr = EPSSetConvergenceTestFunction(sr->eps,ConvergedPositive,NULL,NULL);CHKERRQ(ierr);
         }
+        ierr = EPSSetConvergenceTestFunction(sr->eps,ConvergedPositive,NULL,NULL);CHKERRQ(ierr);
         ierr = EPSSetOperators(sr->eps,P,NULL);CHKERRQ(ierr);
         ierr = EPSSolve(sr->eps);CHKERRQ(ierr);
         ierr = EPSGetConverged(sr->eps,&nconv);CHKERRQ(ierr);
         if (!nconv) SETERRQ1(((PetscObject)pep)->comm,PETSC_ERR_CONV_FAILED,"Inertia computation fails in %g",nzshift);
-        ierr = EPSGetEigenpair(sr->eps,0,NULL,NULL,sr->v[0],sr->v[1]);CHKERRQ(ierr); 
+        ierr = EPSGetEigenpair(sr->eps,0,NULL,NULL,sr->v[0],sr->v[1]);CHKERRQ(ierr);
       }
       if (*inertia!=pep->n) {
         ierr = MatMult(pep->A[1],sr->v[0],sr->v[1]);CHKERRQ(ierr);
@@ -211,6 +230,263 @@ static PetscErrorCode PEPQSliceGetInertia(PEP pep,PetscReal shift,PetscInt *iner
   PetscFunctionReturn(0);
 }
 
+/*
+   Check eigenvalue type - used only in non-hyperbolic problems.
+   All computed eigenvalues must have the same definite type (positive or negative).
+   If ini=TRUE the type is available in omega, otherwise we compute an eigenvalue
+   closest to shift and determine its type.
+ */
+static PetscErrorCode PEPQSliceCheckEigenvalueType(PEP pep,PetscReal shift,PetscReal omega,PetscBool ini)
+{
+  PetscErrorCode ierr;
+  PEP            pep2;
+  ST             st;
+  PetscInt       nconv;
+  PetscScalar    lambda,dot;
+  PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
+  PEP_SR         sr=ctx->sr;
+
+  PetscFunctionBegin;
+  if (!ini) {
+    if (-(omega/(shift*ctx->alpha+ctx->beta))*sr->type<0) SETERRQ1(((PetscObject)pep)->comm,PETSC_ERR_CONV_FAILED,"Different positive/negative type detected in eigenvalue %g",(double)shift);
+  } else {
+    ierr = PEPCreate(PetscObjectComm((PetscObject)pep),&pep2);CHKERRQ(ierr);
+    ierr = PEPSetOptionsPrefix(pep2,((PetscObject)pep)->prefix);CHKERRQ(ierr);
+    ierr = PEPAppendOptionsPrefix(pep2,"pep_eigenvalue_type_");CHKERRQ(ierr);
+    ierr = PEPSetTolerances(pep2,PETSC_DEFAULT,pep->max_it/4);CHKERRQ(ierr);
+    ierr = PEPSetType(pep2,PEPTOAR);CHKERRQ(ierr);
+    ierr = PEPSetOperators(pep2,pep->nmat,pep->A);CHKERRQ(ierr);
+    ierr = PEPSetWhichEigenpairs(pep2,PEP_TARGET_MAGNITUDE);CHKERRQ(ierr);
+    ierr = PEPGetRG(pep2,&pep2->rg);CHKERRQ(ierr);
+    ierr = RGSetType(pep2->rg,RGINTERVAL);
+#if defined(PETSC_USE_COMPLEX)
+    ierr = RGIntervalSetEndpoints(pep2->rg,pep->inta,pep->intb,-PETSC_SQRT_MACHINE_EPSILON,PETSC_SQRT_MACHINE_EPSILON);CHKERRQ(ierr);
+#else
+    ierr = RGIntervalSetEndpoints(pep2->rg,pep->inta,pep->intb,0.0,0.0);CHKERRQ(ierr);
+#endif
+    pep2->target = shift;
+    st = pep2->st;
+    pep2->st = pep->st;
+    ierr = PEPSolve(pep2);CHKERRQ(ierr);
+    ierr = PEPGetConverged(pep2,&nconv);CHKERRQ(ierr);
+    if (nconv) {
+      ierr = PEPGetEigenpair(pep2,0,&lambda,NULL,pep2->work[0],NULL);CHKERRQ(ierr);
+      ierr = MatMult(pep->A[1],pep2->work[0],pep2->work[1]);CHKERRQ(ierr);
+      ierr = MatMult(pep->A[2],pep2->work[0],pep2->work[2]);CHKERRQ(ierr);
+      ierr = VecAXPY(pep2->work[1],2.0*lambda*pep->sfactor,pep2->work[2]);CHKERRQ(ierr);
+      ierr = VecDot(pep2->work[1],pep2->work[0],&dot);CHKERRQ(ierr);
+      ierr = PetscInfo2(pep,"lambda=%g, %s type\n",(double)PetscRealPart(lambda),(PetscRealPart(dot)>0.0)?"positive":"negative");CHKERRQ(ierr);
+      if (!sr->type) sr->type = (PetscRealPart(dot)>0.0)?1:-1;
+      else {
+        if (sr->type*PetscRealPart(dot)<0.0) SETERRQ1(((PetscObject)pep)->comm,PETSC_ERR_CONV_FAILED,"Different positive/negative type detected in eigenvalue %g",(double)PetscRealPart(lambda));
+      }
+    }
+    pep2->st = st;
+    ierr = PEPDestroy(&pep2);CHKERRQ(ierr);
+  }
+  PetscFunctionReturn(0);
+}
+
+PETSC_STATIC_INLINE PetscErrorCode PEPQSliceDiscriminant(PEP pep,Vec u,Vec w,PetscReal *d,PetscReal *smas,PetscReal *smenos)
+{
+  PetscReal      ap,bp,cp;
+  PetscScalar    ts;
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  ierr = MatMult(pep->A[0],u,w);CHKERRQ(ierr);
+  ierr = VecDot(w,u,&ts);CHKERRQ(ierr);
+  cp = PetscRealPart(ts);
+  ierr = MatMult(pep->A[1],u,w);CHKERRQ(ierr);
+  ierr = VecDot(w,u,&ts);CHKERRQ(ierr);
+  bp = PetscRealPart(ts);
+  ierr = MatMult(pep->A[2],u,w);CHKERRQ(ierr);
+  ierr = VecDot(w,u,&ts);CHKERRQ(ierr);
+  ap = PetscRealPart(ts);
+  if (d) *d = bp*bp-4*ap*cp;
+  if (*d>=0.0 && smas) {
+    if (ap>0) *smas = (-bp+PetscSqrtReal(*d))/(2*ap);
+    else if (ap<0) *smas = (-bp-PetscSqrtReal(*d))/(2*ap);
+    else {
+      if (bp >0) *smas = -cp/bp;
+      else *smas = PETSC_MAX_REAL;
+    }
+  }
+  if (*d>=0.0 && smenos) {
+    if (ap>0) *smenos = (-bp-PetscSqrtReal(*d))/(2*ap);
+    else if (ap<0) *smenos = (-bp+PetscSqrtReal(*d))/(2*ap);
+    else {
+      if (bp<0) *smenos = -cp/bp;
+      else *smenos = PETSC_MAX_REAL;
+    }
+  }
+  PetscFunctionReturn(0);
+}
+
+PETSC_STATIC_INLINE PetscErrorCode PEPQSliceEvaluateQEP(PEP pep,PetscScalar x,Mat M,MatStructure str)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  ierr = MatCopy(pep->A[0],M,SAME_NONZERO_PATTERN);CHKERRQ(ierr);
+  ierr = MatAXPY(M,x,pep->A[1],str);CHKERRQ(ierr);
+  ierr = MatAXPY(M,x*x,pep->A[2],str);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+/*@
+   PEPCheckDefiniteQEP - Determines if a symmetric/Hermitian quadratic eigenvalue problem
+   is definite or not.
+
+   Logically Collective on PEP
+
+   Input Parameter:
+.  pep  - eigensolver context
+
+   Output Parameters:
++  xi - first computed parameter
+.  mu - second computed parameter
+.  definite - flag indicating that the problem is definite
+-  hyperbolic - flag indicating that the problem is hyperbolic
+
+   Notes:
+   This function is intended for quadratic eigenvalue problems, Q(lambda)=A*lambda^2+B*lambda+C,
+   with symmetric (or Hermitian) coefficient matrices A,B,C.
+
+   On output, the flag 'definite' may have the values -1 (meaning that the QEP is not
+   definite), 1 (if the problem is definite), or 0 if the algorithm was not able to
+   determine whether the problem is definite or not.
+
+   If definite=1, the output flag 'hyperbolic' informs in a similar way about whether the
+   problem is hyperbolic or not.
+
+   If definite=1, the computed values xi and mu satisfy Q(xi)<0 and Q(mu)>0, as
+   obtained via the method proposed in [Niendorf and Voss, LAA 2010]. Furthermore, if
+   hyperbolic=1 then only xi is computed.
+
+   Level: advanced
+@*/
+PetscErrorCode PEPCheckDefiniteQEP(PEP pep,PetscReal *xi,PetscReal *mu,PetscInt *definite,PetscInt *hyperbolic)
+{
+  PetscErrorCode ierr;
+  PetscRandom    rand;
+  Vec            u,w;
+  PetscReal      d,s,sp,mut=0.0,omg,omgp;
+  PetscInt       k,its=10,hyp=0,check=0,nconv,inertia,n;
+  Mat            M=NULL;
+  MatStructure   str;
+  EPS            eps;
+  PetscBool      transform,ptypehyp;
+
+  PetscFunctionBegin;
+  if (pep->problem_type!=PEP_HERMITIAN && pep->problem_type!=PEP_HYPERBOLIC) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"Only available for Hermitian (or hyperbolic) problems");
+  ptypehyp = (pep->problem_type==PEP_HYPERBOLIC)? PETSC_TRUE: PETSC_FALSE;
+  if (!pep->st) { ierr = PEPGetST(pep,&pep->st);CHKERRQ(ierr); }
+  ierr = PEPSetDefaultST(pep);CHKERRQ(ierr);
+  ierr = STSetMatrices(pep->st,pep->nmat,pep->A);CHKERRQ(ierr);
+  ierr = MatGetSize(pep->A[0],&n,NULL);CHKERRQ(ierr);
+  ierr = STGetTransform(pep->st,&transform);CHKERRQ(ierr);
+  ierr = STSetTransform(pep->st,PETSC_FALSE);CHKERRQ(ierr);
+  ierr = STSetUp(pep->st);CHKERRQ(ierr);
+  ierr = MatCreateVecs(pep->A[0],&u,&w);CHKERRQ(ierr);
+  ierr = PEPGetBV(pep,&pep->V);CHKERRQ(ierr);
+  ierr = BVGetRandomContext(pep->V,&rand);CHKERRQ(ierr);
+  ierr = VecSetRandom(u,rand);CHKERRQ(ierr);
+  ierr = VecNormalize(u,NULL);CHKERRQ(ierr);
+  ierr = PEPQSliceDiscriminant(pep,u,w,&d,&s,NULL);CHKERRQ(ierr);
+  if (d<0.0) check = -1;
+  if (!check) {
+    ierr = EPSCreate(PetscObjectComm((PetscObject)pep),&eps);CHKERRQ(ierr);
+    ierr = EPSSetProblemType(eps,EPS_HEP);CHKERRQ(ierr);
+    ierr = EPSSetWhichEigenpairs(eps,EPS_LARGEST_REAL);CHKERRQ(ierr);
+    ierr = EPSSetTolerances(eps,PetscSqrtReal(PETSC_SQRT_MACHINE_EPSILON),PETSC_DECIDE);
+    ierr = MatDuplicate(pep->A[0],MAT_DO_NOT_COPY_VALUES,&M);CHKERRQ(ierr);
+    ierr = STGetMatStructure(pep->st,&str);CHKERRQ(ierr);
+  }
+  for (k=0;k<its&&!check;k++) {
+    ierr = PEPQSliceEvaluateQEP(pep,s,M,str);CHKERRQ(ierr);
+    ierr = EPSSetOperators(eps,M,NULL);CHKERRQ(ierr);
+    ierr = EPSSolve(eps);CHKERRQ(ierr);
+    ierr = EPSGetConverged(eps,&nconv);CHKERRQ(ierr);
+    if (!nconv) break;
+    ierr = EPSGetEigenpair(eps,0,NULL,NULL,u,w);CHKERRQ(ierr);
+    sp = s;
+    ierr = PEPQSliceDiscriminant(pep,u,w,&d,&s,&omg);CHKERRQ(ierr);
+    if (d<0.0) {check = -1; break;}
+    if (PetscAbsReal((s-sp)/s)<100*PETSC_MACHINE_EPSILON) break;
+    if (s>sp) {hyp = -1;}
+    mut = 2*s-sp;
+    ierr =  PEPQSliceMatGetInertia(pep,mut,&inertia,NULL);CHKERRQ(ierr);
+    if (inertia == n) {check = 1; break;}
+  }
+  for (;k<its&&!check;k++) {
+    mut = (s-omg)/2;
+    ierr =  PEPQSliceMatGetInertia(pep,mut,&inertia,NULL);CHKERRQ(ierr);
+    if (inertia == n) {check = 1; break;}
+    if (PetscAbsReal((s-omg)/omg)<100*PETSC_MACHINE_EPSILON) break;
+    ierr = PEPQSliceEvaluateQEP(pep,omg,M,str);CHKERRQ(ierr);
+    ierr = EPSSetOperators(eps,M,NULL);CHKERRQ(ierr);
+    ierr = EPSSolve(eps);CHKERRQ(ierr);
+    ierr = EPSGetConverged(eps,&nconv);CHKERRQ(ierr);
+    if (!nconv) break;
+    ierr = EPSGetEigenpair(eps,0,NULL,NULL,u,w);CHKERRQ(ierr);
+    omgp = omg;
+    ierr = PEPQSliceDiscriminant(pep,u,w,&d,NULL,&omg);CHKERRQ(ierr);
+    if (d<0.0) {check = -1; break;}
+    if (omg<omgp) {hyp = -1;}
+  }
+  if (check==1) *xi = mut;
+  if (hyp==-1 && ptypehyp) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Problem does not satisfy hyperbolic test; consider removing the hyperbolicity flag");
+  if (check==1 && hyp==0) {
+    ierr =  PEPQSliceMatGetInertia(pep,PETSC_MAX_REAL,&inertia,NULL);CHKERRQ(ierr);
+    if (inertia == 0) hyp = 1;
+    else hyp = -1;
+  }
+  if (check==1 && hyp!=1) {
+    check = 0;
+    ierr = EPSSetWhichEigenpairs(eps,EPS_SMALLEST_REAL);CHKERRQ(ierr);
+    for (;k<its&&!check;k++) {
+      ierr = PEPQSliceEvaluateQEP(pep,s,M,str);CHKERRQ(ierr);
+      ierr = EPSSetOperators(eps,M,NULL);CHKERRQ(ierr);
+      ierr = EPSSolve(eps);CHKERRQ(ierr);
+      ierr = EPSGetConverged(eps,&nconv);CHKERRQ(ierr);
+      if (!nconv) break;
+      ierr = EPSGetEigenpair(eps,0,NULL,NULL,u,w);CHKERRQ(ierr);
+      sp = s;
+      ierr = PEPQSliceDiscriminant(pep,u,w,&d,&s,&omg);CHKERRQ(ierr);
+      if (d<0.0) {check = -1; break;}
+      if (PetscAbsReal((s-sp)/s)<100*PETSC_MACHINE_EPSILON) break;
+      mut = 2*s-sp;
+      ierr =  PEPQSliceMatGetInertia(pep,mut,&inertia,NULL);CHKERRQ(ierr);
+      if (inertia == 0) {check = 1; break;}
+    }
+    for (;k<its&&!check;k++) {
+      mut = (s-omg)/2;
+      ierr =  PEPQSliceMatGetInertia(pep,mut,&inertia,NULL);CHKERRQ(ierr);
+      if (inertia == 0) {check = 1; break;}
+      if (PetscAbsReal((s-omg)/omg)<100*PETSC_MACHINE_EPSILON) break;
+      ierr = PEPQSliceEvaluateQEP(pep,omg,M,str);CHKERRQ(ierr);
+      ierr = EPSSetOperators(eps,M,NULL);CHKERRQ(ierr);
+      ierr = EPSSolve(eps);CHKERRQ(ierr);
+      ierr = EPSGetConverged(eps,&nconv);CHKERRQ(ierr);
+      if (!nconv) break;
+      ierr = EPSGetEigenpair(eps,0,NULL,NULL,u,w);CHKERRQ(ierr);
+      omgp = omg;
+      ierr = PEPQSliceDiscriminant(pep,u,w,&d,NULL,&omg);CHKERRQ(ierr);
+      if (d<0.0) {check = -1; break;}
+    }
+  }
+  if (check==1) *mu = mut;
+  *definite = check;
+  *hyperbolic = hyp;
+  if (M) { ierr = MatDestroy(&M);CHKERRQ(ierr); }
+  ierr = VecDestroy(&u);CHKERRQ(ierr);
+  ierr = VecDestroy(&w);CHKERRQ(ierr);
+  ierr = EPSDestroy(&eps);CHKERRQ(ierr);
+  ierr = STSetTransform(pep->st,transform);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 /*
    Dummy backtransform operation
  */
@@ -223,7 +499,7 @@ static PetscErrorCode PEPBackTransform_Skip(PEP pep)
 PetscErrorCode PEPSetUp_STOAR_QSlice(PEP pep)
 {
   PetscErrorCode ierr;
-  PEP_TOAR       *ctx=(PEP_TOAR*)pep->data;
+  PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
   PEP_SR         sr;
   PetscInt       ld,i,zeros=0;
   SlepcSC        sc;
@@ -235,9 +511,10 @@ PetscErrorCode PEPSetUp_STOAR_QSlice(PEP pep)
   ierr = PetscObjectTypeCompareAny((PetscObject)pep->st,&issinv,STSINVERT,STCAYLEY,"");CHKERRQ(ierr);
   if (!issinv) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"Shift-and-invert or Cayley ST is needed for spectrum slicing");
   if (pep->tol==PETSC_DEFAULT) pep->tol = SLEPC_DEFAULT_TOL*1e-2;  /* use tighter tolerance */
-  if (ctx->nev==0) ctx->nev = PetscMin(20,pep->n);  /* nev not set, use default value */
+  if (ctx->nev==1) ctx->nev = PetscMin(20,pep->n);  /* nev not set, use default value */
   if (pep->n>10 && ctx->nev<10) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_WRONG,"nev cannot be less than 10 in spectrum slicing runs");
   pep->ops->backtransform = PEPBackTransform_Skip;
+  if (!pep->max_it) pep->max_it = 100;
 
   /* create spectrum slicing context and initialize it */
   ierr = PEPQSliceResetSR(pep);CHKERRQ(ierr);
@@ -246,6 +523,15 @@ PetscErrorCode PEPSetUp_STOAR_QSlice(PEP pep)
   sr->itsKs = 0;
   sr->nleap = 0;
   sr->sPres = NULL;
+
+  if (pep->solvematcoeffs) { ierr = PetscFree(pep->solvematcoeffs);CHKERRQ(ierr); }
+  ierr = PetscMalloc1(pep->nmat,&pep->solvematcoeffs);CHKERRQ(ierr);
+  if (!pep->st) { ierr = PEPGetST(pep,&pep->st);CHKERRQ(ierr); }
+  ierr = STSetTransform(pep->st,PETSC_FALSE);CHKERRQ(ierr);
+  ierr = STSetUp(pep->st);CHKERRQ(ierr);
+
+  ctx->hyperbolic = (pep->problem_type==PEP_HYPERBOLIC)? PETSC_TRUE: PETSC_FALSE;
+
   /* check presence of ends and finding direction */
   if (pep->inta > PETSC_MIN_REAL || pep->intb >= PETSC_MAX_REAL) {
     sr->int0 = pep->inta;
@@ -261,20 +547,20 @@ PetscErrorCode PEPSetUp_STOAR_QSlice(PEP pep)
     sr->hasEnd = PetscNot(pep->inta <= PETSC_MIN_REAL);
   }
 
-  ierr = PetscMalloc1(pep->nmat,&pep->solvematcoeffs);CHKERRQ(ierr);
-  if (!pep->st) {ierr = PEPGetST(pep,&pep->st);CHKERRQ(ierr);}
-  ierr = STSetTransform(pep->st,PETSC_FALSE);CHKERRQ(ierr);
-  ierr = STSetUp(pep->st);CHKERRQ(ierr);
-
   /* compute inertia0 */
-  ctx->hyperbolic = (pep->problem_type==PEP_HYPERBOLIC)? PETSC_TRUE: PETSC_FALSE;
   ierr = PEPQSliceGetInertia(pep,sr->int0,&sr->inertia0,ctx->detect?&zeros:NULL,ctx->hyperbolic?0:1);CHKERRQ(ierr);
   if (zeros && (sr->int0==pep->inta || sr->int0==pep->intb)) SETERRQ(((PetscObject)pep)->comm,PETSC_ERR_USER,"Found singular matrix for the transformed problem in the interval endpoint");
+  if (!ctx->hyperbolic && ctx->checket) {
+    ierr = PEPQSliceCheckEigenvalueType(pep,sr->int0,0.0,PETSC_TRUE);CHKERRQ(ierr);
+  }
 
   /* compute inertia1 */
   ierr = PEPQSliceGetInertia(pep,sr->int1,&sr->inertia1,ctx->detect?&zeros:NULL,ctx->hyperbolic?0:1);CHKERRQ(ierr);
   if (zeros) SETERRQ(((PetscObject)pep)->comm,PETSC_ERR_USER,"Found singular matrix for the transformed problem in an interval endpoint defined by user");
-  if (!ctx->hyperbolic) {
+  if (!ctx->hyperbolic && ctx->checket && sr->hasEnd) {
+    ierr = PEPQSliceCheckEigenvalueType(pep,sr->int1,0.0,PETSC_TRUE);CHKERRQ(ierr);
+    if (!sr->type && (sr->inertia1-sr->inertia0)) SETERRQ(((PetscObject)pep)->comm,PETSC_ERR_CONV_FAILED,"No information of eigenvalue type in Interval");
+    if (sr->type && !(sr->inertia1-sr->inertia0)) SETERRQ(((PetscObject)pep)->comm,PETSC_ERR_CONV_FAILED,"Different positive/negative type detected");
     if (sr->dir*(sr->inertia1-sr->inertia0)<0) {
       sr->intcorr = -1;
       sr->inertia0 = 2*pep->n-sr->inertia0;
@@ -284,7 +570,7 @@ PetscErrorCode PEPSetUp_STOAR_QSlice(PEP pep)
     if (sr->inertia0<=pep->n && sr->inertia1<=pep->n) sr->intcorr = 1;
     else if (sr->inertia0>=pep->n && sr->inertia1>=pep->n) sr->intcorr = -1;
   }
-  
+
   if (sr->hasEnd) {
     sr->dir = -sr->dir; r = sr->int0; sr->int0 = sr->int1; sr->int1 = r;
     i = sr->inertia0; sr->inertia0 = sr->inertia1; sr->inertia1 = i;
@@ -297,7 +583,6 @@ PetscErrorCode PEPSetUp_STOAR_QSlice(PEP pep)
     ierr = PEPQSliceAllocateSolution(pep);CHKERRQ(ierr);
     ierr = PEPSetDimensions_Default(pep,ctx->nev,&ctx->ncv,&ctx->mpd);CHKERRQ(ierr);
     pep->nev = ctx->nev; pep->ncv = ctx->ncv; pep->mpd = ctx->mpd;
-    if (!pep->max_it) pep->max_it = 100;
     ld   = ctx->ncv+2;
     ierr = DSSetType(pep->ds,DSGHIEP);CHKERRQ(ierr);
     ierr = DSSetCompact(pep->ds,PETSC_TRUE);CHKERRQ(ierr);
@@ -321,7 +606,7 @@ static PetscErrorCode PEPCreateShift(PEP pep,PetscReal val,PEP_shift neighb0,PEP
   PEP_shift      s,*pending2;
   PetscInt       i;
   PEP_SR         sr;
-  PEP_TOAR       *ctx=(PEP_TOAR*)pep->data;
+  PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
 
   PetscFunctionBegin;
   sr = ctx->sr;
@@ -356,7 +641,7 @@ static PetscErrorCode PEPExtractShift(PEP pep)
 {
   PetscErrorCode ierr;
   PetscInt       iner,zeros=0;
-  PEP_TOAR       *ctx=(PEP_TOAR*)pep->data;
+  PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
   PEP_SR         sr;
   PetscReal      newShift,aux;
   PEP_shift      sPres;
@@ -408,7 +693,7 @@ static PetscErrorCode PEPGetNewShiftValue(PEP pep,PetscInt side,PetscReal *newS)
   PetscInt  i,idxP;
   PEP_SR    sr;
   PEP_shift sPres,s;
-  PEP_TOAR  *ctx=(PEP_TOAR*)pep->data;
+  PEP_STOAR *ctx=(PEP_STOAR*)pep->data;
 
   PetscFunctionBegin;
   sr = ctx->sr;
@@ -507,16 +792,16 @@ static PetscErrorCode sortRealEigenvalues(PetscScalar *r,PetscInt *perm,PetscInt
 static PetscErrorCode PEPStoreEigenpairs(PEP pep)
 {
   PetscErrorCode ierr;
-  PEP_TOAR       *ctx=(PEP_TOAR*)pep->data;
+  PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
   PetscReal      lambda,err,*errest;
   PetscInt       i,*aux,count=0,ndef,ld,nconv=pep->nconv,d=pep->nmat-1,idx;
   PetscBool      iscayley,divide=PETSC_FALSE;
   PEP_SR         sr = ctx->sr;
   PEP_shift      sPres;
-  Vec            w;
+  Vec            w,vomega;
   Mat            MS;
   BV             tV;
-  PetscScalar    *S,*eigr,*tS;
+  PetscScalar    *S,*eigr,*tS,*omega;
 
   PetscFunctionBegin;
   sPres = sr->sPres;
@@ -535,6 +820,9 @@ static PetscErrorCode PEPStoreEigenpairs(PEP pep)
     ierr = PetscObjectTypeCompare((PetscObject)pep->st,STCAYLEY,&iscayley);CHKERRQ(ierr);
     /* Sort eigenvalues */
     ierr = sortRealEigenvalues(pep->eigr,pep->perm,nconv,PETSC_FALSE,sr->dir);CHKERRQ(ierr);
+    ierr = VecCreateSeq(PETSC_COMM_SELF,nconv,&vomega);CHKERRQ(ierr);
+    ierr = BVGetSignature(ctx->V,vomega);CHKERRQ(ierr);
+    ierr = VecGetArray(vomega,&omega);CHKERRQ(ierr);
     ierr = BVGetSizes(pep->V,NULL,NULL,&ld);CHKERRQ(ierr);
     ierr = BVTensorGetFactors(ctx->V,NULL,&MS);CHKERRQ(ierr);
     ierr = MatDenseGetArray(MS,&S);CHKERRQ(ierr);
@@ -546,6 +834,7 @@ static PetscErrorCode PEPStoreEigenpairs(PEP pep)
       err = pep->errest[pep->perm[i]];
       if ((sr->dir)*(lambda - sPres->ext[0]) > 0 && (sr->dir)*(sPres->ext[1] - lambda) > 0) {/* Valid value */
         if (sr->indexEig+count-ndef>=sr->numEigs) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Unexpected error in Spectrum Slicing");
+        ierr = PEPQSliceCheckEigenvalueType(pep,lambda,PetscRealPart(omega[pep->perm[i]]),PETSC_FALSE);CHKERRQ(ierr);
         eigr[count] = lambda;
         errest[count] = err;
         if (((sr->dir)*(sPres->value - lambda) > 0) && ((sr->dir)*(lambda - sPres->ext[0]) > 0)) sPres->nconv[0]++;
@@ -555,6 +844,8 @@ static PetscErrorCode PEPStoreEigenpairs(PEP pep)
         count++;
       }
     }
+    ierr = VecRestoreArray(vomega,&omega);CHKERRQ(ierr);
+    ierr = VecDestroy(&vomega);CHKERRQ(ierr);
     for (i=0;i<count;i++) {
       ierr = PetscMemcpy(S+i*(d*ld),tS+i*nconv*d,nconv*sizeof(PetscScalar));CHKERRQ(ierr);
       ierr = PetscMemcpy(S+i*(d*ld)+ld,tS+i*nconv*d+nconv,nconv*sizeof(PetscScalar));CHKERRQ(ierr);
@@ -605,7 +896,7 @@ static PetscErrorCode PEPStoreEigenpairs(PEP pep)
       ierr = MatDenseRestoreArray(MS,&S);CHKERRQ(ierr);
       ierr = BVTensorRestoreFactors(ctx->V,NULL,&MS);CHKERRQ(ierr);
     }
-  
+
     if (sr->sPres->nconv[1]) {
       if (divide) {
         ierr = BVTensorGetFactors(ctx->V,NULL,&MS);CHKERRQ(ierr);
@@ -658,7 +949,7 @@ static PetscErrorCode PEPStoreEigenpairs(PEP pep)
   /* Check for completion */
   sPres->comp[0] = PetscNot(sPres->nconv[0] < sPres->nsch[0]);
   sPres->comp[1] = PetscNot(sPres->nconv[1] < sPres->nsch[1]);
-  if (sPres->nconv[0] > sPres->nsch[0] || sPres->nconv[1] > sPres->nsch[1]) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Mismatch between number of values found and information from inertia, consider using PEPKrylovSchurSetDetectZeros()");
+  if (sPres->nconv[0] > sPres->nsch[0] || sPres->nconv[1] > sPres->nsch[1]) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Mismatch between number of values found and information from inertia");
   if (divide) { ierr = BVDestroy(&tV);CHKERRQ(ierr); }
   PetscFunctionReturn(0);
 }
@@ -670,7 +961,7 @@ static PetscErrorCode PEPLookForDeflation(PEP pep)
   PEP_shift sPres;
   PetscInt  ini,fin;
   PEP_SR    sr;
-  PEP_TOAR  *ctx=(PEP_TOAR*)pep->data;
+  PEP_STOAR *ctx=(PEP_STOAR*)pep->data;
 
   PetscFunctionBegin;
   sr = ctx->sr;
@@ -698,12 +989,12 @@ static PetscErrorCode PEPLookForDeflation(PEP pep)
   /* The number of values on each side are found */
   if (sPres->neighb[0]) {
     sPres->nsch[0] = (sr->dir)*(sPres->inertia - sPres->neighb[0]->inertia)-count0;
-    if (sPres->nsch[0]<0) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Mismatch between number of values found and information from inertia, consider using PEPSTOARSetDetectZeros()");
+    if (sPres->nsch[0]<0) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Mismatch between number of values found and information from inertia");
   } else sPres->nsch[0] = 0;
 
   if (sPres->neighb[1]) {
     sPres->nsch[1] = (sr->dir)*(sPres->neighb[1]->inertia - sPres->inertia) - count1;
-    if (sPres->nsch[1]<0) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Mismatch between number of values found and information from inertia, consider using PEPSTOARSetDetectZeros()");
+    if (sPres->nsch[1]<0) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Mismatch between number of values found and information from inertia");
   } else sPres->nsch[1] = (sr->dir)*(sr->inertia1 - sPres->inertia);
 
   /* Completing vector of indexes for deflation */
@@ -720,9 +1011,9 @@ static PetscErrorCode PEPLookForDeflation(PEP pep)
 static PetscErrorCode PEPSTOARrun_QSlice(PEP pep,PetscReal *a,PetscReal *b,PetscReal *omega,PetscInt k,PetscInt *M,PetscBool *breakdown,PetscBool *symmlost,Vec *t_)
 {
   PetscErrorCode ierr;
-  PEP_TOAR       *ctx = (PEP_TOAR*)pep->data;
+  PEP_STOAR      *ctx = (PEP_STOAR*)pep->data;
   PetscInt       i,j,m=*M,l,lock;
-  PetscInt       lds,d,ld,offq,nqt;
+  PetscInt       lds,d,ld,offq,nqt,ldds;
   Vec            v=t_[0],t=t_[1],q=t_[2];
   PetscReal      norm,sym=0.0,fro=0.0,*f;
   PetscScalar    *y,*S,sigma;
@@ -737,6 +1028,7 @@ static PetscErrorCode PEPSTOARrun_QSlice(PEP pep,PetscReal *a,PetscReal *b,Petsc
   ierr = BVGetActiveColumns(pep->V,&lock,&nqt);CHKERRQ(ierr);
   lds = d*ld;
   offq = ld;
+  ierr = DSGetLeadingDimension(pep->ds,&ldds);CHKERRQ(ierr);
 
   *breakdown = PETSC_FALSE; /* ----- */
   ierr = STGetShift(pep->st,&sigma);CHKERRQ(ierr);
@@ -782,7 +1074,7 @@ static PetscErrorCode PEPSTOARrun_QSlice(PEP pep,PetscReal *a,PetscReal *b,Petsc
     /* check symmetry */
     ierr = DSGetArrayReal(pep->ds,DS_MAT_T,&f);CHKERRQ(ierr);
     if (j==k) {
-      for (i=l;i<j-1;i++) y[i] = PetscAbsScalar(y[i])-PetscAbsReal(f[2*ld+i]);
+      for (i=l;i<j-1;i++) y[i] = PetscAbsScalar(y[i])-PetscAbsReal(f[2*ldds+i]);
       for (i=0;i<l;i++) y[i] = 0.0;
     }
     ierr = DSRestoreArrayReal(pep->ds,DS_MAT_T,&f);CHKERRQ(ierr);
@@ -806,7 +1098,7 @@ static PetscErrorCode PEPSTOARrun_QSlice(PEP pep,PetscReal *a,PetscReal *b,Petsc
 static PetscErrorCode PEPSTOAR_QSlice(PEP pep,Mat B)
 {
   PetscErrorCode ierr;
-  PEP_TOAR       *ctx = (PEP_TOAR*)pep->data;
+  PEP_STOAR      *ctx = (PEP_STOAR*)pep->data;
   PetscInt       j,k,l,nv=0,ld,ldds,t,nq=0,idx;
   PetscInt       nconv=0,deg=pep->nmat-1,count0=0,count1=0;
   PetscScalar    *Q,*om,sigma,*back,*S,*pQ;
@@ -944,7 +1236,7 @@ static PetscErrorCode PEPSTOAR_QSlice(PEP pep,Mat B)
     if (symmlost && nv==pep->nconv+l) {
       pep->reason = PEP_DIVERGED_SYMMETRY_LOST;
       pep->nconv = nconv;
-      ierr = PetscInfo2(pep,"Symmetry lost in STOAR sigma=%g nconv=%D)\n",(double)sr->sPres->value,nconv);CHKERRQ(ierr);
+      ierr = PetscInfo2(pep,"Symmetry lost in STOAR sigma=%g nconv=%D\n",(double)sr->sPres->value,nconv);CHKERRQ(ierr);
       if (falselock || !ctx->lock) {
         ierr = BVSetActiveColumns(ctx->V,0,pep->nconv);CHKERRQ(ierr);
         ierr = BVTensorCompress(ctx->V,0);CHKERRQ(ierr);
@@ -1080,7 +1372,7 @@ static PetscErrorCode PEPSTOAR_QSlice(PEP pep,Mat B)
 static PetscErrorCode PEPQSliceGetInertias(PEP pep,PetscInt *n,PetscReal **shifts,PetscInt **inertias)
 {
   PetscErrorCode  ierr;
-  PEP_TOAR       *ctx=(PEP_TOAR*)pep->data;
+  PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
   PEP_SR          sr=ctx->sr;
   PetscInt        i=0,j,tmpi;
   PetscReal       v,tmpr;
@@ -1137,7 +1429,7 @@ PetscErrorCode PEPSolve_STOAR_QSlice(PEP pep)
   PetscErrorCode ierr;
   PetscInt       i,j,ti,deg=pep->nmat-1;
   PetscReal      newS;
-  PEP_TOAR       *ctx=(PEP_TOAR*)pep->data;
+  PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
   PEP_SR         sr=ctx->sr;
   Mat            S,B;
   PetscScalar    *pS;
