@@ -1,30 +1,18 @@
 /*
-     This file contains some simple default routines for common PEP operations.
-
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2015, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
-
-   SLEPc is free software: you can redistribute it and/or modify it under  the
-   terms of version 3 of the GNU Lesser General Public License as published by
-   the Free Software Foundation.
-
-   SLEPc  is  distributed in the hope that it will be useful, but WITHOUT  ANY
-   WARRANTY;  without even the implied warranty of MERCHANTABILITY or  FITNESS
-   FOR  A  PARTICULAR PURPOSE. See the GNU Lesser General Public  License  for
-   more details.
-
-   You  should have received a copy of the GNU Lesser General  Public  License
-   along with SLEPc. If not, see <http://www.gnu.org/licenses/>.
+   SLEPc is distributed under a 2-clause BSD license (see LICENSE).
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
+/*
+   Simple default routines for common PEP operations
+*/
 
 #include <slepc/private/pepimpl.h>     /*I "slepcpep.h" I*/
 
-#undef __FUNCT__
-#define __FUNCT__ "PEPSetWorkVecs"
 /*@
    PEPSetWorkVecs - Sets a number of work vectors into a PEP object.
 
@@ -35,7 +23,7 @@
 -  nw  - number of work vectors to allocate
 
    Developers Note:
-   This is PETSC_EXTERN because it may be required by user plugin PEP
+   This is SLEPC_EXTERN because it may be required by user plugin PEP
    implementations.
 
    Level: developer
@@ -57,12 +45,10 @@ PetscErrorCode PEPSetWorkVecs(PEP pep,PetscInt nw)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "PEPConvergedEigRelative"
 /*
-  PEPConvergedEigRelative - Checks convergence relative to the eigenvalue.
+  PEPConvergedRelative - Checks convergence relative to the eigenvalue.
 */
-PetscErrorCode PEPConvergedEigRelative(PEP pep,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx)
+PetscErrorCode PEPConvergedRelative(PEP pep,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx)
 {
   PetscReal w;
 
@@ -72,30 +58,6 @@ PetscErrorCode PEPConvergedEigRelative(PEP pep,PetscScalar eigr,PetscScalar eigi
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "PEPConvergedLinear"
-/*
-  PEPConvergedLinear - Checks convergence related to the linearized eigenproblem.
-*/
-PetscErrorCode PEPConvergedLinear(PEP pep,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx)
-{
-  PetscErrorCode ierr;
-  PetscScalar    er,ei;
-  PetscBool      flg;
-  PetscFunctionBegin;
-  ierr = STGetTransform(pep->st,&flg);CHKERRQ(ierr);
-  if (!flg) {
-    ierr = PetscObjectTypeCompare((PetscObject)pep->st,STSINVERT,&flg);CHKERRQ(ierr);
-  } else flg = PETSC_FALSE;
-  er = eigr; ei = eigi;
-  ierr = STBackTransform(pep->st,1,&er,&ei);CHKERRQ(ierr);
-  if (flg) *errest = res*((pep->nrml[0]+PetscAbsScalar(pep->target)*pep->nrml[1])/SlepcAbsEigenvalue(eigr,eigi))/(pep->nrml[0]+SlepcAbsEigenvalue(er,ei)*pep->nrml[1]);
-  else *errest = res*pep->nrml[1]/(pep->nrml[0]+SlepcAbsEigenvalue(er,ei)*pep->nrml[1]);
-  PetscFunctionReturn(0);
-}
-
-#undef __FUNCT__
-#define __FUNCT__ "PEPConvergedNorm"
 /*
   PEPConvergedNorm - Checks convergence relative to the matrix norms.
 */
@@ -123,8 +85,6 @@ PetscErrorCode PEPConvergedNorm(PEP pep,PetscScalar eigr,PetscScalar eigi,PetscR
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "PEPConvergedAbsolute"
 /*
   PEPConvergedAbsolute - Checks convergence absolutely.
 */
@@ -135,8 +95,54 @@ PetscErrorCode PEPConvergedAbsolute(PEP pep,PetscScalar eigr,PetscScalar eigi,Pe
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "PEPBackTransform_Default"
+/*@C
+   PEPStoppingBasic - Default routine to determine whether the outer eigensolver
+   iteration must be stopped.
+
+   Collective on PEP
+
+   Input Parameters:
++  pep    - eigensolver context obtained from PEPCreate()
+.  its    - current number of iterations
+.  max_it - maximum number of iterations
+.  nconv  - number of currently converged eigenpairs
+.  nev    - number of requested eigenpairs
+-  ctx    - context (not used here)
+
+   Output Parameter:
+.  reason - result of the stopping test
+
+   Notes:
+   A positive value of reason indicates that the iteration has finished successfully
+   (converged), and a negative value indicates an error condition (diverged). If
+   the iteration needs to be continued, reason must be set to PEP_CONVERGED_ITERATING
+   (zero).
+
+   PEPStoppingBasic() will stop if all requested eigenvalues are converged, or if
+   the maximum number of iterations has been reached.
+
+   Use PEPSetStoppingTest() to provide your own test instead of using this one.
+
+   Level: advanced
+
+.seealso: PEPSetStoppingTest(), PEPConvergedReason, PEPGetConvergedReason()
+@*/
+PetscErrorCode PEPStoppingBasic(PEP pep,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nev,PEPConvergedReason *reason,void *ctx)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  *reason = PEP_CONVERGED_ITERATING;
+  if (nconv >= nev) {
+    ierr = PetscInfo2(pep,"Polynomial eigensolver finished successfully: %D eigenpairs converged at iteration %D\n",nconv,its);CHKERRQ(ierr);
+    *reason = PEP_CONVERGED_TOL;
+  } else if (its >= max_it) {
+    *reason = PEP_DIVERGED_ITS;
+    ierr = PetscInfo1(pep,"Polynomial eigensolver iteration reached maximum number of iterations (%D)\n",its);CHKERRQ(ierr);
+  }
+  PetscFunctionReturn(0);
+}
+
 PetscErrorCode PEPBackTransform_Default(PEP pep)
 {
   PetscErrorCode ierr;
@@ -146,8 +152,6 @@ PetscErrorCode PEPBackTransform_Default(PEP pep)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "PEPComputeVectors_Default"
 PetscErrorCode PEPComputeVectors_Default(PEP pep)
 {
   PetscErrorCode ierr;
@@ -175,7 +179,7 @@ PetscErrorCode PEPComputeVectors_Default(PEP pep)
     if (pep->eigi[i]!=0.0) {   /* first eigenvalue of a complex conjugate pair */
       ierr = BVGetColumn(pep->V,i,&v);CHKERRQ(ierr);
       ierr = BVGetColumn(pep->V,i+1,&v1);CHKERRQ(ierr);
-      ierr = SlepcVecNormalize(v,v1,PETSC_TRUE,NULL);CHKERRQ(ierr);
+      ierr = VecNormalizeComplex(v,v1,PETSC_TRUE,NULL);CHKERRQ(ierr);
       ierr = BVRestoreColumn(pep->V,i,&v);CHKERRQ(ierr);
       ierr = BVRestoreColumn(pep->V,i+1,&v1);CHKERRQ(ierr);
       i++;
@@ -183,70 +187,15 @@ PetscErrorCode PEPComputeVectors_Default(PEP pep)
 #endif
     {
       ierr = BVGetColumn(pep->V,i,&v);CHKERRQ(ierr);
-      ierr = SlepcVecNormalize(v,NULL,PETSC_FALSE,NULL);CHKERRQ(ierr);
+      ierr = VecNormalizeComplex(v,NULL,PETSC_FALSE,NULL);CHKERRQ(ierr);
       ierr = BVRestoreColumn(pep->V,i,&v);CHKERRQ(ierr);
     }
   }
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "PEPKrylovConvergence"
 /*
-   PEPKrylovConvergence - This is the analogue to EPSKrylovConvergence, but
-   for polynomial Krylov methods.
-
-   Differences:
-   - Always non-symmetric
-   - Does not check for STSHIFT
-   - No correction factor
-   - No support for true residual
-*/
-PetscErrorCode PEPKrylovConvergence(PEP pep,PetscBool getall,PetscInt kini,PetscInt nits,PetscReal beta,PetscInt *kout)
-{
-  PetscErrorCode ierr;
-  PetscInt       k,newk,marker,ld,inside;
-  PetscScalar    re,im;
-  PetscReal      resnorm;
-  PetscBool      istrivial;
-
-  PetscFunctionBegin;
-  ierr = RGIsTrivial(pep->rg,&istrivial);CHKERRQ(ierr);
-  ierr = DSGetLeadingDimension(pep->ds,&ld);CHKERRQ(ierr);
-  marker = -1;
-  if (pep->trackall) getall = PETSC_TRUE;
-  for (k=kini;k<kini+nits;k++) {
-    /* eigenvalue */
-    re = pep->eigr[k];
-    im = pep->eigi[k];
-    if (!istrivial) {
-      ierr = STBackTransform(pep->st,1,&re,&im);CHKERRQ(ierr);
-      ierr = RGCheckInside(pep->rg,1,&re,&im,&inside);CHKERRQ(ierr);
-      if (marker==-1 && inside<=0) marker = k;
-      re = pep->eigr[k];
-      im = pep->eigi[k];
-    }
-    newk = k;
-    ierr = DSVectors(pep->ds,DS_MAT_X,&newk,&resnorm);CHKERRQ(ierr);
-    resnorm *= beta;
-    /* error estimate */
-    ierr = (*pep->converged)(pep,re,im,resnorm,&pep->errest[k],pep->convergedctx);CHKERRQ(ierr);
-    if (marker==-1 && pep->errest[k] >= pep->tol) marker = k;
-    if (newk==k+1) {
-      pep->errest[k+1] = pep->errest[k];
-      k++;
-    }
-    if (marker!=-1 && !getall) break;
-  }
-  if (marker!=-1) k = marker;
-  *kout = k;
-  PetscFunctionReturn(0);
-}
-
-#undef __FUNCT__
-#define __FUNCT__ "PEPBuildDiagonalScaling"
-/*
-  PEPBuildDiagonalScaling - compute two diagonal matrices to be applied for balancing 
+  PEPBuildDiagonalScaling - compute two diagonal matrices to be applied for balancing
   in polynomial eigenproblems.
 */
 PetscErrorCode PEPBuildDiagonalScaling(PEP pep)
@@ -265,11 +214,11 @@ PetscErrorCode PEPBuildDiagonalScaling(PEP pep)
   PetscFunctionBegin;
   l2 = 2*PetscLogReal(2.0);
   nmat = pep->nmat;
-  ierr = PetscMPIIntCast(pep->n,&n);
+  ierr = PetscMPIIntCast(pep->n,&n);CHKERRQ(ierr);
   ierr = STGetMatStructure(pep->st,&str);CHKERRQ(ierr);
   ierr = PetscMalloc1(nmat,&T);CHKERRQ(ierr);
   for (k=0;k<nmat;k++) {
-    ierr = STGetTOperators(pep->st,k,&T[k]);CHKERRQ(ierr);
+    ierr = STGetMatrixTransformed(pep->st,k,&T[k]);CHKERRQ(ierr);
   }
   /* Form local auxiliar matrix M */
   ierr = PetscObjectTypeCompareAny((PetscObject)T[0],&cont,MATMPIAIJ,MATSEQAIJ,"");CHKERRQ(ierr);
@@ -277,12 +226,12 @@ PetscErrorCode PEPBuildDiagonalScaling(PEP pep)
   ierr = PetscObjectTypeCompare((PetscObject)T[0],MATMPIAIJ,&cont);CHKERRQ(ierr);
   if (cont) {
     ierr = MatMPIAIJGetLocalMat(T[0],MAT_INITIAL_MATRIX,&M);CHKERRQ(ierr);
-    flg = PETSC_TRUE; 
+    flg = PETSC_TRUE;
   } else {
     ierr = MatDuplicate(T[0],MAT_COPY_VALUES,&M);CHKERRQ(ierr);
   }
   ierr = MatGetInfo(M,MAT_LOCAL,&info);CHKERRQ(ierr);
-  nz = info.nz_used;
+  nz = (PetscInt)info.nz_used;
   ierr = MatSeqAIJGetArray(M,&array);CHKERRQ(ierr);
   for (i=0;i<nz;i++) {
     t = PetscAbsScalar(array[i]);
@@ -300,7 +249,7 @@ PetscErrorCode PEPBuildDiagonalScaling(PEP pep)
       }
     }
     ierr = MatGetInfo(A,MAT_LOCAL,&info);CHKERRQ(ierr);
-    nz = info.nz_used;
+    nz = (PetscInt)info.nz_used;
     ierr = MatSeqAIJGetArray(A,&array);CHKERRQ(ierr);
     for (i=0;i<nz;i++) {
       t = PetscAbsScalar(array[i]);
@@ -311,12 +260,12 @@ PetscErrorCode PEPBuildDiagonalScaling(PEP pep)
     ierr = MatAXPY(M,w,A,str);CHKERRQ(ierr);
     if (flg || str!=SAME_NONZERO_PATTERN || k==nmat-2) {
       ierr = MatDestroy(&A);CHKERRQ(ierr);
-    } 
+    }
   }
   ierr = MatGetRowIJ(M,0,PETSC_FALSE,PETSC_FALSE,&nr,&ridx,&cidx,&cont);CHKERRQ(ierr);
-  if (!cont) SETERRQ(PetscObjectComm((PetscObject)T[0]), PETSC_ERR_SUP,"It is not possible to compute scaling diagonals for these PEP matrices");
+  if (!cont) SETERRQ(PetscObjectComm((PetscObject)T[0]),PETSC_ERR_SUP,"It is not possible to compute scaling diagonals for these PEP matrices");
   ierr = MatGetInfo(M,MAT_LOCAL,&info);CHKERRQ(ierr);
-  nz = info.nz_used;
+  nz = (PetscInt)info.nz_used;
   ierr = VecGetOwnershipRange(pep->Dl,&lst,&lend);CHKERRQ(ierr);
   ierr = PetscMalloc4(nr,&rsum,pep->n,&csum,pep->n,&aux,PetscMin(pep->n-lend+lst,nz),&cols);CHKERRQ(ierr);
   ierr = VecSet(pep->Dr,1.0);CHKERRQ(ierr);
@@ -333,14 +282,14 @@ PetscErrorCode PEPBuildDiagonalScaling(PEP pep)
   }
   for (it=0;it<pep->sits && cont;it++) {
     emaxl = 0; eminl = 0;
-    /* Column sum  */    
+    /* Column sum  */
     if (it>0) { /* it=0 has been already done*/
       ierr = MatSeqAIJGetArray(M,&array);CHKERRQ(ierr);
       ierr = PetscMemzero(aux,pep->n*sizeof(PetscReal));CHKERRQ(ierr);
       for (j=0;j<nz;j++) aux[cidx[j]] += PetscAbsScalar(array[j]);
-      ierr = MatSeqAIJRestoreArray(M,&array);CHKERRQ(ierr); 
+      ierr = MatSeqAIJRestoreArray(M,&array);CHKERRQ(ierr);
     }
-    ierr = MPI_Allreduce(aux,csum,n,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)pep->Dr));
+    ierr = MPI_Allreduce(aux,csum,n,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)pep->Dr));CHKERRQ(ierr);
     /* Update Dr */
     for (j=lst;j<lend;j++) {
       d = PetscLogReal(csum[j])/l2;
@@ -365,7 +314,7 @@ PetscErrorCode PEPBuildDiagonalScaling(PEP pep)
       array[j] *= aux[cidx[j]];
     }
     ierr = MatSeqAIJRestoreArray(M,&array);CHKERRQ(ierr);
-    /* Row sum */    
+    /* Row sum */
     ierr = PetscMemzero(rsum,nr*sizeof(PetscReal));CHKERRQ(ierr);
     ierr = MatSeqAIJGetArray(M,&array);CHKERRQ(ierr);
     for (i=0;i<nr;i++) {
@@ -378,12 +327,12 @@ PetscErrorCode PEPBuildDiagonalScaling(PEP pep)
       /* Scale M */
       for (j=ridx[i];j<ridx[i+1];j++) array[j] *= d*d;
       emaxl = PetscMax(emaxl,e);
-      eminl = PetscMin(eminl,e);      
+      eminl = PetscMin(eminl,e);
     }
-    ierr = MatSeqAIJRestoreArray(M,&array);CHKERRQ(ierr);  
+    ierr = MatSeqAIJRestoreArray(M,&array);CHKERRQ(ierr);
     /* Compute global max and min */
-    ierr = MPI_Allreduce(&emaxl,&emax,1,MPIU_INT,MPI_MAX,PetscObjectComm((PetscObject)pep->Dl));
-    ierr = MPI_Allreduce(&eminl,&emin,1,MPIU_INT,MPI_MIN,PetscObjectComm((PetscObject)pep->Dl));
+    ierr = MPI_Allreduce(&emaxl,&emax,1,MPIU_INT,MPI_MAX,PetscObjectComm((PetscObject)pep->Dl));CHKERRQ(ierr);
+    ierr = MPI_Allreduce(&eminl,&emin,1,MPIU_INT,MPI_MIN,PetscObjectComm((PetscObject)pep->Dl));CHKERRQ(ierr);
     if (emax<=emin+2) cont = PETSC_FALSE;
   }
   ierr = VecRestoreArray(pep->Dr,&Dr);CHKERRQ(ierr);
@@ -395,8 +344,6 @@ PetscErrorCode PEPBuildDiagonalScaling(PEP pep)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "PEPComputeScaleFactor"
 /*
    PEPComputeScaleFactor - compute sfactor as described in [Betcke 2008].
 */
@@ -422,8 +369,8 @@ PetscErrorCode PEPComputeScaleFactor(PEP pep)
   if (basis==PEP_BASIS_MONOMIAL) {
     ierr = STGetTransform(pep->st,&flg);CHKERRQ(ierr);
     if (flg) {
-      ierr = STGetTOperators(pep->st,0,&T[0]);CHKERRQ(ierr);
-      ierr = STGetTOperators(pep->st,pep->nmat-1,&T[1]);CHKERRQ(ierr);
+      ierr = STGetMatrixTransformed(pep->st,0,&T[0]);CHKERRQ(ierr);
+      ierr = STGetMatrixTransformed(pep->st,pep->nmat-1,&T[1]);CHKERRQ(ierr);
     } else {
       T[0] = pep->A[0];
       T[1] = pep->A[pep->nmat-1];
@@ -437,7 +384,7 @@ PetscErrorCode PEPComputeScaleFactor(PEP pep)
         pep->sfactor = PetscPowReal(norm0/norm1,1.0/(pep->nmat-1));
         pep->dsfactor = norm1;
         for (i=pep->nmat-2;i>0;i--) {
-          ierr = STGetTOperators(pep->st,i,&T[1]);CHKERRQ(ierr);
+          ierr = STGetMatrixTransformed(pep->st,i,&T[1]);CHKERRQ(ierr);
           ierr = MatHasOperation(T[1],MATOP_NORM,&has1);CHKERRQ(ierr);
           if (has1) {
             ierr = MatNorm(T[1],NORM_INFINITY,&norm1);CHKERRQ(ierr);
@@ -448,65 +395,12 @@ PetscErrorCode PEPComputeScaleFactor(PEP pep)
           pep->dsfactor = pep->dsfactor*pep->sfactor+norm0;
           pep->dsfactor = pep->nmat/pep->dsfactor;
         } else pep->dsfactor = 1.0;
-      } 
+      }
     }
-  } 
+  }
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "PEPComputeLinearNorms"
-/*
-   PEPComputeLinearNorms - compute norm for the linearized problem.
-*/
-PetscErrorCode PEPComputeLinearNorms(PEP pep)
-{
-  PetscErrorCode    ierr;
-  PetscReal         out=0.0,nrmd=0.0,max=0.0,summ,summrow,summd=0.0;
-  PetscReal         *pbc,*a,*b,*g,t;
-  PetscInt          i,m0,m1,ncols,j,k;
-  const PetscScalar *vals;
-  Mat               *T;
-
-  PetscFunctionBegin;
-  ierr = PetscMalloc2(3*pep->nmat,&pbc,pep->nmat,&T);CHKERRQ(ierr);
-  for (i=0;i<pep->nmat;i++) {
-    ierr = STGetTOperators(pep->st,i,&T[i]);CHKERRQ(ierr);
-  }
-  a=pbc; b=pbc+pep->nmat; g = b+pep->nmat;
-  ierr = PEPBasisCoefficients(pep,pbc);CHKERRQ(ierr);
-  out = b[0]+a[0];
-  for (i=1;i<pep->nmat-2;i++) out = PetscMax(out,a[i]+b[i]+g[i]);
-  ierr = MatGetOwnershipRange(T[0],&m0,&m1);CHKERRQ(ierr);
-  for (i=m0;i<m1;i++) {
-    summrow = 0.0;
-    t = 1.0;
-    for (j=0;j<pep->nmat;j++) {
-      summ = 0.0;
-      ierr = MatGetRow(T[j],i,&ncols,NULL,&vals);CHKERRQ(ierr);
-      for (k=0;k<ncols;k++) summ += PetscAbsScalar(vals[k]);
-      ierr = MatRestoreRow(T[j],i,&ncols,NULL,&vals);CHKERRQ(ierr);
-      summ *= t;
-      if (j==pep->nmat-1) {
-        summd = summ;
-        summ *= (b[pep->nmat-2]+g[pep->nmat-2])/a[pep->nmat-2];
-      } else summ *= a[pep->nmat-2];
-      summrow += summ;
-      t *= pep->sfactor;
-    }
-    nrmd = PetscMax(nrmd,summd);
-    max = PetscMax(max,summrow);
-  }
-  max = PetscMax(max*pep->dsfactor,out);
-  ierr = MPI_Allreduce(&max,&pep->nrml[0],1,MPIU_REAL,MPIU_MAX,PetscObjectComm((PetscObject)pep));CHKERRQ(ierr);
-  ierr = MPI_Allreduce(&nrmd,&pep->nrml[1],1,MPIU_REAL,MPIU_MAX,PetscObjectComm((PetscObject)pep));CHKERRQ(ierr);
-  pep->nrml[1] = PetscMax(1.0,pep->nrml[1]*pep->dsfactor);
-  ierr = PetscFree2(pbc,T);CHKERRQ(ierr);
-  PetscFunctionReturn(0);
-}
-
-#undef __FUNCT__
-#define __FUNCT__ "PEPBasisCoefficients"
 /*
    PEPBasisCoefficients - compute polynomial basis coefficients
 */
@@ -514,7 +408,7 @@ PetscErrorCode PEPBasisCoefficients(PEP pep,PetscReal *pbc)
 {
   PetscReal *ca,*cb,*cg;
   PetscInt  k,nmat=pep->nmat;
-  
+
   PetscFunctionBegin;
   ca = pbc;
   cb = pbc+nmat;
@@ -535,7 +429,7 @@ PetscErrorCode PEPBasisCoefficients(PEP pep,PetscReal *pbc)
     ca[0] = .5; cb[0] = 0.0; cg[0] = 0.0;
     for (k=1;k<nmat;k++) {
       ca[k] = .5; cb[k] = 0.0; cg[k] = .5;
-    }    
+    }
     break;
   case PEP_BASIS_LEGENDRE:
     ca[0] = 1.0; cb[0] = 0.0; cg[0] = 0.0;
@@ -555,35 +449,6 @@ PetscErrorCode PEPBasisCoefficients(PEP pep,PetscReal *pbc)
       ca[k] = .5; cb[k] = 0.0; cg[k] = -k;
     }
     break;
-  default:
-    SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"Invalid 'basis' value");
-  }
-  PetscFunctionReturn(0);
-}
-
-#undef __FUNCT__
-#define __FUNCT__ "PEPEvaluateBasis"
-/*
-   PEPEvaluateBasis - evaluate the polynomial basis on a given parameter sigma
-*/
-PetscErrorCode PEPEvaluateBasis(PEP pep,PetscScalar sigma,PetscScalar isigma,PetscScalar *vals,PetscScalar *ivals)
-{
-  PetscInt   nmat=pep->nmat,k;
-  PetscReal  *a=pep->pbc,*b=pep->pbc+nmat,*g=pep->pbc+2*nmat;
-  
-  PetscFunctionBegin;
-  if (ivals) for (k=0;k<nmat;k++) ivals[k] = 0.0;
-  vals[0] = 1.0;
-  vals[1] = (sigma-b[0])/a[0];
-#if !defined(PETSC_USE_COMPLEX)
-  if (ivals) ivals[1] = isigma/a[0];
-#endif
-  for (k=2;k<nmat;k++) {
-    vals[k] = ((sigma-b[k-1])*vals[k-1]-g[k-1]*vals[k-2])/a[k-1];
-    if (ivals) vals[k] -= isigma*ivals[k-1]/a[k-1];
-#if !defined(PETSC_USE_COMPLEX)
-    if (ivals) ivals[k] = ((sigma-b[k-1])*ivals[k-1]+isigma*vals[k-1]-g[k-1]*ivals[k-2])/a[k-1];
-#endif
   }
   PetscFunctionReturn(0);
 }
