@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -42,7 +42,7 @@ PetscErrorCode PEPMonitorSetFromOptions(PEP pep,const char name[],const char hel
   PetscViewerAndFormat *vf;
 
   PetscFunctionBegin;
-  ierr = PetscOptionsGetViewer(PetscObjectComm((PetscObject)pep),((PetscObject)pep)->prefix,name,&viewer,&format,&flg);CHKERRQ(ierr);
+  ierr = PetscOptionsGetViewer(PetscObjectComm((PetscObject)pep),((PetscObject)pep)->options,((PetscObject)pep)->prefix,name,&viewer,&format,&flg);CHKERRQ(ierr);
   if (flg) {
     ierr = PetscViewerAndFormatCreate(viewer,format,&vf);CHKERRQ(ierr);
     ierr = PetscObjectDereference((PetscObject)viewer);CHKERRQ(ierr);
@@ -80,7 +80,7 @@ PetscErrorCode PEPConvMonitorSetFromOptions(PEP pep,const char name[],const char
   SlepcConvMonitor  ctx;
 
   PetscFunctionBegin;
-  ierr = PetscOptionsGetViewer(PetscObjectComm((PetscObject)pep),((PetscObject)pep)->prefix,name,&viewer,&format,&flg);CHKERRQ(ierr);
+  ierr = PetscOptionsGetViewer(PetscObjectComm((PetscObject)pep),((PetscObject)pep)->options,((PetscObject)pep)->prefix,name,&viewer,&format,&flg);CHKERRQ(ierr);
   if (flg) {
     ierr = SlepcConvMonitorCreate(viewer,format,&ctx);CHKERRQ(ierr);
     ierr = PetscObjectDereference((PetscObject)viewer);CHKERRQ(ierr);
@@ -1060,7 +1060,7 @@ PetscErrorCode PEPGetStoppingTest(PEP pep,PEPStop *stop)
    In the scalar strategy, scaling is applied to the eigenvalue, that is,
    mu = lambda/alpha is the new eigenvalue and all matrices are scaled
    accordingly. After solving the scaled problem, the original lambda is
-   recovered. Parameter 'alpha' must be positive. Use PETSC_DECIDE to let
+   recovered. Parameter 'alpha' must be positive. Use PETSC_DEFAULT to let
    the solver compute a reasonable scaling factor.
 
    In the diagonal strategy, the solver works implicitly with matrix Dl*A*Dr,
@@ -1070,7 +1070,7 @@ PetscErrorCode PEPGetStoppingTest(PEP pep,PEPStop *stop)
    provided, these matrices are computed internally. This option requires
    that the polynomial coefficient matrices are of MATAIJ type.
    The parameter 'its' is the number of iterations performed by the method.
-   Parameter 'lambda' must be positive. Use PETSC_DECIDE or set lambda = 1.0 if
+   Parameter 'lambda' must be positive. Use PETSC_DEFAULT or set lambda = 1.0 if
    no information about eigenvalues is available.
 
    Level: intermediate
