@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -179,7 +179,7 @@ int main(int argc,char **argv)
 
    testset:
       args: -svd_nsv 4 -mat_type aijcusparse
-      requires: veccuda
+      requires: cuda
       output_file: output/test3_1.out
       test:
          suffix: 3_cuda_lanczos
@@ -209,12 +209,11 @@ int main(int argc,char **argv)
          suffix: 3_cuda_cyclic_exp
          args: -svd_type cyclic -svd_cyclic_explicitmatrix
 
-   testset:
+   test:
       suffix: 4
       requires: !single
       args: -svd_type lapack -svd_nsv 4
       output_file: output/test3_1.out
-      test:
-         nsize: 2
+      nsize: 2
 
 TEST*/
