@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -86,7 +86,7 @@ PetscErrorCode SVDInitializePackage(void)
   This one registers all the SVD methods that are in the basic SLEPc libslepcsvd
   library.
  */
-PETSC_EXTERN PetscErrorCode PetscDLLibraryRegister_slepcsvd()
+SLEPC_EXTERN PetscErrorCode PetscDLLibraryRegister_slepcsvd()
 {
   PetscErrorCode ierr;
 
