@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -225,7 +225,7 @@ int main(int argc,char **argv)
       suffix: 1_cuda
       nsize: 1
       args: -bv_type svec -mat_type aijcusparse
-      requires: veccuda
+      requires: cuda
       output_file: output/test9_1.out
 
    test:
