@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -590,7 +590,6 @@ PetscErrorCode BVView(BV bv,PetscViewer viewer)
 {
   PetscErrorCode    ierr;
   PetscBool         isascii;
-  PetscInt          tabs;
   PetscViewerFormat format;
   const char        *orthname[2] = {"classical","modified"};
   const char        *refname[3] = {"if needed","never","always"};
@@ -604,8 +603,6 @@ PetscErrorCode BVView(BV bv,PetscViewer viewer)
 
   ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
   if (isascii) {
-    ierr = PetscViewerASCIIGetTab(viewer,&tabs);CHKERRQ(ierr);
-    ierr = PetscViewerASCIISetTab(viewer,((PetscObject)bv)->tablevel);CHKERRQ(ierr);
     ierr = PetscObjectPrintClassNamePrefixType((PetscObject)bv,viewer);CHKERRQ(ierr);
     ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
     if (format == PETSC_VIEWER_ASCII_INFO || format == PETSC_VIEWER_ASCII_INFO_DETAIL) {
@@ -630,8 +627,11 @@ PetscErrorCode BVView(BV bv,PetscViewer viewer)
         } else {
           ierr = PetscViewerASCIIPrintf(viewer,"  non-standard inner product\n");CHKERRQ(ierr);
         }
+        ierr = PetscViewerASCIIPrintf(viewer,"  inner product matrix:\n");CHKERRQ(ierr);
         ierr = PetscViewerPushFormat(viewer,PETSC_VIEWER_ASCII_INFO);CHKERRQ(ierr);
+        ierr = PetscViewerASCIIPushTab(viewer);CHKERRQ(ierr);
         ierr = MatView(bv->matrix,viewer);CHKERRQ(ierr);
+        ierr = PetscViewerASCIIPopTab(viewer);CHKERRQ(ierr);
         ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
       }
       switch (bv->vmm) {
@@ -653,7 +653,6 @@ PetscErrorCode BVView(BV bv,PetscViewer viewer)
       if (bv->ops->view) { ierr = (*bv->ops->view)(bv,viewer);CHKERRQ(ierr); }
       else { ierr = BVView_Default(bv,viewer);CHKERRQ(ierr); }
     }
-    ierr = PetscViewerASCIISetTab(viewer,tabs);CHKERRQ(ierr);
   } else {
     ierr = (*bv->ops->view)(bv,viewer);CHKERRQ(ierr);
   }
@@ -701,3 +700,26 @@ PetscErrorCode BVAllocateWork_Private(BV bv,PetscInt s)
   PetscFunctionReturn(0);
 }
 
+#if defined(PETSC_USE_DEBUG)
+/*
+   SlepcDebugBVView - partially view a BV object, to be used from within a debugger.
+
+     ini, end: columns to be viewed
+     s: name of Matlab variable
+     filename: optionally write output to a file
+ */
+PETSC_UNUSED PetscErrorCode SlepcDebugBVView(BV bv,PetscInt ini,PetscInt end,const char *s,const char *filename)
+{
+  PetscErrorCode ierr;
+  PetscInt       N,m;
+  PetscScalar    *array;
+
+  PetscFunctionBegin;
+  ierr = BVGetArray(bv,&array);CHKERRQ(ierr);
+  ierr = BVGetSizes(bv,NULL,&N,&m);CHKERRQ(ierr);
+  ierr = SlepcDebugViewMatrix(N,end-ini+1,array+ini*N,NULL,N,s,filename);CHKERRQ(ierr);
+  ierr = BVRestoreArray(bv,&array);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+#endif
+
