@@ -1,28 +1,16 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2015, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
-
-   SLEPc is free software: you can redistribute it and/or modify it under  the
-   terms of version 3 of the GNU Lesser General Public License as published by
-   the Free Software Foundation.
-
-   SLEPc  is  distributed in the hope that it will be useful, but WITHOUT  ANY
-   WARRANTY;  without even the implied warranty of MERCHANTABILITY or  FITNESS
-   FOR  A  PARTICULAR PURPOSE. See the GNU Lesser General Public  License  for
-   more details.
-
-   You  should have received a copy of the GNU Lesser General  Public  License
-   along with SLEPc. If not, see <http://www.gnu.org/licenses/>.
+   SLEPc is distributed under a 2-clause BSD license (see LICENSE).
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
+
 #include <slepc/private/dsimpl.h>
 #include <slepcblaslapack.h>
 
-#undef __FUNCT__
-#define __FUNCT__ "DSAllocate_GHIEP"
 PetscErrorCode DSAllocate_GHIEP(DS ds,PetscInt ld)
 {
   PetscErrorCode ierr;
@@ -39,8 +27,6 @@ PetscErrorCode DSAllocate_GHIEP(DS ds,PetscInt ld)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "DSSwitchFormat_GHIEP"
 PetscErrorCode DSSwitchFormat_GHIEP(DS ds,PetscBool tocompact)
 {
   PetscErrorCode ierr;
@@ -59,21 +45,21 @@ PetscErrorCode DSSwitchFormat_GHIEP(DS ds,PetscBool tocompact)
     ierr = PetscMemzero(T,3*ld*sizeof(PetscReal));CHKERRQ(ierr);
     ierr = PetscMemzero(S,ld*sizeof(PetscReal));CHKERRQ(ierr);
     for (i=0;i<n-1;i++) {
-      T[i] = PetscRealPart(A[i+i*ld]);
+      T[i]    = PetscRealPart(A[i+i*ld]);
       T[ld+i] = PetscRealPart(A[i+1+i*ld]);
-      S[i] = PetscRealPart(B[i+i*ld]);
+      S[i]    = PetscRealPart(B[i+i*ld]);
     }
     T[n-1] = PetscRealPart(A[n-1+(n-1)*ld]);
     S[n-1] = PetscRealPart(B[n-1+(n-1)*ld]);
-    for (i=ds->l;i< ds->k;i++) T[2*ld+i] = PetscRealPart(A[ds->k+i*ld]);
+    for (i=ds->l;i<ds->k;i++) T[2*ld+i] = PetscRealPart(A[ds->k+i*ld]);
   } else { /* switch from compact (arrow) to dense storage */
     ierr = PetscMemzero(A,ld*ld*sizeof(PetscScalar));CHKERRQ(ierr);
     ierr = PetscMemzero(B,ld*ld*sizeof(PetscScalar));CHKERRQ(ierr);
     for (i=0;i<n-1;i++) {
-      A[i+i*ld] = T[i];
-      A[i+1+i*ld] = T[ld+i];
+      A[i+i*ld]     = T[i];
+      A[i+1+i*ld]   = T[ld+i];
       A[i+(i+1)*ld] = T[ld+i];
-      B[i+i*ld] = S[i];
+      B[i+i*ld]     = S[i];
     }
     A[n-1+(n-1)*ld] = T[n-1];
     B[n-1+(n-1)*ld] = S[n-1];
@@ -85,8 +71,6 @@ PetscErrorCode DSSwitchFormat_GHIEP(DS ds,PetscBool tocompact)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "DSView_GHIEP"
 PetscErrorCode DSView_GHIEP(DS ds,PetscViewer viewer)
 {
   PetscErrorCode    ierr;
@@ -94,19 +78,16 @@ PetscErrorCode DSView_GHIEP(DS ds,PetscViewer viewer)
   PetscInt          i,j;
   PetscReal         value;
   const char        *methodname[] = {
-                     "HR method",
                      "QR + Inverse Iteration",
-                     "QR",
-                     "DQDS + Inverse Iteration "
+                     "HZ method",
+                     "QR"
   };
   const int         nmeth=sizeof(methodname)/sizeof(methodname[0]);
 
   PetscFunctionBegin;
   ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
   if (format == PETSC_VIEWER_ASCII_INFO || format == PETSC_VIEWER_ASCII_INFO_DETAIL) {
-    if (ds->method>=nmeth) {
-      ierr = PetscViewerASCIIPrintf(viewer,"solving the problem with: INVALID METHOD\n");CHKERRQ(ierr);
-    } else {
+    if (ds->method<nmeth) {
       ierr = PetscViewerASCIIPrintf(viewer,"solving the problem with: %s\n",methodname[ds->method]);CHKERRQ(ierr);
     }
     PetscFunctionReturn(0);
@@ -118,18 +99,18 @@ PetscErrorCode DSView_GHIEP(DS ds,PetscViewer viewer)
       ierr = PetscViewerASCIIPrintf(viewer,"zzz = zeros(%D,3);\n",3*ds->n);CHKERRQ(ierr);
       ierr = PetscViewerASCIIPrintf(viewer,"zzz = [\n");CHKERRQ(ierr);
       for (i=0;i<ds->n;i++) {
-        ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+1,i+1,*(ds->rmat[DS_MAT_T]+i));CHKERRQ(ierr);
+        ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+1,i+1,(double)*(ds->rmat[DS_MAT_T]+i));CHKERRQ(ierr);
       }
       for (i=0;i<ds->n-1;i++) {
         if (*(ds->rmat[DS_MAT_T]+ds->ld+i) !=0 && i!=ds->k-1) {
-          ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+2,i+1,*(ds->rmat[DS_MAT_T]+ds->ld+i));CHKERRQ(ierr);
-          ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+1,i+2,*(ds->rmat[DS_MAT_T]+ds->ld+i));CHKERRQ(ierr);
+          ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+2,i+1,(double)*(ds->rmat[DS_MAT_T]+ds->ld+i));CHKERRQ(ierr);
+          ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+1,i+2,(double)*(ds->rmat[DS_MAT_T]+ds->ld+i));CHKERRQ(ierr);
         }
       }
       for (i = ds->l;i<ds->k;i++) {
         if (*(ds->rmat[DS_MAT_T]+2*ds->ld+i)) {
-          ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",ds->k+1,i+1,*(ds->rmat[DS_MAT_T]+2*ds->ld+i));CHKERRQ(ierr);
-          ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+1,ds->k+1,*(ds->rmat[DS_MAT_T]+2*ds->ld+i));CHKERRQ(ierr);
+          ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",ds->k+1,i+1,(double)*(ds->rmat[DS_MAT_T]+2*ds->ld+i));CHKERRQ(ierr);
+          ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+1,ds->k+1,(double)*(ds->rmat[DS_MAT_T]+2*ds->ld+i));CHKERRQ(ierr);
         }
       }
       ierr = PetscViewerASCIIPrintf(viewer,"];\n%s = spconvert(zzz);\n",DSMatName[DS_MAT_A]);CHKERRQ(ierr);
@@ -138,7 +119,7 @@ PetscErrorCode DSView_GHIEP(DS ds,PetscViewer viewer)
       ierr = PetscViewerASCIIPrintf(viewer,"omega = zeros(%D,3);\n",3*ds->n);CHKERRQ(ierr);
       ierr = PetscViewerASCIIPrintf(viewer,"omega = [\n");CHKERRQ(ierr);
       for (i=0;i<ds->n;i++) {
-        ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+1,i+1,*(ds->rmat[DS_MAT_D]+i));CHKERRQ(ierr);
+        ierr = PetscViewerASCIIPrintf(viewer,"%D %D  %18.16e\n",i+1,i+1,(double)*(ds->rmat[DS_MAT_D]+i));CHKERRQ(ierr);
       }
       ierr = PetscViewerASCIIPrintf(viewer,"];\n%s = spconvert(omega);\n",DSMatName[DS_MAT_B]);CHKERRQ(ierr);
 
@@ -150,7 +131,7 @@ PetscErrorCode DSView_GHIEP(DS ds,PetscViewer viewer)
           else if (i==j+1 || j==i+1) value = *(ds->rmat[DS_MAT_T]+ds->ld+PetscMin(i,j));
           else if ((i<ds->k && j==ds->k) || (i==ds->k && j<ds->k)) value = *(ds->rmat[DS_MAT_T]+2*ds->ld+PetscMin(i,j));
           else value = 0.0;
-          ierr = PetscViewerASCIIPrintf(viewer," %18.16e ",value);CHKERRQ(ierr);
+          ierr = PetscViewerASCIIPrintf(viewer," %18.16e ",(double)value);CHKERRQ(ierr);
         }
         ierr = PetscViewerASCIIPrintf(viewer,"\n");CHKERRQ(ierr);
       }
@@ -159,7 +140,7 @@ PetscErrorCode DSView_GHIEP(DS ds,PetscViewer viewer)
         for (j=0;j<ds->n;j++) {
           if (i==j) value = *(ds->rmat[DS_MAT_D]+i);
           else value = 0.0;
-          ierr = PetscViewerASCIIPrintf(viewer," %18.16e ",value);CHKERRQ(ierr);
+          ierr = PetscViewerASCIIPrintf(viewer," %18.16e ",(double)value);CHKERRQ(ierr);
         }
         ierr = PetscViewerASCIIPrintf(viewer,"\n");CHKERRQ(ierr);
       }
@@ -176,10 +157,12 @@ PetscErrorCode DSView_GHIEP(DS ds,PetscViewer viewer)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "DSVectors_GHIEP_Eigen_Some"
-PetscErrorCode DSVectors_GHIEP_Eigen_Some(DS ds,PetscInt *idx,PetscReal *rnorm)
+static PetscErrorCode DSVectors_GHIEP_Eigen_Some(DS ds,PetscInt *idx,PetscReal *rnorm)
 {
+#if defined(SLEPC_MISSING_LAPACK_LAG2)
+  PetscFunctionBegin;
+  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"LAG2 - Lapack routine is unavailable");
+#else
   PetscErrorCode ierr;
   PetscReal      b[4],M[4],d1,d2,s1,s2,e;
   PetscReal      scal1,scal2,wr1,wr2,wi,ep,norm;
@@ -196,19 +179,16 @@ PetscErrorCode DSVectors_GHIEP_Eigen_Some(DS ds,PetscInt *idx,PetscReal *rnorm)
   k = *idx;
   ierr = PetscBLASIntCast(ds->n,&n_);CHKERRQ(ierr);
   ierr = PetscBLASIntCast(ds->ld,&ld);CHKERRQ(ierr);
-  if (k < ds->n-1) {
-    e = (ds->compact)?*(ds->rmat[DS_MAT_T]+ld+k):PetscRealPart(*(ds->mat[DS_MAT_A]+(k+1)+ld*k));
-  } else e = 0.0;
-  if (e == 0.0) {/* Real */
+  if (k < ds->n-1) e = (ds->compact)?*(ds->rmat[DS_MAT_T]+ld+k):PetscRealPart(*(ds->mat[DS_MAT_A]+(k+1)+ld*k));
+  else e = 0.0;
+  if (e == 0.0) { /* Real */
     if (ds->state>=DS_STATE_CONDENSED) {
       ierr = PetscMemcpy(X+k*ld,Q+k*ld,ld*sizeof(PetscScalar));CHKERRQ(ierr);
     } else {
       ierr = PetscMemzero(X+k*ds->ld,ds->ld*sizeof(PetscScalar));CHKERRQ(ierr);
       X[k+k*ds->ld] = 1.0;
     }
-    if (rnorm) {
-      *rnorm = PetscAbsScalar(X[ds->n-1+k*ld]);
-    }
+    if (rnorm) *rnorm = PetscAbsScalar(X[ds->n-1+k*ld]);
   } else { /* 2x2 block */
     if (ds->compact) {
       s1 = *(ds->rmat[DS_MAT_D]+k);
@@ -226,11 +206,11 @@ PetscErrorCode DSVectors_GHIEP_Eigen_Some(DS ds,PetscInt *idx,PetscReal *rnorm)
     ep = LAPACKlamch_("S");
     /* Compute eigenvalues of the block */
     PetscStackCallBLAS("LAPACKlag2",LAPACKlag2_(M,&two,b,&two,&ep,&scal1,&scal2,&wr1,&wr2,&wi));
-    if (wi==0.0)  /* Real eigenvalues */
-      SETERRQ(PETSC_COMM_SELF,1,"Real block in DSVectors_GHIEP");
+    if (wi==0.0) SETERRQ(PETSC_COMM_SELF,1,"Real block in DSVectors_GHIEP");
     else { /* Complex eigenvalues */
       if (scal1<ep) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_FP,"Nearly infinite eigenvalue");
-      wr1 /= scal1; wi /= scal1;
+      wr1 /= scal1;
+      wi  /= scal1;
 #if !defined(PETSC_USE_COMPLEX)
       if (SlepcAbs(s1*d1-wr1,wi)<SlepcAbs(s2*d2-wr1,wi)) {
         Y[0] = wr1-s2*d2; Y[1] = s2*e; Y[2] = wi; Y[3] = 0.0;
@@ -238,42 +218,47 @@ PetscErrorCode DSVectors_GHIEP_Eigen_Some(DS ds,PetscInt *idx,PetscReal *rnorm)
         Y[0] = s1*e; Y[1] = wr1-s1*d1; Y[2] = 0.0; Y[3] = wi;
       }
       norm = BLASnrm2_(&four,Y,&one);
-      norm = 1/norm;
+      norm = 1.0/norm;
       if (ds->state >= DS_STATE_CONDENSED) {
         alpha = norm;
         PetscStackCallBLAS("BLASgemm",BLASgemm_("N","N",&n_,&two,&two,&alpha,ds->mat[DS_MAT_Q]+k*ld,&ld,Y,&two,&zeroS,X+k*ld,&ld));
         if (rnorm) *rnorm = SlepcAbsEigenvalue(X[ds->n-1+k*ld],X[ds->n-1+(k+1)*ld]);
       } else {
         ierr = PetscMemzero(X+k*ld,2*ld*sizeof(PetscScalar));CHKERRQ(ierr);
-        X[k*ld+k] = Y[0]*norm; X[k*ld+k+1] = Y[1]*norm;
-        X[(k+1)*ld+k] = Y[2]*norm; X[(k+1)*ld+k+1] = Y[3]*norm;
+        X[k*ld+k]       = Y[0]*norm;
+        X[k*ld+k+1]     = Y[1]*norm;
+        X[(k+1)*ld+k]   = Y[2]*norm;
+        X[(k+1)*ld+k+1] = Y[3]*norm;
       }
 #else
       if (SlepcAbs(s1*d1-wr1,wi)<SlepcAbs(s2*d2-wr1,wi)) {
-        Y[0] = wr1-s2*d2+PETSC_i*wi; Y[1] = s2*e;
+        Y[0] = wr1-s2*d2+PETSC_i*wi;
+        Y[1] = s2*e;
       } else {
-        Y[0] = s1*e; Y[1] = wr1-s1*d1+PETSC_i*wi;
+        Y[0] = s1*e;
+        Y[1] = wr1-s1*d1+PETSC_i*wi;
       }
       norm = BLASnrm2_(&two,Y,&one);
-      norm = 1/norm;
+      norm = 1.0/norm;
       if (ds->state >= DS_STATE_CONDENSED) {
         alpha = norm;
         PetscStackCallBLAS("BLASgemv",BLASgemv_("N",&n_,&two,&alpha,ds->mat[DS_MAT_Q]+k*ld,&ld,Y,&one,&zeroS,X+k*ld,&one));
         if (rnorm) *rnorm = PetscAbsScalar(X[ds->n-1+k*ld]);
       } else {
         ierr = PetscMemzero(X+k*ld,2*ld*sizeof(PetscScalar));CHKERRQ(ierr);
-        X[k*ld+k] = Y[0]*norm; X[k*ld+k+1] = Y[1]*norm;
+        X[k*ld+k]   = Y[0]*norm;
+        X[k*ld+k+1] = Y[1]*norm;
       }
-      X[(k+1)*ld+k] = PetscConj(X[k*ld+k]); X[(k+1)*ld+k+1] = PetscConj(X[k*ld+k+1]);
+      X[(k+1)*ld+k]   = PetscConj(X[k*ld+k]);
+      X[(k+1)*ld+k+1] = PetscConj(X[k*ld+k+1]);
 #endif
       (*idx)++;
     }
   }
   PetscFunctionReturn(0);
+#endif
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "DSVectors_GHIEP"
 PetscErrorCode DSVectors_GHIEP(DS ds,DSMatType mat,PetscInt *k,PetscReal *rnorm)
 {
   PetscInt       i;
@@ -289,7 +274,7 @@ PetscErrorCode DSVectors_GHIEP(DS ds,DSMatType mat,PetscInt *k,PetscReal *rnorm)
       } else {
         for (i=0; i<ds->n; i++) {
           e = (ds->compact)?*(ds->rmat[DS_MAT_T]+ds->ld+i):PetscRealPart(*(ds->mat[DS_MAT_A]+(i+1)+ds->ld*i));
-          if (e == 0.0) {/* real */
+          if (e == 0.0) { /* real */
             if (ds->state >= DS_STATE_CONDENSED) {
               ierr = PetscMemcpy(ds->mat[mat]+i*ds->ld,ds->mat[DS_MAT_Q]+i*ds->ld,ds->ld*sizeof(PetscScalar));CHKERRQ(ierr);
             } else {
@@ -304,7 +289,7 @@ PetscErrorCode DSVectors_GHIEP(DS ds,DSMatType mat,PetscInt *k,PetscReal *rnorm)
       break;
     case DS_MAT_U:
     case DS_MAT_VT:
-      SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"Not implemented yet");
+      SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"Not implemented yet");
       break;
     default:
       SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Invalid mat parameter");
@@ -312,14 +297,16 @@ PetscErrorCode DSVectors_GHIEP(DS ds,DSMatType mat,PetscInt *k,PetscReal *rnorm)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "DSGHIEPComplexEigs"
 /*
   Extract the eigenvalues contained in the block-diagonal of the indefinite problem.
   Only the index range n0..n1 is processed.
 */
 PetscErrorCode DSGHIEPComplexEigs(DS ds,PetscInt n0,PetscInt n1,PetscScalar *wr,PetscScalar *wi)
 {
+#if defined(SLEPC_MISSING_LAPACK_LAG2)
+  PetscFunctionBegin;
+  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"LAG2 - Lapack routine is unavailable");
+#else
   PetscInt     k,ld;
   PetscBLASInt two=2;
   PetscScalar  *A,*B;
@@ -334,19 +321,14 @@ PetscErrorCode DSGHIEPComplexEigs(DS ds,PetscInt n0,PetscInt n1,PetscScalar *wr,
   D = ds->rmat[DS_MAT_D];
   T = ds->rmat[DS_MAT_T];
   for (k=n0;k<n1;k++) {
-    if (k < n1-1) {
-      e = (ds->compact)?T[ld+k]:PetscRealPart(A[(k+1)+ld*k]);
-    } else {
-      e = 0.0;
-    }
-    if (e==0.0) {
-      /* real eigenvalue */
+    if (k < n1-1) e = (ds->compact)?T[ld+k]:PetscRealPart(A[(k+1)+ld*k]);
+    else e = 0.0;
+    if (e==0.0) { /* real eigenvalue */
       wr[k] = (ds->compact)?T[k]/D[k]:A[k+k*ld]/B[k+k*ld];
 #if !defined(PETSC_USE_COMPLEX)
       wi[k] = 0.0 ;
 #endif
-    } else {
-      /* diagonal block */
+    } else { /* diagonal block */
       if (ds->compact) {
         s1 = D[k];
         d1 = T[k];
@@ -369,16 +351,16 @@ PetscErrorCode DSGHIEPComplexEigs(DS ds,PetscInt n0,PetscInt n1,PetscScalar *wr,
         if (scal2<ep) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_FP,"Nearly infinite eigenvalue");
         wr[k+1] = wr2/scal2;
 #if !defined(PETSC_USE_COMPLEX)
-        wi[k] = 0.0;
+        wi[k]   = 0.0;
         wi[k+1] = 0.0;
 #endif
       } else { /* Complex eigenvalues */
 #if !defined(PETSC_USE_COMPLEX)
         wr[k+1] = wr[k];
-        wi[k] = wi1/scal1;
+        wi[k]   = wi1/scal1;
         wi[k+1] = -wi[k];
 #else
-        wr[k] += PETSC_i*wi1/scal1;
+        wr[k]  += PETSC_i*wi1/scal1;
         wr[k+1] = PetscConj(wr[k]);
 #endif
       }
@@ -391,10 +373,9 @@ PetscErrorCode DSGHIEPComplexEigs(DS ds,PetscInt n0,PetscInt n1,PetscScalar *wr,
   }
 #endif
   PetscFunctionReturn(0);
+#endif
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "DSSort_GHIEP"
 PetscErrorCode DSSort_GHIEP(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *rr,PetscScalar *ri,PetscInt *k)
 {
   PetscErrorCode ierr;
@@ -437,16 +418,13 @@ PetscErrorCode DSSort_GHIEP(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *r
   PetscFunctionReturn(0);
 }
 
-
-#undef __FUNCT__
-#define __FUNCT__ "DSGHIEPInverseIteration"
 /*
   Get eigenvectors with inverse iteration.
   The system matrix is in Hessenberg form.
 */
 PetscErrorCode DSGHIEPInverseIteration(DS ds,PetscScalar *wr,PetscScalar *wi)
 {
-#if defined(PETSC_MISSING_LAPACK_HSEIN)
+#if defined(SLEPC_MISSING_LAPACK_HSEIN)
   PetscFunctionBegin;
   SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"HSEIN - Lapack routine is unavailable");
 #else
@@ -484,8 +462,8 @@ PetscErrorCode DSGHIEPInverseIteration(DS ds,PetscScalar *wr,PetscScalar *wi)
     H[ds->n-1+(ds->n-2)*ld] = e[ds->n-2]*s[ds->n-1];
     H[ds->n-1+(ds->n-1)*ld] = d[ds->n-1]*s[ds->n-1];
   } else {
-    s[ds->l] = PetscRealPart(B[off]);
-    H[off] = A[off]*s[ds->l];
+    s[ds->l]  = PetscRealPart(B[off]);
+    H[off]    = A[off]*s[ds->l];
     H[off+ld] = A[off+ld]*s[ds->l];
     for (i=ds->l+1;i<ds->n-1;i++) {
       s[i] = PetscRealPart(B[i+i*ld]);
@@ -516,21 +494,21 @@ PetscErrorCode DSGHIEPInverseIteration(DS ds,PetscScalar *wr,PetscScalar *wi)
     }
   }
 #endif
-  if (info<0) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_LIB,"Error in hsein routine %d",-i);
-  if (info>0) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_LIB,"Convergence error in hsein routine %d",i);
+  SlepcCheckLapackInfo("hsein",info);
   ierr = DSGHIEPOrthogEigenv(ds,DS_MAT_X,wr,wi,PETSC_TRUE);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 #endif
 }
 
-
-#undef __FUNCT__
-#define __FUNCT__ "DSGHIEPRealBlocks"
 /*
    Undo 2x2 blocks that have real eigenvalues.
 */
 PetscErrorCode DSGHIEPRealBlocks(DS ds)
 {
+#if defined(SLEPC_MISSING_LAPACK_LAG2)
+  PetscFunctionBegin;
+  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"LAG2 - Lapack routine is unavailable");
+#else
   PetscErrorCode ierr;
   PetscInt       i;
   PetscReal      e,d1,d2,s1,s2,ss1,ss2,t,dd,ss;
@@ -590,7 +568,8 @@ PetscErrorCode DSGHIEPRealBlocks(DS ds)
         if (wi==0.0) { /* Real eigenvalues */
           isreal = PETSC_TRUE;
           if (scal1<ep||scal2<ep) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_FP,"Nearly infinite eigenvalue");
-          wr1 /= scal1; wr2 /= scal2;
+          wr1 /= scal1;
+          wr2 /= scal2;
           if (PetscAbsReal(s1*d1-wr1)<PetscAbsReal(s2*d2-wr1)) {
             Y[0] = wr1-s2*d2;
             Y[1] = s2*e;
@@ -600,10 +579,13 @@ PetscErrorCode DSGHIEPRealBlocks(DS ds)
           }
           /* normalize with a signature*/
           maxy = PetscMax(PetscAbsScalar(Y[0]),PetscAbsScalar(Y[1]));
-          scal1 = PetscRealPart(Y[0])/maxy; scal2 = PetscRealPart(Y[1])/maxy;
+          scal1 = PetscRealPart(Y[0])/maxy;
+          scal2 = PetscRealPart(Y[1])/maxy;
           snorm = scal1*scal1*s1 + scal2*scal2*s2;
           if (snorm<0) { ss1 = -1.0; snorm = -snorm; }
-          snorm = maxy*PetscSqrtReal(snorm); Y[0] = Y[0]/snorm; Y[1] = Y[1]/snorm;
+          snorm = maxy*PetscSqrtReal(snorm);
+          Y[0] = Y[0]/snorm;
+          Y[1] = Y[1]/snorm;
           if (PetscAbsReal(s1*d1-wr2)<PetscAbsReal(s2*d2-wr2)) {
             Y[2] = wr2-s2*d2;
             Y[3] = s2*e;
@@ -612,27 +594,28 @@ PetscErrorCode DSGHIEPRealBlocks(DS ds)
             Y[3] = wr2-s1*d1;
           }
           maxy = PetscMax(PetscAbsScalar(Y[2]),PetscAbsScalar(Y[3]));
-          scal1 = PetscRealPart(Y[2])/maxy; scal2 = PetscRealPart(Y[3])/maxy;
+          scal1 = PetscRealPart(Y[2])/maxy;
+          scal2 = PetscRealPart(Y[3])/maxy;
           snorm = scal1*scal1*s1 + scal2*scal2*s2;
           if (snorm<0) { ss2 = -1.0; snorm = -snorm; }
-          snorm = maxy*PetscSqrtReal(snorm);Y[2] = Y[2]/snorm; Y[3] = Y[3]/snorm;
+          snorm = maxy*PetscSqrtReal(snorm); Y[2] = Y[2]/snorm; Y[3] = Y[3]/snorm;
         }
         wr1 *= ss1; wr2 *= ss2;
       }
       if (isreal) {
         if (ds->compact) {
-          D[i] = ss1;
-          T[i] = wr1;
-          D[i+1] = ss2;
-          T[i+1] = wr2;
+          D[i]    = ss1;
+          T[i]    = wr1;
+          D[i+1]  = ss2;
+          T[i+1]  = wr2;
           T[ld+i] = 0.0;
         } else {
-          B[i*ld+i] = ss1;
-          A[i*ld+i] = wr1;
+          B[i*ld+i]       = ss1;
+          A[i*ld+i]       = wr1;
           B[(i+1)*ld+i+1] = ss2;
           A[(i+1)*ld+i+1] = wr2;
-          A[(i+1)+ld*i] = 0.0;
-          A[i+ld*(i+1)] = 0.0;
+          A[(i+1)+ld*i]   = 0.0;
+          A[i+ld*(i+1)]   = 0.0;
         }
         PetscStackCallBLAS("BLASgemm",BLASgemm_("N","N",&m,&two,&two,&oneS,ds->mat[DS_MAT_Q]+ds->l+i*ld,&ld,Y,&two,&zeroS,ds->work,&m));
         ierr = PetscMemcpy(ds->mat[DS_MAT_Q]+ds->l+i*ld,ds->work,m*sizeof(PetscScalar));CHKERRQ(ierr);
@@ -642,10 +625,9 @@ PetscErrorCode DSGHIEPRealBlocks(DS ds)
     }
   }
   PetscFunctionReturn(0);
+#endif
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "DSSolve_GHIEP_QR_II"
 PetscErrorCode DSSolve_GHIEP_QR_II(DS ds,PetscScalar *wr,PetscScalar *wi)
 {
 #if defined(PETSC_MISSING_LAPACK_HSEQR)
@@ -680,7 +662,7 @@ PetscErrorCode DSSolve_GHIEP_QR_II(DS ds,PetscScalar *wr,PetscScalar *wi)
 
   /* Quick return if possible */
   if (n1 == 1) {
-    *(Q+off) = 1;
+    Q[off] = 1.0;
     if (!ds->compact) {
       d[ds->l] = PetscRealPart(A[off]);
       s[ds->l] = PetscRealPart(B[off]);
@@ -696,7 +678,7 @@ PetscErrorCode DSSolve_GHIEP_QR_II(DS ds,PetscScalar *wr,PetscScalar *wi)
   ierr = DSAllocateMat_Private(ds,DS_MAT_W);CHKERRQ(ierr);
   H = ds->mat[DS_MAT_W];
   if (ds->compact) {
-    H[off] = d[ds->l]*s[ds->l];
+    H[off]    = d[ds->l]*s[ds->l];
     H[off+ld] = e[ds->l]*s[ds->l];
     for (i=ds->l+1;i<ds->n-1;i++) {
       H[i+(i-1)*ld] = e[i-1]*s[i];
@@ -706,8 +688,8 @@ PetscErrorCode DSSolve_GHIEP_QR_II(DS ds,PetscScalar *wr,PetscScalar *wi)
     H[ds->n-1+(ds->n-2)*ld] = e[ds->n-2]*s[ds->n-1];
     H[ds->n-1+(ds->n-1)*ld] = d[ds->n-1]*s[ds->n-1];
   } else {
-    s[ds->l] = PetscRealPart(B[off]);
-    H[off] = A[off]*s[ds->l];
+    s[ds->l]  = PetscRealPart(B[off]);
+    H[off]    = A[off]*s[ds->l];
     H[off+ld] = A[off+ld]*s[ds->l];
     for (i=ds->l+1;i<ds->n-1;i++) {
       s[i] = PetscRealPart(B[i+i*ld]);
@@ -731,7 +713,7 @@ PetscErrorCode DSSolve_GHIEP_QR_II(DS ds,PetscScalar *wr,PetscScalar *wi)
       while (j<ds->n && (PetscAbsScalar(wr[i]-PetscConj(wr[j]))>PetscAbsScalar(wr[i])*PETSC_SQRT_MACHINE_EPSILON)) j++;
       if (j==ds->n) {
         if (PetscAbsReal(PetscImaginaryPart(wr[i]))<PetscAbsScalar(wr[i])*PETSC_SQRT_MACHINE_EPSILON) wr[i]=PetscRealPart(wr[i]);
-        else SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"In QR_II complex without conjugate pair");
+        else SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"Found complex without conjugate pair");
       } else { /* complex eigenvalue */
         wr[j] = wr[i+1];
         if (PetscImaginaryPart(wr[i])<0) wr[i] = PetscConj(wr[i]);
@@ -740,7 +722,7 @@ PetscErrorCode DSSolve_GHIEP_QR_II(DS ds,PetscScalar *wr,PetscScalar *wi)
       }
   }
 #endif
-  if (info) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_LIB,"Error in Lapack xHSEQR %d",&info);
+  SlepcCheckLapackInfo("hseqr",info);
   /* Compute Eigenvectors with Inverse Iteration */
   ierr = DSGHIEPInverseIteration(ds,wr,wi);CHKERRQ(ierr);
 
@@ -755,21 +737,19 @@ PetscErrorCode DSSolve_GHIEP_QR_II(DS ds,PetscScalar *wr,PetscScalar *wi)
 #endif
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "DSSolve_GHIEP_QR"
 PetscErrorCode DSSolve_GHIEP_QR(DS ds,PetscScalar *wr,PetscScalar *wi)
 {
-#if defined(SLEPC_MISSING_LAPACK_GEHRD) || defined(SLEPC_MISSING_LAPACK_ORGHR) || defined(PETSC_MISSING_LAPACK_HSEQR)
+#if defined(SLEPC_MISSING_LAPACK_GEEVX)
   PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"GEHRD/ORGHR/HSEQR - Lapack routines are unavailable");
+  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"GEEVX - Lapack routine is unavailable");
 #else
   PetscErrorCode ierr;
-  PetscInt       i,off,nwu=0,n,lw;
-  PetscBLASInt   n_,ld,info,lwork;
+  PetscInt       i,j,off,nwu=0,n,lw,lwr,nwru=0;
+  PetscBLASInt   n_,ld,info,lwork,ilo,ihi;
   PetscScalar    *H,*A,*B,*Q,*X;
-  PetscReal      *d,*s;
+  PetscReal      *d,*s,*scale,nrm,*rcde,*rcdv;
 #if defined(PETSC_USE_COMPLEX)
-  PetscInt       j,k;
+  PetscInt       k;
 #endif
 
   PetscFunctionBegin;
@@ -786,11 +766,17 @@ PetscErrorCode DSSolve_GHIEP_QR(DS ds,PetscScalar *wr,PetscScalar *wi)
   d = ds->rmat[DS_MAT_T];
   s = ds->rmat[DS_MAT_D];
   lw = 14*ld+ld*ld;
-  ierr = DSAllocateWork_Private(ds,lw,2*ld,0);CHKERRQ(ierr);
-
+  lwr = 7*ld;
+  ierr = DSAllocateWork_Private(ds,lw,lwr,0);CHKERRQ(ierr);
+  scale = ds->rwork+nwru;
+  nwru += ld;
+  rcde = ds->rwork+nwru;
+  nwru += ld;
+  rcdv = ds->rwork+nwru;
+  nwru += ld;
   /* Quick return if possible */
   if (n_ == 1) {
-    *(Q+off) = 1;
+    Q[off] = 1.0;
     if (!ds->compact) {
       d[ds->l] = PetscRealPart(A[off]);
       s[ds->l] = PetscRealPart(B[off]);
@@ -816,28 +802,21 @@ PetscErrorCode DSSolve_GHIEP_QR(DS ds,PetscScalar *wr,PetscScalar *wi)
       H[i+(ds->k-ds->l)*n] = s[i+ds->l]*d[2*ld+ds->l+i];
     }
   } else {
-    for (i=0;i<n-1;i++) {
-      H[i+i*n]     = B[off+i+i*ld]*A[off+i+i*ld];
-      H[i+1+i*n]   = B[off+i+1+(i+1)*ld]*A[off+i+1+i*ld];
-      H[i+(i+1)*n] = B[off+i+i*ld]*A[off+i+(i+1)*ld];
-    }
-    H[n-1+(n-1)*n] = B[off+n-1+(n-1)*ld]*A[off+n-1+(n-1)*n];
-    for (i=0;i<ds->k-ds->l;i++) {
-      H[ds->k-ds->l+i*n] = B[ds->k*(1+ld)]*A[off+ds->k-ds->l+i*ld];
-      H[i+(ds->k-ds->l)*n] = B[(i+ds->l)*(1+ld)]*A[off+i+(ds->k-ds->l)*ld];
+    for (j=0;j<n;j++) {
+      for (i=0;i<n;i++) H[i+j*n] = B[off+i+i*ld]*A[off+i+j*ld];
     }
   }
- 
+
   /* Compute eigenpairs */
-  ierr = PetscBLASIntCast(lw-nwu,&lwork);CHKERRQ(ierr);  
+  ierr = PetscBLASIntCast(lw-nwu,&lwork);CHKERRQ(ierr);
   ierr = DSAllocateMat_Private(ds,DS_MAT_X);CHKERRQ(ierr);
   X = ds->mat[DS_MAT_X];
 #if !defined(PETSC_USE_COMPLEX)
-  PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_("N","V",&n_,H,&n_,wr+ds->l,wi+ds->l,NULL,&ld,X+off,&ld,ds->work+nwu,&lwork,&info));
+  PetscStackCallBLAS("LAPACKgeevx",LAPACKgeevx_("B","N","V","N",&n_,H,&n_,wr+ds->l,wi+ds->l,NULL,&ld,X+off,&ld,&ilo,&ihi,scale,&nrm,rcde,rcdv,ds->work+nwu,&lwork,NULL,&info));
 #else
-  PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_("N","V",&n_,H,&n_,wr+ds->l,NULL,&ld,X+off,&ld,ds->work+nwu,&lwork,ds->rwork,&info));
+  PetscStackCallBLAS("LAPACKgeevx",LAPACKgeevx_("B","N","V","N",&n_,H,&n_,wr+ds->l,NULL,&ld,X+off,&ld,&ilo,&ihi,scale,&nrm,rcde,rcdv,ds->work+nwu,&lwork,ds->rwork+nwru,&info));
 
-  /* Sort to have consecutive conjugate pairs 
+  /* Sort to have consecutive conjugate pairs
      Separate real and imaginary part of complex eigenvectors*/
   for (i=ds->l;i<ds->n;i++) {
     j=i+1;
@@ -848,7 +827,7 @@ PetscErrorCode DSSolve_GHIEP_QR(DS ds,PetscScalar *wr,PetscScalar *wi)
         for (k=ds->l;k<ds->n;k++) {
           X[k+i*ds->ld] = PetscRealPart(X[k+i*ds->ld]);
         }
-      } else SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"In QR_II complex without conjugate pair");
+      } else SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"Found complex without conjugate pair");
     } else { /* complex eigenvalue */
       if (j!=i+1) {
         wr[j] = wr[i+1];
@@ -871,7 +850,7 @@ PetscErrorCode DSSolve_GHIEP_QR(DS ds,PetscScalar *wr,PetscScalar *wi)
     }
   }
 #endif
-  if (info) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_LIB,"Error in Lapack xHSEQR %d",&info);
+  SlepcCheckLapackInfo("geevx",info);
 
   /* Compute real s-orthonormal basis */
   ierr = DSGHIEPOrthogEigenv(ds,DS_MAT_X,wr,wi,PETSC_FALSE);CHKERRQ(ierr);
@@ -887,77 +866,85 @@ PetscErrorCode DSSolve_GHIEP_QR(DS ds,PetscScalar *wr,PetscScalar *wi)
 #endif
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "DSNormalize_GHIEP"
-PetscErrorCode DSNormalize_GHIEP(DS ds,DSMatType mat,PetscInt col)
+PetscErrorCode DSSynchronize_GHIEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
 {
   PetscErrorCode ierr;
-  PetscInt       i,i0,i1;
-  PetscBLASInt   ld,n,one = 1;
-  PetscScalar    *A = ds->mat[DS_MAT_A],norm,*x;
-#if !defined(PETSC_USE_COMPLEX)
-  PetscScalar    norm0;
-#endif
+  PetscInt       ld=ds->ld,l=ds->l,k=0,kr=0;
+  PetscMPIInt    n,rank,off=0,size,ldn,ld3,ld_;
 
   PetscFunctionBegin;
-  switch (mat) {
-    case DS_MAT_X:
-    case DS_MAT_Y:
-    case DS_MAT_Q:
-      /* Supported matrices */
-      break;
-    case DS_MAT_U:
-    case DS_MAT_VT:
-      SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"Not implemented yet");
-      break;
-    default:
-      SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Invalid mat parameter");
+  if (ds->compact) kr = 4*ld;
+  else k = 2*(ds->n-l)*ld;
+  if (ds->state>DS_STATE_RAW) k += (ds->n-l)*ld;
+  if (eigr) k += (ds->n-l); 
+  if (eigi) k += (ds->n-l); 
+  ierr = DSAllocateWork_Private(ds,k+kr,0,0);CHKERRQ(ierr);
+  ierr = PetscMPIIntCast(k*sizeof(PetscScalar)+kr*sizeof(PetscReal),&size);CHKERRQ(ierr);
+  ierr = PetscMPIIntCast(ds->n-l,&n);CHKERRQ(ierr);
+  ierr = PetscMPIIntCast(ld*(ds->n-l),&ldn);CHKERRQ(ierr);
+  ierr = PetscMPIIntCast(ld*3,&ld3);CHKERRQ(ierr);
+  ierr = PetscMPIIntCast(ld,&ld_);CHKERRQ(ierr);
+  ierr = MPI_Comm_rank(PetscObjectComm((PetscObject)ds),&rank);CHKERRQ(ierr);
+  if (!rank) {
+    if (ds->compact) {
+      ierr = MPI_Pack(ds->rmat[DS_MAT_T],ld3,MPIU_REAL,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+      ierr = MPI_Pack(ds->rmat[DS_MAT_D],ld_,MPIU_REAL,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+    } else {
+      ierr = MPI_Pack(ds->mat[DS_MAT_A]+l*ld,ldn,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+      ierr = MPI_Pack(ds->mat[DS_MAT_B]+l*ld,ldn,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+    }
+    if (ds->state>DS_STATE_RAW) {
+      ierr = MPI_Pack(ds->mat[DS_MAT_Q]+l*ld,ldn,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+    }
+    if (eigr) {
+      ierr = MPI_Pack(eigr+l,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+    }
+    if (eigi) {
+      ierr = MPI_Pack(eigi+l,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+    }
   }
-
-  ierr = PetscBLASIntCast(ds->n,&n);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(ds->ld,&ld);CHKERRQ(ierr);
-  ierr = DSGetArray(ds,mat,&x);CHKERRQ(ierr);
-  if (col < 0) {
-    i0 = 0; i1 = ds->n;
-  } else if (col>0 && A[ds->ld*(col-1)+col] != 0.0) {
-    i0 = col-1; i1 = col+1;
-  } else {
-    i0 = col; i1 = col+1;
-  }
-  for (i=i0; i<i1; i++) {
-#if !defined(PETSC_USE_COMPLEX)
-    if (i<n-1 && A[ds->ld*i+i+1] != 0.0) {
-      norm = BLASnrm2_(&n,&x[ld*i],&one);
-      norm0 = BLASnrm2_(&n,&x[ld*(i+1)],&one);
-      norm = 1.0/SlepcAbsEigenvalue(norm,norm0);
-      PetscStackCallBLAS("BLASscal",BLASscal_(&n,&norm,&x[ld*i],&one));
-      PetscStackCallBLAS("BLASscal",BLASscal_(&n,&norm,&x[ld*(i+1)],&one));
-      i++;
-    } else
-#endif
-    {
-      norm = BLASnrm2_(&n,&x[ld*i],&one);
-      norm = 1.0/norm;
-      PetscStackCallBLAS("BLASscal",BLASscal_(&n,&norm,&x[ld*i],&one));
+  ierr = MPI_Bcast(ds->work,size,MPI_BYTE,0,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+  if (rank) {
+    if (ds->compact) {
+      ierr = MPI_Unpack(ds->work,size,&off,ds->rmat[DS_MAT_T],ld3,MPIU_REAL,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+      ierr = MPI_Unpack(ds->work,size,&off,ds->rmat[DS_MAT_D],ld_,MPIU_REAL,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+    } else {
+      ierr = MPI_Unpack(ds->work,size,&off,ds->mat[DS_MAT_A]+l*ld,ldn,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+      ierr = MPI_Unpack(ds->work,size,&off,ds->mat[DS_MAT_B]+l*ld,ldn,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+    }
+    if (ds->state>DS_STATE_RAW) {
+      ierr = MPI_Unpack(ds->work,size,&off,ds->mat[DS_MAT_Q]+l*ld,ldn,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+    }
+    if (eigr) {
+      ierr = MPI_Unpack(ds->work,size,&off,eigr+l,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
+    }
+    if (eigi) {
+      ierr = MPI_Unpack(ds->work,size,&off,eigi+l,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRQ(ierr);
     }
   }
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "DSCreate_GHIEP"
-PETSC_EXTERN PetscErrorCode DSCreate_GHIEP(DS ds)
+PetscErrorCode DSHermitian_GHIEP(DS ds,DSMatType m,PetscBool *flg)
+{
+  PetscFunctionBegin;
+  if (m==DS_MAT_A || m==DS_MAT_B) *flg = PETSC_TRUE;
+  else *flg = PETSC_FALSE;
+  PetscFunctionReturn(0);
+}
+
+SLEPC_EXTERN PetscErrorCode DSCreate_GHIEP(DS ds)
 {
   PetscFunctionBegin;
   ds->ops->allocate      = DSAllocate_GHIEP;
   ds->ops->view          = DSView_GHIEP;
   ds->ops->vectors       = DSVectors_GHIEP;
-  ds->ops->solve[0]      = DSSolve_GHIEP_HZ;
-  ds->ops->solve[1]      = DSSolve_GHIEP_QR_II;
+  ds->ops->solve[0]      = DSSolve_GHIEP_QR_II;
+  ds->ops->solve[1]      = DSSolve_GHIEP_HZ;
   ds->ops->solve[2]      = DSSolve_GHIEP_QR;
-  ds->ops->solve[3]      = DSSolve_GHIEP_DQDS_II;
   ds->ops->sort          = DSSort_GHIEP;
-  ds->ops->normalize     = DSNormalize_GHIEP;
+  ds->ops->synchronize   = DSSynchronize_GHIEP;
+  ds->ops->hermitian     = DSHermitian_GHIEP;
   PetscFunctionReturn(0);
 }
 
