@@ -1,3 +1,12 @@
+/*
+   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+   SLEPc - Scalable Library for Eigenvalue Problem Computations
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+
+   This file is part of SLEPc.
+   SLEPc is distributed under a 2-clause BSD license (see LICENSE).
+   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+*/
 /*
    HZ iteration for generalized symmetric-indefinite eigenproblem.
    Based on Matlab code from David Watkins.
@@ -10,31 +19,11 @@
        [2] M.A. Brebner, J. Grad, "Eigenvalues of Ax = lambda Bx for real
            symmetric matrices A and B computed by reduction to pseudosymmetric
            form and the HR process", Linear Alg. Appl. 43:99-118, 1982.
-
-   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-   SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2015, Universitat Politecnica de Valencia, Spain
-
-   This file is part of SLEPc.
-
-   SLEPc is free software: you can redistribute it and/or modify it under  the
-   terms of version 3 of the GNU Lesser General Public License as published by
-   the Free Software Foundation.
-
-   SLEPc  is  distributed in the hope that it will be useful, but WITHOUT  ANY
-   WARRANTY;  without even the implied warranty of MERCHANTABILITY or  FITNESS
-   FOR  A  PARTICULAR PURPOSE. See the GNU Lesser General Public  License  for
-   more details.
-
-   You  should have received a copy of the GNU Lesser General  Public  License
-   along with SLEPc. If not, see <http://www.gnu.org/licenses/>.
-   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
+
 #include <slepc/private/dsimpl.h>
 #include <slepcblaslapack.h>
 
-#undef __FUNCT__
-#define __FUNCT__ "UnifiedRotation"
 /*
    Sets up a 2-by-2 matrix to eliminate y in the vector [x y]'.
    Transformation is rotator if sygn = 1 and hyperbolic if sygn = -1.
@@ -63,8 +52,7 @@ static PetscErrorCode UnifiedRotation(PetscReal x,PetscReal y,PetscReal sygn,Pet
       else if (nrm < 0) {
         nrm = PetscSqrtReal(-nrm);
         *swap = PETSC_TRUE;
-      } else   /* breakdown */
-        SETERRQ(PETSC_COMM_SELF,1,"Breakdown in construction of hyperbolic transformation");
+      } else SETERRQ(PETSC_COMM_SELF,1,"Breakdown in construction of hyperbolic transformation");
       c = c/nrm; s = s/nrm;
       /* rot = [c -s; -s c]; */
       rot[0] = c; rot[1] = -s; rot[2] = -s; rot[3] = c;
@@ -74,8 +62,6 @@ static PetscErrorCode UnifiedRotation(PetscReal x,PetscReal y,PetscReal sygn,Pet
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "HZStep"
 static PetscErrorCode HZStep(PetscBLASInt ntop,PetscBLASInt nn,PetscReal tr,PetscReal dt,PetscReal *aa,PetscReal *bb,PetscReal *dd,PetscScalar *uu,PetscInt n,PetscInt ld,PetscBool *flag)
 {
   PetscErrorCode ierr;
@@ -88,6 +74,7 @@ static PetscErrorCode HZStep(PetscBLASInt ntop,PetscBLASInt nn,PetscReal tr,Pets
   PetscBool      swap;
 
   PetscFunctionBegin;
+  *flag = PETSC_FALSE;
   worstcond = 1.0;
   ierr = PetscBLASIntCast(n,&n_);CHKERRQ(ierr);
 
@@ -157,7 +144,7 @@ static PetscErrorCode HZStep(PetscBLASInt ntop,PetscBLASInt nn,PetscReal tr,Pets
         }
 
         /* Accumulate transforming matrix */
-        PetscStackCallBLAS("BLASrot",BLASrot_(&n_,uu+(jj+1)*ld,&one,uu+(jj+2)*ld,&one,&rot[0],&rot[2]));
+        PetscStackCallBLAS("BLASrot",BLASMIXEDrot_(&n_,uu+(jj+1)*ld,&one,uu+(jj+2)*ld,&one,&rot[0],&rot[2]));
       }
 
       /* Annihilate inner entry bulge20 */
@@ -167,7 +154,6 @@ static PetscErrorCode HZStep(PetscBLASInt ntop,PetscBLASInt nn,PetscReal tr,Pets
         sygn = dd[jj]*dd[jj+1];
         ierr = UnifiedRotation(bulge10,bulge20,sygn,rot,&rcond,&swap);CHKERRQ(ierr);
         if (rcond<PETSC_MACHINE_EPSILON) {
-          SETERRQ1(PETSC_COMM_SELF,0,"Transforming matrix is numerically singular rcond=%g",rcond);
           *flag = PETSC_TRUE;
           PetscFunctionReturn(0);
         }
@@ -202,7 +188,7 @@ static PetscErrorCode HZStep(PetscBLASInt ntop,PetscBLASInt nn,PetscReal tr,Pets
 
         /* Accumulate transforming matrix, uu(jj:jj+1,:) = rot*uu(jj:jj+1,:) */
         if (sygn==1) {
-          PetscStackCallBLAS("BLASrot",BLASrot_(&n_,uu+jj*ld,&one,uu+(jj+1)*ld,&one,&rot[0],&rot[2]));
+          PetscStackCallBLAS("BLASrot",BLASMIXEDrot_(&n_,uu+jj*ld,&one,uu+(jj+1)*ld,&one,&rot[0],&rot[2]));
         } else {
           if (PetscAbsReal(rot[0])>PetscAbsReal(rot[1])) { /* Type I */
             t = rot[1]/rot[0];
@@ -233,8 +219,6 @@ static PetscErrorCode HZStep(PetscBLASInt ntop,PetscBLASInt nn,PetscReal tr,Pets
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "HZIteration"
 static PetscErrorCode HZIteration(PetscBLASInt nn,PetscBLASInt cgd,PetscReal *aa,PetscReal *bb,PetscReal *dd,PetscScalar *uu,PetscBLASInt ld)
 {
   PetscErrorCode ierr;
@@ -279,10 +263,7 @@ static PetscErrorCode HZIteration(PetscBLASInt nn,PetscBLASInt cgd,PetscReal *aa
           aa[nbot] = aa[nbot] - tn*bb[ntop];
           bb[ntop] = 0;
           j2 = nn-cgd;
-          PetscStackCallBLAS("BLASrot",BLASrot_(&j2,uu+ntop*ld+cgd,&one,uu+nbot*ld+cgd,&one,&c,&s));
-        } else {
-          dis = PetscSqrtScalar(dis);
-          if (htr < 0) dis = -dis;
+          PetscStackCallBLAS("BLASrot",BLASMIXEDrot_(&j2,uu+ntop*ld+cgd,&one,uu+nbot*ld+cgd,&one,&c,&s));
         }
       }
       nbot = ntop - 1;
@@ -294,8 +275,7 @@ static PetscErrorCode HZIteration(PetscBLASInt nn,PetscBLASInt cgd,PetscReal *aa
       for (ntry=1;ntry<=6;ntry++) {
         ierr = HZStep(ntop,nbot+1,tr,dt,aa,bb,dd,uu,nn,ld,&flag);CHKERRQ(ierr);
         if (!flag) break;
-        else if (ntry == 6)
-          SETERRQ(PETSC_COMM_SELF,1,"Unable to complete hz step on six tries");
+        else if (ntry == 6) SETERRQ(PETSC_COMM_SELF,1,"Unable to complete hz step on six tries");
         else {
           tr = 0.9*tr; dt = 0.81*dt;
         }
@@ -305,8 +285,6 @@ static PetscErrorCode HZIteration(PetscBLASInt nn,PetscBLASInt cgd,PetscReal *aa
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "DSSolve_GHIEP_HZ"
 PetscErrorCode DSSolve_GHIEP_HZ(DS ds,PetscScalar *wr,PetscScalar *wi)
 {
   PetscErrorCode ierr;
