@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -54,9 +54,9 @@ PetscErrorCode DSFinalizePackage(void)
 @*/
 PetscErrorCode DSInitializePackage()
 {
-  char             logList[256];
+  char           logList[256];
   PetscBool      opt,pkg;
-  PetscErrorCode   ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   if (DSPackageInitialized) PetscFunctionReturn(0);
@@ -140,6 +140,7 @@ PetscErrorCode DSCreate(MPI_Comm comm,DS *newds)
   }
   ds->perm          = NULL;
   ds->data          = NULL;
+  ds->scset         = PETSC_FALSE;
   ds->work          = NULL;
   ds->rwork         = NULL;
   ds->iwork         = NULL;
@@ -298,6 +299,47 @@ PetscErrorCode DSGetType(DS ds,DSType *type)
   PetscFunctionReturn(0);
 }
 
+/*@
+   DSDuplicate - Creates a new direct solver object with the same options as
+   an existing one.
+
+   Collective on DS
+
+   Input Parameter:
+.  ds - direct solver context
+
+   Output Parameter:
+.  dsnew - location to put the new DS
+
+   Notes:
+   DSDuplicate() DOES NOT COPY the matrices, and the new DS does not even have
+   internal arrays allocated. Use DSAllocate() to use the new DS.
+
+   The sorting criterion options are not copied, see DSSetSlepcSC().
+
+   Level: intermediate
+
+.seealso: DSCreate(), DSAllocate(), DSSetSlepcSC()
+@*/
+PetscErrorCode DSDuplicate(DS ds,DS *dsnew)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(ds,DS_CLASSID,1);
+  PetscValidType(ds,1);
+  PetscValidPointer(dsnew,2);
+  ierr = DSCreate(PetscObjectComm((PetscObject)ds),dsnew);CHKERRQ(ierr);
+  ierr = DSSetType(*dsnew,((PetscObject)ds)->type_name);CHKERRQ(ierr);
+  (*dsnew)->method   = ds->method;
+  (*dsnew)->compact  = ds->compact;
+  (*dsnew)->refined  = ds->refined;
+  (*dsnew)->extrarow = ds->extrarow;
+  (*dsnew)->bs       = ds->bs;
+  (*dsnew)->pmode    = ds->pmode;
+  PetscFunctionReturn(0);
+}
+
 /*@
    DSSetMethod - Selects the method to be used to solve the problem.
 
@@ -646,10 +688,11 @@ PetscErrorCode DSSetSlepcSC(DS ds,SlepcSC sc)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidPointer(sc,2);
-  if (ds->sc) {
+  if (ds->sc && !ds->scset) {
     ierr = PetscFree(ds->sc);CHKERRQ(ierr);
   }
-  ds->sc = sc;
+  ds->sc    = sc;
+  ds->scset = PETSC_TRUE;
   PetscFunctionReturn(0);
 }
 
@@ -752,20 +795,19 @@ PetscErrorCode DSSetFromOptions(DS ds)
 PetscErrorCode DSView(DS ds,PetscViewer viewer)
 {
   PetscBool         isascii,issvd;
-  PetscInt          tabs;
   PetscViewerFormat format;
   PetscErrorCode    ierr;
   PetscMPIInt       size;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
-  if (!viewer) viewer = PETSC_VIEWER_STDOUT_(PetscObjectComm((PetscObject)ds));
+  if (!viewer) {
+    ierr = PetscViewerASCIIGetStdout(PetscObjectComm((PetscObject)ds),&viewer);CHKERRQ(ierr);
+  }
   PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,2);
   PetscCheckSameComm(ds,1,viewer,2);
   ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
   if (isascii) {
-    ierr = PetscViewerASCIIGetTab(viewer,&tabs);CHKERRQ(ierr);
-    ierr = PetscViewerASCIISetTab(viewer,((PetscObject)ds)->tablevel);CHKERRQ(ierr);
     ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
     ierr = PetscObjectPrintClassNamePrefixType((PetscObject)ds,viewer);CHKERRQ(ierr);
     ierr = MPI_Comm_size(PetscObjectComm((PetscObject)ds),&size);CHKERRQ(ierr);
@@ -792,7 +834,6 @@ PetscErrorCode DSView(DS ds,PetscViewer viewer)
       ierr = (*ds->ops->view)(ds,viewer);CHKERRQ(ierr);
       ierr = PetscViewerASCIIPopTab(viewer);CHKERRQ(ierr);
     }
-    ierr = PetscViewerASCIISetTab(viewer,tabs);CHKERRQ(ierr);
   }
   PetscFunctionReturn(0);
 }
@@ -896,7 +937,7 @@ PetscErrorCode DSDestroy(DS *ds)
   ierr = PetscFree((*ds)->work);CHKERRQ(ierr);
   ierr = PetscFree((*ds)->rwork);CHKERRQ(ierr);
   ierr = PetscFree((*ds)->iwork);CHKERRQ(ierr);
-  ierr = PetscFree((*ds)->sc);CHKERRQ(ierr);
+  if (!(*ds)->scset) { ierr = PetscFree((*ds)->sc);CHKERRQ(ierr); }
   ierr = PetscHeaderDestroy(ds);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -928,14 +969,14 @@ PetscErrorCode DSRegister(const char *name,PetscErrorCode (*function)(DS))
   PetscFunctionReturn(0);
 }
 
-PETSC_EXTERN PetscErrorCode DSCreate_HEP(DS);
-PETSC_EXTERN PetscErrorCode DSCreate_NHEP(DS);
-PETSC_EXTERN PetscErrorCode DSCreate_GHEP(DS);
-PETSC_EXTERN PetscErrorCode DSCreate_GHIEP(DS);
-PETSC_EXTERN PetscErrorCode DSCreate_GNHEP(DS);
-PETSC_EXTERN PetscErrorCode DSCreate_SVD(DS);
-PETSC_EXTERN PetscErrorCode DSCreate_PEP(DS);
-PETSC_EXTERN PetscErrorCode DSCreate_NEP(DS);
+SLEPC_EXTERN PetscErrorCode DSCreate_HEP(DS);
+SLEPC_EXTERN PetscErrorCode DSCreate_NHEP(DS);
+SLEPC_EXTERN PetscErrorCode DSCreate_GHEP(DS);
+SLEPC_EXTERN PetscErrorCode DSCreate_GHIEP(DS);
+SLEPC_EXTERN PetscErrorCode DSCreate_GNHEP(DS);
+SLEPC_EXTERN PetscErrorCode DSCreate_SVD(DS);
+SLEPC_EXTERN PetscErrorCode DSCreate_PEP(DS);
+SLEPC_EXTERN PetscErrorCode DSCreate_NEP(DS);
 
 /*@C
    DSRegisterAll - Registers all of the direct solvers in the DS package.
