@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -130,7 +130,7 @@ int main(int argc,char **argv)
    test:
       suffix: 1_subdiagonalpade
       nsize: 1
-      args: -fn_method 2
+      args: -fn_method {{2 3}}
       requires: c99_complex !single
       filter: grep -v "computing matrix functions"
       output_file: output/test3_1.out
@@ -149,13 +149,18 @@ int main(int argc,char **argv)
       filter: grep -v "computing matrix functions"
       output_file: output/test3_3.out
 
-   test:
-      suffix: 3_subdiagonalpade
+   testset:
       nsize: 1
-      args: -fn_scale 0.1 -fn_method 2
-      requires: c99_complex
       filter: grep -v "computing matrix functions"
       output_file: output/test3_3.out
+      test:
+        suffix: 3_subdiagonalpade_product
+        args: -fn_scale 0.1 -fn_method 2
+        requires: c99_complex
+      test:
+        suffix: 3_subdiagonalpade_partial
+        args: -fn_scale 0.1 -fn_method 3
+        requires: c99_complex !single
 
    test:
       suffix: 4
@@ -165,12 +170,17 @@ int main(int argc,char **argv)
       filter: grep -v "computing matrix functions"
       output_file: output/test3_4.out
 
-   test:
-      suffix: 4_subdiagonalpade
+   testset:
       nsize: 1
-      args: -n 80 -fn_scale 0.6,1.5 -fn_method 2
-      requires: c99_complex
       filter: grep -v "computing matrix functions"
       output_file: output/test3_4.out
+      test:
+        suffix: 4_subdiagonalpade_product
+        args: -n 80 -fn_scale 0.6,1.5 -fn_method 2
+        requires: c99_complex
+      test:
+        suffix: 4_subdiagonalpade_partial
+        args: -n 80 -fn_scale 0.6,1.5 -fn_method 3
+        requires: c99_complex !single
 
 TEST*/
