@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -242,8 +242,10 @@ PetscErrorCode FNView_Combine(FN fn,PetscViewer viewer)
         ierr = PetscViewerASCIIPrintf(viewer,"  Two composed functions f2(f1(.))\n");CHKERRQ(ierr);
         break;
     }
+    ierr = PetscViewerASCIIPushTab(viewer);CHKERRQ(ierr);
     ierr = FNView(ctx->f1,viewer);CHKERRQ(ierr);
     ierr = FNView(ctx->f2,viewer);CHKERRQ(ierr);
+    ierr = PetscViewerASCIIPopTab(viewer);CHKERRQ(ierr);
   }
   PetscFunctionReturn(0);
 }
@@ -373,7 +375,7 @@ PetscErrorCode FNDestroy_Combine(FN fn)
   PetscFunctionReturn(0);
 }
 
-PETSC_EXTERN PetscErrorCode FNCreate_Combine(FN fn)
+SLEPC_EXTERN PetscErrorCode FNCreate_Combine(FN fn)
 {
   PetscErrorCode ierr;
   FN_COMBINE     *ctx;
