@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -130,13 +130,10 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Pade(FN fn,Mat A,Mat B)
 #endif
 }
 
-#define PARTIAL_FRACTION_FORM 0
-#define PRODUCT_FORM          1
-
 /*
  * Set scaling factor (s) and Pade degree (k,m)
  */
-static PetscErrorCode sexpm_params(PetscReal nrm,PetscInt mode,PetscInt *s,PetscInt *k,PetscInt *m)
+static PetscErrorCode sexpm_params(PetscReal nrm,PetscInt *s,PetscInt *k,PetscInt *m)
 {
   PetscFunctionBegin;
   if (nrm>1) {
@@ -210,7 +207,7 @@ static PetscErrorCode getcoeffs(PetscInt k,PetscInt m,PetscComplex *r,PetscCompl
                 6.796058759868242e+00 - 1.886649260140217e+00*PETSC_i},
     m1r4[3] = { 2.484269593165883e+01 + 7.460342395992306e+01*PETSC_i,
                 2.484269593165883e+01 - 7.460342395992306e+01*PETSC_i,
-               -2.734353918633177e+02                                },
+               -1.734353918633177e+02                                },
     m1q4[3] = { 4.675757014491557e+00 + 3.913489560603711e+00*PETSC_i,
                 4.675757014491557e+00 - 3.913489560603711e+00*PETSC_i,
                 5.648485971016893e+00                                },
@@ -496,7 +493,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa(FN fn,Mat A,Mat B)
   PetscFunctionBegin;
   SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"GEEV/GESV/LANGE - Lapack routines are unavailable");
 #else
-  PetscInt       i,j,n_,s,k,m,mode=PRODUCT_FORM,mod;
+  PetscInt       i,j,n_,s,k,m,mod;
   PetscBLASInt   n,n2,irsize,rsizediv2,ipsize,iremainsize,query=-1,info,*piv,minlen,lwork,one=1;
   PetscReal      nrm,shift;
 #if defined(PETSC_USE_COMPLEX)
@@ -506,6 +503,11 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa(FN fn,Mat A,Mat B)
   PetscScalar    *Aa,*Ba,*Ba2,*sMaux,*wr,*wi,expshift,sone=1.0,szero=0.0,*work,work1,*saux;
   PetscErrorCode ierr;
   PetscBool      isreal;
+#if defined(PETSC_HAVE_ESSL)
+  PetscScalar    sdummy;
+  PetscBLASInt   idummy,io=0;
+  PetscScalar    *wri;
+#endif
 
   PetscFunctionBegin;
   ierr = MatGetSize(A,&n_,NULL);CHKERRQ(ierr);
@@ -520,6 +522,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa(FN fn,Mat A,Mat B)
   ierr = PetscMalloc2(n,&wr,n,&wi);CHKERRQ(ierr);
   ierr = PetscMemcpy(sMaux,Aa,n2*sizeof(PetscScalar));CHKERRQ(ierr);
   /* estimate rightmost eigenvalue and shift A with it */
+#if !defined(PETSC_HAVE_ESSL)
 #if !defined(PETSC_USE_COMPLEX)
   PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_("N","N",&n,sMaux,&n,wr,wi,NULL,&n,NULL,&n,&work1,&query,&info));
   SlepcCheckLapackInfo("geev",info);
@@ -537,6 +540,20 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa(FN fn,Mat A,Mat B)
   ierr = PetscFree2(rwork,work);CHKERRQ(ierr);
 #endif
   SlepcCheckLapackInfo("geev",info);
+#else /* defined(PETSC_HAVE_ESSL) */
+  ierr = PetscBLASIntCast(3*n,&lwork);CHKERRQ(ierr);
+  ierr = PetscMalloc2(lwork,&work,2*n,&wri);CHKERRQ(ierr);
+  PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_(&io,Maux,&n,wri,&sdummy,&idummy,&idummy,&n,work,&lwork));
+#if !defined(PETSC_USE_COMPLEX)
+  for (i=0;i<n;i++) {
+    wr[i] = wri[2*i];
+    wi[i] = wri[2*i+1];
+  }
+#else
+  for (i=0;i<n;i++) wr[i] = wri[i];
+#endif
+  ierr = PetscFree2(work,wri);CHKERRQ(ierr);
+#endif
   ierr = PetscLogFlops(25.0*n*n*n+(n*n*n)/3.0+1.0*n*n*n);CHKERRQ(ierr);
 
   shift = PetscRealPart(wr[0]);
@@ -561,9 +578,9 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa(FN fn,Mat A,Mat B)
   /* estimate norm(A) and select the scaling factor */
   nrm = LAPACKlange_("O",&n,&n,sMaux,&n,NULL);
   ierr = PetscLogFlops(1.0*n*n);CHKERRQ(ierr);
-  ierr = sexpm_params(nrm,mode,&s,&k,&m);CHKERRQ(ierr);
+  ierr = sexpm_params(nrm,&s,&k,&m);CHKERRQ(ierr);
   if (s==0 && k==1 && m==0) { /* exp(A) = I+A to eps! */
-    expshift = PetscExpScalar(shift);
+    expshift = PetscExpReal(shift);
     for (i=0;i<n;i++) {
       sMaux[i+i*n] += 1.0;
     }
@@ -591,7 +608,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa(FN fn,Mat A,Mat B)
   ierr = SlepcLogFlopsComplex(1.0*n2);CHKERRQ(ierr);
 
   /* evaluate Pade approximant (partial fraction or product form) */
-  if (mode==PARTIAL_FRACTION_FORM || !m) { /* partial fraction */
+  if (fn->method==3 || !m) { /* partial fraction */
     ierr = getcoeffs(k,m,&rsize,&psize,&remainsize,PETSC_TRUE);CHKERRQ(ierr);
     ierr = PetscBLASIntCast((PetscInt)PetscRealPartComplex(rsize),&irsize);CHKERRQ(ierr);
     ierr = PetscBLASIntCast((PetscInt)PetscRealPartComplex(psize),&ipsize);CHKERRQ(ierr);
@@ -762,137 +779,8 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa(FN fn,Mat A,Mat B)
 #endif
 }
 
-#define ITMAX 5
-
-/*
- * Estimate norm(A^m,1) by block 1-norm power method (required workspace is 11*n)
- */
-static PetscReal normest1(PetscBLASInt n,PetscScalar *A,PetscInt m,PetscScalar *work,PetscRandom rand)
-{
-  PetscScalar    *X,*Y,*Z,*S,*S_old,*aux,val,sone=1.0,szero=0.0;
-  PetscReal      est=0.0,est_old,vals[2]={0.0,0.0},*zvals,maxzval[2],raux;
-  PetscBLASInt   i,j,t=2,it=0,ind[2],est_j=0,m1;
-  PetscErrorCode ierr;
-
-  PetscFunctionBegin;
-  X = work;
-  Y = work + 2*n;
-  Z = work + 4*n;
-  S = work + 6*n;
-  S_old = work + 8*n;
-  zvals = (PetscReal*)(work + 10*n);
-
-  for (i=0;i<n;i++) {  /* X has columns of unit 1-norm */
-    X[i] = 1.0/n;
-    PetscRandomGetValue(rand,&val);
-    if (PetscRealPart(val) < 0.5) X[i+n] = -1.0/n;
-    else X[i+n] = 1.0/n;
-  }
-  for (i=0;i<t*n;i++) S[i] = 0.0;
-  ind[0] = 0; ind[1] = 0;
-  est_old = 0;
-  while (1) {
-    it++;
-    for (j=0;j<m;j++) {  /* Y = A^m*X */
-      PetscStackCallBLAS("BLASgemm",BLASgemm_("N","N",&n,&t,&n,&sone,A,&n,X,&n,&szero,Y,&n));
-      if (j<m-1) SWAP(X,Y,aux);
-    }
-    for (j=0;j<t;j++) {  /* vals[j] = norm(Y(:,j),1) */
-      vals[j] = 0.0;
-      for (i=0;i<n;i++) vals[j] += PetscAbsScalar(Y[i+j*n]);
-    }
-    if (vals[0]<vals[1]) {
-      SWAP(vals[0],vals[1],raux);
-      m1 = 1;
-    } else m1 = 0;
-    est = vals[0];
-    if (est>est_old || it==2) est_j = ind[m1];
-    if (it>=2 && est<=est_old) {
-      est = est_old;
-      break;
-    }
-    est_old = est;
-    if (it>ITMAX) break;
-    SWAP(S,S_old,aux);
-    for (i=0;i<t*n;i++) {  /* S = sign(Y) */
-      S[i] = (PetscRealPart(Y[i]) < 0.0)? -1.0: 1.0;
-    }
-    for (j=0;j<m;j++) {  /* Z = (A^T)^m*S */
-      PetscStackCallBLAS("BLASgemm",BLASgemm_("C","N",&n,&t,&n,&sone,A,&n,S,&n,&szero,Z,&n));
-      if (j<m-1) SWAP(S,Z,aux);
-    }
-    maxzval[0] = -1; maxzval[1] = -1;
-    ind[0] = 0; ind[1] = 0;
-    for (i=0;i<n;i++) {  /* zvals[i] = norm(Z(i,:),inf) */
-      zvals[i] = PetscMax(PetscAbsScalar(Z[i+0*n]),PetscAbsScalar(Z[i+1*n]));
-      if (zvals[i]>maxzval[0]) {
-        maxzval[0] = zvals[i];
-        ind[0] = i;
-      } else if (zvals[i]>maxzval[1]) {
-        maxzval[1] = zvals[i];
-        ind[1] = i;
-      }
-    }
-    if (it>=2 && maxzval[0]==zvals[est_j]) break;
-    for (i=0;i<t*n;i++) X[i] = 0.0;
-    for (j=0;j<t;j++) X[ind[j]+j*n] = 1.0;
-  }
-  /* Flop count is roughly (it * 2*m * t*gemv) = 4*its*m*t*n*n */
-  ierr = PetscLogFlops(4.0*it*m*t*n*n);CHKERRQ(ierr);
-  PetscFunctionReturn(est);
-}
-
 #define SMALLN 100
 
-/*
- * Estimate norm(A^m,1) (required workspace is 2*n*n)
- */
-static PetscReal normAm(PetscBLASInt n,PetscScalar *A,PetscInt m,PetscScalar *work,PetscRandom rand)
-{
-  PetscScalar    *v=work,*w=work+n*n,*aux,sone=1.0,szero=0.0;
-  PetscReal      nrm,rwork[1],tmp;
-  PetscBLASInt   i,j,one=1;
-  PetscBool      isrealpos=PETSC_TRUE;
-  PetscErrorCode ierr;
-
-  PetscFunctionBegin;
-  if (n<SMALLN) {   /* compute matrix power explicitly */
-    if (m==1) {
-      nrm = LAPACKlange_("O",&n,&n,A,&n,rwork);
-      ierr = PetscLogFlops(1.0*n*n);CHKERRQ(ierr);
-    } else {  /* m>=2 */
-      PetscStackCallBLAS("BLASgemm",BLASgemm_("N","N",&n,&n,&n,&sone,A,&n,A,&n,&szero,v,&n));
-      for (j=0;j<m-2;j++) {
-        PetscStackCallBLAS("BLASgemm",BLASgemm_("N","N",&n,&n,&n,&sone,A,&n,v,&n,&szero,w,&n));
-        SWAP(v,w,aux);
-      }
-      nrm = LAPACKlange_("O",&n,&n,v,&n,rwork);
-      ierr = PetscLogFlops(2.0*n*n*n*(m-1)+1.0*n*n);CHKERRQ(ierr);
-    }
-  } else {
-    for (i=0;i<n;i++)
-      for (j=0;j<n;j++) 
-#if defined(PETSC_USE_COMPLEX)
-        if (PetscRealPart(A[i+j*n])<0.0 || PetscImaginaryPart(A[i+j*n])!=0.0) { isrealpos = PETSC_FALSE; break; }
-#else
-        if (A[i+j*n]<0.0) { isrealpos = PETSC_FALSE; break; }
-#endif
-    if (isrealpos) {   /* for positive matrices only */
-      for (i=0;i<n;i++) v[i] = 1.0;
-      for (j=0;j<m;j++) {  /* w = A'*v */
-        PetscStackCallBLAS("BLASgemv",BLASgemv_("C",&n,&n,&sone,A,&n,v,&one,&szero,w,&one));
-        SWAP(v,w,aux);
-      }
-      ierr = PetscLogFlops(2.0*n*n*m);CHKERRQ(ierr);
-      nrm = 0.0;
-      for (i=0;i<n;i++) if ((tmp = PetscAbsScalar(v[i])) > nrm) nrm = tmp;   /* norm(v,inf) */
-    } else {
-      nrm = normest1(n,A,m,work,rand);
-    }
-  }
-  PetscFunctionReturn(nrm);
-}
-
 /*
  * Function needed to compute optimal parameters (required workspace is 3*n*n)
  */
@@ -911,7 +799,8 @@ static PetscInt ell(PetscBLASInt n,PetscScalar *A,PetscReal coeff,PetscInt m,Pet
       Ascaled[i+j*n] = beta*PetscAbsScalar(A[i+j*n]);
   nrm = LAPACKlange_("O",&n,&n,A,&n,rwork);
   ierr = PetscLogFlops(2.0*n*n);CHKERRQ(ierr);
-  alpha = normAm(n,Ascaled,2*m+1,work+n*n,rand)/nrm;
+  ierr = SlepcNormAm(n,Ascaled,2*m+1,work+n*n,rand,&alpha);CHKERRQ(ierr);
+  alpha /= nrm;
   t = PetscMax((PetscInt)PetscCeilReal(PetscLogReal(2.0*alpha/PETSC_MACHINE_EPSILON)/PetscLogReal(2.0)/(2*m)),0);
   PetscFunctionReturn(t);
 }
@@ -960,7 +849,8 @@ static PetscErrorCode expm_params(PetscInt n,PetscScalar **Apowers,PetscInt *s,P
     d8 = PetscPowReal(LAPACKlange_("O",&n_,&n_,work,&n_,rwork),1.0/8.0);
     ierr = PetscLogFlops(2.0*n*n*n+1.0*n*n);CHKERRQ(ierr);
   } else {
-    d8 = PetscPowReal(normAm(n_,Apowers[2],2,work,rand),1.0/8.0);
+    ierr = SlepcNormAm(n_,Apowers[2],2,work,rand,&d8);CHKERRQ(ierr);
+    d8 = PetscPowReal(d8,1.0/8.0);
   }
   eta3 = PetscMax(d6,d8);
   if (eta3<=theta[2] && !ell(n_,A,coeff[2],7,work,rand)) {
@@ -976,7 +866,8 @@ static PetscErrorCode expm_params(PetscInt n,PetscScalar **Apowers,PetscInt *s,P
     d10 = PetscPowReal(LAPACKlange_("O",&n_,&n_,work,&n_,rwork),1.0/10.0);
     ierr = PetscLogFlops(2.0*n*n*n+1.0*n*n);CHKERRQ(ierr);
   } else {
-    d10 = PetscPowReal(normAm(n_,Apowers[1],5,work,rand),1.0/10.0);
+    ierr = SlepcNormAm(n_,Apowers[1],5,work,rand,&d10);CHKERRQ(ierr);
+    d10 = PetscPowReal(d10,1.0/10.0);
   }
   eta4 = PetscMax(d8,d10);
   eta5 = PetscMin(eta3,eta4);
@@ -1153,7 +1044,8 @@ PetscErrorCode FNView_Exp(FN fn,PetscViewer viewer)
   const char     *methodname[] = {
                   "scaling & squaring, [m/m] Pade approximant (Higham)",
                   "scaling & squaring, [6/6] Pade approximant",
-                  "scaling & squaring, subdiagonal Pade approximant"
+                  "scaling & squaring, subdiagonal Pade approximant (product form)",
+                  "scaling & squaring, subdiagonal Pade approximant (partial fraction)"
   };
   const int      nmeth=sizeof(methodname)/sizeof(methodname[0]);
 
@@ -1186,14 +1078,15 @@ PetscErrorCode FNView_Exp(FN fn,PetscViewer viewer)
   PetscFunctionReturn(0);
 }
 
-PETSC_EXTERN PetscErrorCode FNCreate_Exp(FN fn)
+SLEPC_EXTERN PetscErrorCode FNCreate_Exp(FN fn)
 {
   PetscFunctionBegin;
   fn->ops->evaluatefunction       = FNEvaluateFunction_Exp;
   fn->ops->evaluatederivative     = FNEvaluateDerivative_Exp;
   fn->ops->evaluatefunctionmat[0] = FNEvaluateFunctionMat_Exp_Higham;
   fn->ops->evaluatefunctionmat[1] = FNEvaluateFunctionMat_Exp_Pade;
-  fn->ops->evaluatefunctionmat[2] = FNEvaluateFunctionMat_Exp_GuettelNakatsukasa;
+  fn->ops->evaluatefunctionmat[2] = FNEvaluateFunctionMat_Exp_GuettelNakatsukasa; /* product form */
+  fn->ops->evaluatefunctionmat[3] = FNEvaluateFunctionMat_Exp_GuettelNakatsukasa; /* partial fraction */
   fn->ops->view                   = FNView_Exp;
   PetscFunctionReturn(0);
 }
