@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -265,7 +265,7 @@ PetscErrorCode FNDestroy_Phi(FN fn)
   PetscFunctionReturn(0);
 }
 
-PETSC_EXTERN PetscErrorCode FNCreate_Phi(FN fn)
+SLEPC_EXTERN PetscErrorCode FNCreate_Phi(FN fn)
 {
   PetscErrorCode ierr;
   FN_PHI         *ctx;
