@@ -1,28 +1,19 @@
 /*
-   Ring region, similar to the ellipse but with a start and end angle,
-   together with the width.
-
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2015, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
-
-   SLEPc is free software: you can redistribute it and/or modify it under  the
-   terms of version 3 of the GNU Lesser General Public License as published by
-   the Free Software Foundation.
-
-   SLEPc  is  distributed in the hope that it will be useful, but WITHOUT  ANY
-   WARRANTY;  without even the implied warranty of MERCHANTABILITY or  FITNESS
-   FOR  A  PARTICULAR PURPOSE. See the GNU Lesser General Public  License  for
-   more details.
-
-   You  should have received a copy of the GNU Lesser General  Public  License
-   along with SLEPc. If not, see <http://www.gnu.org/licenses/>.
+   SLEPc is distributed under a 2-clause BSD license (see LICENSE).
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
+/*
+   Ring region, similar to the ellipse but with a start and end angle,
+   together with the width
+*/
 
 #include <slepc/private/rgimpl.h>      /*I "slepcrg.h" I*/
+#include <petscdraw.h>
 
 typedef struct {
   PetscScalar center;     /* center of the ellipse */
@@ -33,8 +24,6 @@ typedef struct {
   PetscReal   width;      /* ring width */
 } RG_RING;
 
-#undef __FUNCT__
-#define __FUNCT__ "RGRingSetParameters_Ring"
 static PetscErrorCode RGRingSetParameters_Ring(RG rg,PetscScalar center,PetscReal radius,PetscReal vscale,PetscReal start_ang,PetscReal end_ang,PetscReal width)
 {
   RG_RING *ctx = (RG_RING*)rg->data;
@@ -63,7 +52,9 @@ static PetscErrorCode RGRingSetParameters_Ring(RG rg,PetscScalar center,PetscRea
     if (end_ang>1.0) SETERRQ(PetscObjectComm((PetscObject)rg),PETSC_ERR_ARG_OUTOFRANGE,"The left-hand side angle argument must be <= 1.0");
     ctx->end_ang = end_ang;
   }
-  if (ctx->start_ang>ctx->end_ang) SETERRQ(PetscObjectComm((PetscObject)rg),PETSC_ERR_ARG_OUTOFRANGE,"The right-hand side angle argument must be smaller than left one");
+#if !defined(PETSC_USE_COMPLEX)
+  if (ctx->start_ang+ctx->end_ang!=1.0) SETERRQ(PetscObjectComm((PetscObject)rg),PETSC_ERR_ARG_WRONG,"In real scalars the region must be symmetric wrt real axis");
+#endif
   if (width == PETSC_DEFAULT) {
     ctx->width = 0.1;
   } else {
@@ -73,8 +64,6 @@ static PetscErrorCode RGRingSetParameters_Ring(RG rg,PetscScalar center,PetscRea
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "RGRingSetParameters"
 /*@
    RGRingSetParameters - Sets the parameters defining the ring region.
 
@@ -102,15 +91,20 @@ static PetscErrorCode RGRingSetParameters_Ring(RG rg,PetscScalar center,PetscRea
    ellipse region. The startangle and endangle define the span of the ring
    (by default it is the whole ring), while the width is the separation
    between the two concentric ellipses (above and below the radius by
-   width/2). The start and end angles are expressed as a fraction of the
-   circumference: the allowed range is [0..1], with 0 corresponding to 0
-   radians, 0.25 to pi/2 radians, and so on.
+   width/2).
+
+   The start and end angles are expressed as a fraction of the circumference:
+   the allowed range is [0..1], with 0 corresponding to 0 radians, 0.25 to
+   pi/2 radians, and so on. It is allowed to have startangle>endangle, in
+   which case the ring region crosses over the zero angle.
 
    In the case of complex scalars, a complex center can be provided in the
    command line with [+/-][realnumber][+/-]realnumberi with no spaces, e.g.
    -rg_ring_center 1.0+2.0i
 
-   When PETSc is built with real scalars, the center is restricted to a real value.
+   When PETSc is built with real scalars, the center is restricted to a real value,
+   and the start and end angles must be such that the region is symmetric with
+   respect to the real axis.
 
    Level: advanced
 
@@ -132,8 +126,6 @@ PetscErrorCode RGRingSetParameters(RG rg,PetscScalar center,PetscReal radius,Pet
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "RGRingGetParameters_Ring"
 static PetscErrorCode RGRingGetParameters_Ring(RG rg,PetscScalar *center,PetscReal *radius,PetscReal *vscale,PetscReal *start_ang,PetscReal *end_ang,PetscReal *width)
 {
   RG_RING *ctx = (RG_RING*)rg->data;
@@ -148,8 +140,6 @@ static PetscErrorCode RGRingGetParameters_Ring(RG rg,PetscScalar *center,PetscRe
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "RGRingGetParameters"
 /*@
    RGRingGetParameters - Gets the parameters that define the ring region.
 
@@ -176,51 +166,127 @@ PetscErrorCode RGRingGetParameters(RG rg,PetscScalar *center,PetscReal *radius,P
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(rg,RG_CLASSID,1);
-  ierr = PetscTryMethod(rg,"RGRingGetParameters_C",(RG,PetscScalar*,PetscReal*,PetscReal*,PetscReal*,PetscReal*,PetscReal*),(rg,center,radius,vscale,start_ang,end_ang,width));CHKERRQ(ierr);
+  ierr = PetscUseMethod(rg,"RGRingGetParameters_C",(RG,PetscScalar*,PetscReal*,PetscReal*,PetscReal*,PetscReal*,PetscReal*),(rg,center,radius,vscale,start_ang,end_ang,width));CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "RGView_Ring"
 PetscErrorCode RGView_Ring(RG rg,PetscViewer viewer)
 {
   PetscErrorCode ierr;
   RG_RING        *ctx = (RG_RING*)rg->data;
-  PetscBool      isascii;
+  int            winw,winh;
+  PetscBool      isdraw,isascii;
+  PetscDraw      draw;
+  PetscDrawAxis  axis;
+  PetscReal      cx,cy,radius,width,ab,cd,lx,ly,w,end_ang,x1,y1,x2,y2,r,theta,scale=1.2;
   char           str[50];
 
   PetscFunctionBegin;
+  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERDRAW,&isdraw);CHKERRQ(ierr);
   ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
   if (isascii) {
     ierr = SlepcSNPrintfScalar(str,50,ctx->center,PETSC_FALSE);CHKERRQ(ierr);
-    ierr = PetscViewerASCIIPrintf(viewer,"center: %s, radius: %g, vscale: %g, start angle: %g, end angle: %g, ring width: %g\n",str,RGShowReal(ctx->radius),RGShowReal(ctx->vscale),ctx->start_ang,ctx->end_ang,ctx->width);CHKERRQ(ierr);
+    ierr = PetscViewerASCIIPrintf(viewer,"  center: %s, radius: %g, vscale: %g, start angle: %g, end angle: %g, ring width: %g\n",str,RGShowReal(ctx->radius),RGShowReal(ctx->vscale),(double)ctx->start_ang,(double)ctx->end_ang,(double)ctx->width);CHKERRQ(ierr);
+  } else if (isdraw) {
+    ierr = PetscViewerDrawGetDraw(viewer,0,&draw);CHKERRQ(ierr);
+    ierr = PetscDrawCheckResizedWindow(draw);CHKERRQ(ierr);
+    ierr = PetscDrawGetWindowSize(draw,&winw,&winh);CHKERRQ(ierr);
+    winw = PetscMax(winw,1); winh = PetscMax(winh,1);
+    ierr = PetscDrawClear(draw);CHKERRQ(ierr);
+    ierr = PetscDrawSetTitle(draw,"Ring region");CHKERRQ(ierr);
+    ierr = PetscDrawAxisCreate(draw,&axis);CHKERRQ(ierr);
+    cx = PetscRealPart(ctx->center)*rg->sfactor;
+    cy = PetscImaginaryPart(ctx->center)*rg->sfactor;
+    radius = ctx->radius*rg->sfactor;
+    width  = ctx->width*rg->sfactor;
+    lx = 2*(radius+width);
+    ly = 2*(radius+width)*ctx->vscale;
+    ab = cx;
+    cd = cy;
+    w  = scale*PetscMax(lx/winw,ly/winh)/2;
+    ierr = PetscDrawAxisSetLimits(axis,ab-w*winw,ab+w*winw,cd-w*winh,cd+w*winh);CHKERRQ(ierr);
+    ierr = PetscDrawAxisDraw(axis);CHKERRQ(ierr);
+    ierr = PetscDrawAxisDestroy(&axis);CHKERRQ(ierr);
+    /* draw outer ellipse */
+    ierr = PetscDrawEllipse(draw,cx,cy,2*(radius+width),2*(radius+width)*ctx->vscale,PETSC_DRAW_ORANGE);CHKERRQ(ierr);
+    /* remove inner part */
+    ierr = PetscDrawEllipse(draw,cx,cy,2*(radius-width),2*(radius-width)*ctx->vscale,PETSC_DRAW_WHITE);CHKERRQ(ierr);
+    if (ctx->start_ang!=ctx->end_ang) {
+      /* remove section from end_ang to start_ang */
+      end_ang = (ctx->start_ang<ctx->end_ang)? ctx->end_ang-1: ctx->end_ang;
+      theta = end_ang;
+      r = scale*(radius+width);
+      if (ctx->vscale>1) r *= ctx->vscale;
+      x1 = PetscMin(PetscMax(ab+r*PetscCosReal(2.0*PETSC_PI*theta),ab-w*winw),ab+w*winw);
+      y1 = PetscMin(PetscMax(cd+r*PetscSinReal(2.0*PETSC_PI*theta),cd-w*winh),cd+w*winh);
+      do {
+        theta = PetscMin(PetscFloorReal(8*theta+1)/8,ctx->start_ang);
+        x2 = PetscMin(PetscMax(ab+r*PetscCosReal(2.0*PETSC_PI*theta),ab-w*winw),ab+w*winw);
+        y2 = PetscMin(PetscMax(cd+r*PetscSinReal(2.0*PETSC_PI*theta),cd-w*winh),cd+w*winh);
+        ierr = PetscDrawTriangle(draw,cx,cy,x1,y1,x2,y2,PETSC_DRAW_WHITE,PETSC_DRAW_WHITE,PETSC_DRAW_WHITE);CHKERRQ(ierr);
+        x1 = x2; y1 = y2;
+      } while (theta<ctx->start_ang);
+    }
+    ierr = PetscDrawFlush(draw);CHKERRQ(ierr);
+    ierr = PetscDrawSave(draw);CHKERRQ(ierr);
+    ierr = PetscDrawPause(draw);CHKERRQ(ierr);
   }
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "RGIsTrivial_Ring"
 PetscErrorCode RGIsTrivial_Ring(RG rg,PetscBool *trivial)
 {
   RG_RING *ctx = (RG_RING*)rg->data;
 
   PetscFunctionBegin;
-  if (rg->complement) *trivial = (ctx->radius==0.0)? PETSC_TRUE: PETSC_FALSE;
-  else *trivial = (ctx->radius>=PETSC_MAX_REAL)? PETSC_TRUE: PETSC_FALSE;
+  if (rg->complement) *trivial = PetscNot(ctx->radius);
+  else *trivial = PetscNot(ctx->radius<PETSC_MAX_REAL);
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "RGComputeContour_Ring"
 PetscErrorCode RGComputeContour_Ring(RG rg,PetscInt n,PetscScalar *cr,PetscScalar *ci)
 {
+  RG_RING   *ctx = (RG_RING*)rg->data;
+  PetscReal theta,start_ang;
+  PetscInt  i,n2=n/2;
+
   PetscFunctionBegin;
-  SETERRQ(PetscObjectComm((PetscObject)rg),1,"Not implemented yet");
+  start_ang = (ctx->start_ang>ctx->end_ang)? ctx->start_ang-1: ctx->start_ang;
+  for (i=0;i<n;i++) {
+    if (i < n2) {
+      theta = ((ctx->end_ang-start_ang)*i/n2 + start_ang)*2.0*PETSC_PI;
+#if defined(PETSC_USE_COMPLEX)
+      cr[i] = ctx->center + (ctx->radius+ctx->width/2.0)*(PetscCosReal(theta)+ctx->vscale*PetscSinReal(theta)*PETSC_i);
+#else
+      cr[i] = ctx->center + (ctx->radius+ctx->width/2.0)*PetscCosReal(theta);
+      ci[i] = (ctx->radius+ctx->width/2.0)*ctx->vscale*PetscSinReal(theta);
+#endif
+    } else {
+      theta = ((ctx->end_ang-start_ang)*(n-i)/n2 + start_ang)*2.0*PETSC_PI;
+#if defined(PETSC_USE_COMPLEX)
+      cr[i] = ctx->center + (ctx->radius-ctx->width/2.0)*(PetscCosReal(theta)+ctx->vscale*PetscSinReal(theta)*PETSC_i);
+#else
+      cr[i] = ctx->center + (ctx->radius-ctx->width/2.0)*PetscCosReal(theta);
+      ci[i] = (ctx->radius-ctx->width/2.0)*ctx->vscale*PetscSinReal(theta);
+#endif
+    }
+  }
+  PetscFunctionReturn(0);
+}
+
+PetscErrorCode RGComputeBoundingBox_Ring(RG rg,PetscReal *a,PetscReal *b,PetscReal *c,PetscReal *d)
+{
+  RG_RING *ctx = (RG_RING*)rg->data;
+
+  PetscFunctionBegin;
+  /* current implementation does not return a tight bounding box */
+  if (a) *a = PetscRealPart(ctx->center) - (ctx->radius+ctx->width/2.0);
+  if (b) *b = PetscRealPart(ctx->center) + (ctx->radius+ctx->width/2.0);
+  if (c) *c = PetscImaginaryPart(ctx->center) - (ctx->radius+ctx->width/2.0)*ctx->vscale;
+  if (d) *d = PetscImaginaryPart(ctx->center) + (ctx->radius+ctx->width/2.0)*ctx->vscale;
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "RGCheckInside_Ring"
 PetscErrorCode RGCheckInside_Ring(RG rg,PetscReal px,PetscReal py,PetscInt *inside)
 {
   RG_RING   *ctx = (RG_RING*)rg->data;
@@ -247,31 +313,33 @@ PetscErrorCode RGCheckInside_Ring(RG rg,PetscReal px,PetscReal py,PetscInt *insi
 #endif
   r = -1.0+dx*dx+(dy*dy)/(ctx->vscale*ctx->vscale);
   *inside *= PetscSign(r);
-  /* check angles */
+  if (*inside == 1) {  /* check angles */
 #if defined(PETSC_USE_COMPLEX)
-  dx = (px-PetscRealPart(ctx->center));
-  dy = (py-PetscImaginaryPart(ctx->center));
+    dx = (px-PetscRealPart(ctx->center));
+    dy = (py-PetscImaginaryPart(ctx->center));
 #else
-  dx = px-ctx->center;
-  dy = py;
+    dx = px-ctx->center;
+    dy = py;
 #endif
-  if (dx == 0) {
-    if (dy == 0) r = -1;
-    else if (dy > 0) r = 0.25;
-    else r = 0.75;
-  } else if (dx > 0) {
-    r = PetscAtanReal((dy/ctx->vscale)/dx);
-    if (dy >= 0) r /= 2*PETSC_PI;
-    else r = r/(2*PETSC_PI)+1;
-  } else r = PetscAtanReal((dy/ctx->vscale)/dx)/(2*PETSC_PI)+0.5;
-  if (r>=ctx->start_ang && r<=ctx->end_ang && *inside == 1) *inside = 1;
-  else *inside = 0;
+    if (dx == 0) {
+      if (dy == 0) r = -1;
+      else if (dy > 0) r = 0.25;
+      else r = 0.75;
+    } else if (dx > 0) {
+      r = PetscAtanReal((dy/ctx->vscale)/dx);
+      if (dy >= 0) r /= 2*PETSC_PI;
+      else r = r/(2*PETSC_PI)+1;
+    } else r = PetscAtanReal((dy/ctx->vscale)/dx)/(2*PETSC_PI)+0.5;
+    if (ctx->start_ang>ctx->end_ang) {
+      if (r>ctx->end_ang && r<ctx->start_ang) *inside = -1;
+    } else {
+      if (r<ctx->start_ang || r>ctx->end_ang) *inside = -1;
+    }
+  }
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "RGSetFromOptions_Ring"
-PetscErrorCode RGSetFromOptions_Ring(PetscOptions *PetscOptionsObject,RG rg)
+PetscErrorCode RGSetFromOptions_Ring(PetscOptionItems *PetscOptionsObject,RG rg)
 {
   PetscErrorCode ierr;
   PetscScalar    s;
@@ -281,23 +349,19 @@ PetscErrorCode RGSetFromOptions_Ring(PetscOptions *PetscOptionsObject,RG rg)
   PetscFunctionBegin;
   ierr = PetscOptionsHead(PetscOptionsObject,"RG Ring Options");CHKERRQ(ierr);
 
-  ierr = RGRingGetParameters(rg,&s,&r1,&r2,&r3,&r4,&r5);CHKERRQ(ierr);
-  ierr = PetscOptionsScalar("-rg_ring_center","Center of ellipse","RGRingSetParameters",s,&s,&flg1);CHKERRQ(ierr);
-  ierr = PetscOptionsReal("-rg_ring_radius","Radius of ellipse","RGRingSetParameters",r1,&r1,&flg2);CHKERRQ(ierr);
-  ierr = PetscOptionsReal("-rg_ring_vscale","Vertical scale of ellipse","RGRingSetParameters",r2,&r2,&flg3);CHKERRQ(ierr);
-  ierr = PetscOptionsReal("-rg_ring_startangle","Right-hand side angle","RGRingSetParameters",r3,&r3,&flg4);CHKERRQ(ierr);
-  ierr = PetscOptionsReal("-rg_ring_endangle","Left-hand side angle","RGRingSetParameters",r4,&r4,&flg5);CHKERRQ(ierr);
-  ierr = PetscOptionsReal("-rg_ring_width","Width of ring","RGRingSetParameters",r5,&r5,&flg6);CHKERRQ(ierr);
-  if (flg1 || flg2 || flg3 || flg4 || flg5 || flg6) {
-    ierr = RGRingSetParameters(rg,s,r1,r2,r3,r4,r5);CHKERRQ(ierr);
-  }
+    ierr = RGRingGetParameters(rg,&s,&r1,&r2,&r3,&r4,&r5);CHKERRQ(ierr);
+    ierr = PetscOptionsScalar("-rg_ring_center","Center of ellipse","RGRingSetParameters",s,&s,&flg1);CHKERRQ(ierr);
+    ierr = PetscOptionsReal("-rg_ring_radius","Radius of ellipse","RGRingSetParameters",r1,&r1,&flg2);CHKERRQ(ierr);
+    ierr = PetscOptionsReal("-rg_ring_vscale","Vertical scale of ellipse","RGRingSetParameters",r2,&r2,&flg3);CHKERRQ(ierr);
+    ierr = PetscOptionsReal("-rg_ring_startangle","Right-hand side angle","RGRingSetParameters",r3,&r3,&flg4);CHKERRQ(ierr);
+    ierr = PetscOptionsReal("-rg_ring_endangle","Left-hand side angle","RGRingSetParameters",r4,&r4,&flg5);CHKERRQ(ierr);
+    ierr = PetscOptionsReal("-rg_ring_width","Width of ring","RGRingSetParameters",r5,&r5,&flg6);CHKERRQ(ierr);
+    if (flg1 || flg2 || flg3 || flg4 || flg5 || flg6) { ierr = RGRingSetParameters(rg,s,r1,r2,r3,r4,r5);CHKERRQ(ierr); }
 
   ierr = PetscOptionsTail();CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "RGDestroy_Ring"
 PetscErrorCode RGDestroy_Ring(RG rg)
 {
   PetscErrorCode ierr;
@@ -309,9 +373,7 @@ PetscErrorCode RGDestroy_Ring(RG rg)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "RGCreate_Ring"
-PETSC_EXTERN PetscErrorCode RGCreate_Ring(RG rg)
+SLEPC_EXTERN PetscErrorCode RGCreate_Ring(RG rg)
 {
   RG_RING        *ring;
   PetscErrorCode ierr;
@@ -319,7 +381,7 @@ PETSC_EXTERN PetscErrorCode RGCreate_Ring(RG rg)
   PetscFunctionBegin;
   ierr = PetscNewLog(rg,&ring);CHKERRQ(ierr);
   ring->center    = 0.0;
-  ring->radius    = 1.0;
+  ring->radius    = PETSC_MAX_REAL;
   ring->vscale    = 1.0;
   ring->start_ang = 0.0;
   ring->end_ang   = 1.0;
@@ -328,6 +390,7 @@ PETSC_EXTERN PetscErrorCode RGCreate_Ring(RG rg)
 
   rg->ops->istrivial      = RGIsTrivial_Ring;
   rg->ops->computecontour = RGComputeContour_Ring;
+  rg->ops->computebbox    = RGComputeBoundingBox_Ring;
   rg->ops->checkinside    = RGCheckInside_Ring;
   rg->ops->setfromoptions = RGSetFromOptions_Ring;
   rg->ops->view           = RGView_Ring;
