@@ -1,36 +1,23 @@
 /*
-      Implements the Cayley spectral transform.
-
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2015, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
-
-   SLEPc is free software: you can redistribute it and/or modify it under  the
-   terms of version 3 of the GNU Lesser General Public License as published by
-   the Free Software Foundation.
-
-   SLEPc  is  distributed in the hope that it will be useful, but WITHOUT  ANY
-   WARRANTY;  without even the implied warranty of MERCHANTABILITY or  FITNESS
-   FOR  A  PARTICULAR PURPOSE. See the GNU Lesser General Public  License  for
-   more details.
-
-   You  should have received a copy of the GNU Lesser General  Public  License
-   along with SLEPc. If not, see <http://www.gnu.org/licenses/>.
+   SLEPc is distributed under a 2-clause BSD license (see LICENSE).
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
+/*
+   Implements the Cayley spectral transform
+*/
 
 #include <slepc/private/stimpl.h>          /*I "slepcst.h" I*/
 
 typedef struct {
   PetscScalar nu;
   PetscBool   nu_set;
-  Vec         w2;
 } ST_CAYLEY;
 
-#undef __FUNCT__
-#define __FUNCT__ "STApply_Cayley"
 PetscErrorCode STApply_Cayley(ST st,Vec x,Vec y)
 {
   PetscErrorCode ierr;
@@ -38,13 +25,11 @@ PetscErrorCode STApply_Cayley(ST st,Vec x,Vec y)
   PetscFunctionBegin;
   /* standard eigenproblem: y = (A - sI)^-1 (A + tI)x */
   /* generalized eigenproblem: y = (A - sB)^-1 (A + tB)x */
-  ierr = MatMult(st->T[0],x,st->w);CHKERRQ(ierr);
-  ierr = STMatSolve(st,st->w,y);CHKERRQ(ierr);
+  ierr = MatMult(st->T[0],x,st->work[0]);CHKERRQ(ierr);
+  ierr = STMatSolve(st,st->work[0],y);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "STApplyTranspose_Cayley"
 PetscErrorCode STApplyTranspose_Cayley(ST st,Vec x,Vec y)
 {
   PetscErrorCode ierr;
@@ -52,13 +37,11 @@ PetscErrorCode STApplyTranspose_Cayley(ST st,Vec x,Vec y)
   PetscFunctionBegin;
   /* standard eigenproblem: y =  (A + tI)^T (A - sI)^-T x */
   /* generalized eigenproblem: y = (A + tB)^T (A - sB)^-T x */
-  ierr = STMatSolveTranspose(st,x,st->w);CHKERRQ(ierr);
-  ierr = MatMultTranspose(st->T[0],st->w,y);CHKERRQ(ierr);
+  ierr = STMatSolveTranspose(st,x,st->work[0]);CHKERRQ(ierr);
+  ierr = MatMultTranspose(st->T[0],st->work[0],y);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "MatMult_Cayley"
 static PetscErrorCode MatMult_Cayley(Mat B,Vec x,Vec y)
 {
   PetscErrorCode ierr;
@@ -76,8 +59,8 @@ static PetscErrorCode MatMult_Cayley(Mat B,Vec x,Vec y)
   if (st->nmat>1) {
     /* generalized eigenproblem: y = (A + tB)x */
     ierr = MatMult(st->A[0],x,y);CHKERRQ(ierr);
-    ierr = MatMult(st->A[1],x,ctx->w2);CHKERRQ(ierr);
-    ierr = VecAXPY(y,nu,ctx->w2);CHKERRQ(ierr);
+    ierr = MatMult(st->A[1],x,st->work[1]);CHKERRQ(ierr);
+    ierr = VecAXPY(y,nu,st->work[1]);CHKERRQ(ierr);
   } else {
     /* standard eigenproblem: y = (A + tI)x */
     ierr = MatMult(st->A[0],x,y);CHKERRQ(ierr);
@@ -86,8 +69,34 @@ static PetscErrorCode MatMult_Cayley(Mat B,Vec x,Vec y)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "STGetBilinearForm_Cayley"
+static PetscErrorCode MatMultTranspose_Cayley(Mat B,Vec x,Vec y)
+{
+  PetscErrorCode ierr;
+  ST             st;
+  ST_CAYLEY      *ctx;
+  PetscScalar    nu;
+
+  PetscFunctionBegin;
+  ierr = MatShellGetContext(B,(void**)&st);CHKERRQ(ierr);
+  ctx = (ST_CAYLEY*)st->data;
+  nu = ctx->nu;
+
+  if (st->shift_matrix == ST_MATMODE_INPLACE) { nu = nu + st->sigma; };
+  nu = PetscConj(nu);
+
+  if (st->nmat>1) {
+    /* generalized eigenproblem: y = (A + tB)x */
+    ierr = MatMultTranspose(st->A[0],x,y);CHKERRQ(ierr);
+    ierr = MatMultTranspose(st->A[1],x,st->work[1]);CHKERRQ(ierr);
+    ierr = VecAXPY(y,nu,st->work[1]);CHKERRQ(ierr);
+  } else {
+    /* standard eigenproblem: y = (A + tI)x */
+    ierr = MatMultTranspose(st->A[0],x,y);CHKERRQ(ierr);
+    ierr = VecAXPY(y,nu,x);CHKERRQ(ierr);
+  }
+  PetscFunctionReturn(0);
+}
+
 PetscErrorCode STGetBilinearForm_Cayley(ST st,Mat *B)
 {
   PetscErrorCode ierr;
@@ -99,8 +108,6 @@ PetscErrorCode STGetBilinearForm_Cayley(ST st,Mat *B)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "STBackTransform_Cayley"
 PetscErrorCode STBackTransform_Cayley(ST st,PetscInt n,PetscScalar *eigr,PetscScalar *eigi)
 {
   ST_CAYLEY   *ctx = (ST_CAYLEY*)st->data;
@@ -131,8 +138,6 @@ PetscErrorCode STBackTransform_Cayley(ST st,PetscInt n,PetscScalar *eigr,PetscSc
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "STPostSolve_Cayley"
 PetscErrorCode STPostSolve_Cayley(ST st)
 {
   PetscErrorCode ierr;
@@ -145,13 +150,11 @@ PetscErrorCode STPostSolve_Cayley(ST st)
       ierr = MatShift(st->A[0],st->sigma);CHKERRQ(ierr);
     }
     st->Astate[0] = ((PetscObject)st->A[0])->state;
-    st->setupcalled = 0;
+    st->state = ST_STATE_INITIAL;
   }
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "STSetUp_Cayley"
 PetscErrorCode STSetUp_Cayley(ST st)
 {
   PetscErrorCode ierr;
@@ -159,6 +162,8 @@ PetscErrorCode STSetUp_Cayley(ST st)
   ST_CAYLEY      *ctx = (ST_CAYLEY*)st->data;
 
   PetscFunctionBegin;
+  ierr = STSetWorkVecs(st,2);CHKERRQ(ierr);
+
   /* if the user did not set the shift, use the target value */
   if (!st->sigma_set) st->sigma = st->defsigma;
 
@@ -170,20 +175,17 @@ PetscErrorCode STSetUp_Cayley(ST st)
     ierr = MatGetLocalSize(st->A[0],&n,&m);CHKERRQ(ierr);
     ierr = MatCreateShell(PetscObjectComm((PetscObject)st),n,m,PETSC_DETERMINE,PETSC_DETERMINE,st,&st->T[0]);CHKERRQ(ierr);
     ierr = MatShellSetOperation(st->T[0],MATOP_MULT,(void(*)(void))MatMult_Cayley);CHKERRQ(ierr);
+    ierr = MatShellSetOperation(st->T[0],MATOP_MULT_TRANSPOSE,(void(*)(void))MatMultTranspose_Cayley);CHKERRQ(ierr);
     ierr = PetscLogObjectParent((PetscObject)st,(PetscObject)st->T[0]);CHKERRQ(ierr);
   } else {
-    ierr = STMatMAXPY_Private(st,ctx->nu,0.0,0,NULL,PETSC_TRUE,&st->T[0]);CHKERRQ(ierr);
+    ierr = STMatMAXPY_Private(st,ctx->nu,0.0,0,NULL,PetscNot(st->state==ST_STATE_UPDATED),&st->T[0]);CHKERRQ(ierr);
   }
 
   /* T[1] = A-sigma*B */
-  ierr = STMatMAXPY_Private(st,-st->sigma,0.0,0,NULL,PETSC_TRUE,&st->T[1]);CHKERRQ(ierr);
+  ierr = STMatMAXPY_Private(st,-st->sigma,0.0,0,NULL,PetscNot(st->state==ST_STATE_UPDATED),&st->T[1]);CHKERRQ(ierr);
+  ierr = PetscObjectReference((PetscObject)st->T[1]);CHKERRQ(ierr);
+  ierr = MatDestroy(&st->P);CHKERRQ(ierr);
   st->P = st->T[1];
-  ierr = PetscObjectReference((PetscObject)st->P);CHKERRQ(ierr);
-  if (st->nmat>1) {
-    ierr = VecDestroy(&ctx->w2);CHKERRQ(ierr);
-    ierr = MatCreateVecs(st->A[1],&ctx->w2,NULL);CHKERRQ(ierr);
-    ierr = PetscLogObjectParent((PetscObject)st,(PetscObject)ctx->w2);CHKERRQ(ierr);
-  }
   if (!st->ksp) { ierr = STGetKSP(st,&st->ksp);CHKERRQ(ierr); }
   ierr = STCheckFactorPackage(st);CHKERRQ(ierr);
   ierr = KSPSetOperators(st->ksp,st->P,st->P);CHKERRQ(ierr);
@@ -191,8 +193,6 @@ PetscErrorCode STSetUp_Cayley(ST st)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "STSetShift_Cayley"
 PetscErrorCode STSetShift_Cayley(ST st,PetscScalar newshift)
 {
   PetscErrorCode ierr;
@@ -201,9 +201,6 @@ PetscErrorCode STSetShift_Cayley(ST st,PetscScalar newshift)
   PetscFunctionBegin;
   if (newshift==0.0 && (!ctx->nu_set || (ctx->nu_set && ctx->nu==0.0))) SETERRQ(PetscObjectComm((PetscObject)st),1,"Values of shift and antishift cannot be zero simultaneously");
 
-  /* Nothing to be done if STSetUp has not been called yet */
-  if (!st->setupcalled) PetscFunctionReturn(0);
-
   if (!ctx->nu_set) {
     if (st->shift_matrix!=ST_MATMODE_INPLACE) {
       ierr = STMatMAXPY_Private(st,newshift,ctx->nu,0,NULL,PETSC_FALSE,&st->T[0]);CHKERRQ(ierr);
@@ -212,62 +209,39 @@ PetscErrorCode STSetShift_Cayley(ST st,PetscScalar newshift)
   }
   ierr = STMatMAXPY_Private(st,-newshift,-st->sigma,0,NULL,PETSC_FALSE,&st->T[1]);CHKERRQ(ierr);
   if (st->P!=st->T[1]) {
+    ierr = PetscObjectReference((PetscObject)st->T[1]);CHKERRQ(ierr);
     ierr = MatDestroy(&st->P);CHKERRQ(ierr);
     st->P = st->T[1];
-    ierr = PetscObjectReference((PetscObject)st->P);CHKERRQ(ierr);
   }
   ierr = KSPSetOperators(st->ksp,st->P,st->P);CHKERRQ(ierr);
   ierr = KSPSetUp(st->ksp);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "STSetFromOptions_Cayley"
-PetscErrorCode STSetFromOptions_Cayley(PetscOptions *PetscOptionsObject,ST st)
+PetscErrorCode STSetFromOptions_Cayley(PetscOptionItems *PetscOptionsObject,ST st)
 {
   PetscErrorCode ierr;
   PetscScalar    nu;
   PetscBool      flg;
   ST_CAYLEY      *ctx = (ST_CAYLEY*)st->data;
-  PC             pc;
-  PCType         pctype;
-  KSPType        ksptype;
 
   PetscFunctionBegin;
-  if (!st->ksp) { ierr = STGetKSP(st,&st->ksp);CHKERRQ(ierr); }
-  ierr = KSPGetPC(st->ksp,&pc);CHKERRQ(ierr);
-  ierr = KSPGetType(st->ksp,&ksptype);CHKERRQ(ierr);
-  ierr = PCGetType(pc,&pctype);CHKERRQ(ierr);
-  if (!pctype && !ksptype) {
-    if (st->shift_matrix == ST_MATMODE_SHELL) {
-      /* in shell mode use GMRES with Jacobi as the default */
-      ierr = KSPSetType(st->ksp,KSPGMRES);CHKERRQ(ierr);
-      ierr = PCSetType(pc,PCJACOBI);CHKERRQ(ierr);
-    } else {
-      /* use direct solver as default */
-      ierr = KSPSetType(st->ksp,KSPPREONLY);CHKERRQ(ierr);
-      ierr = PCSetType(pc,PCLU);CHKERRQ(ierr);
-    }
-  }
-
   ierr = PetscOptionsHead(PetscOptionsObject,"ST Cayley Options");CHKERRQ(ierr);
-  ierr = PetscOptionsScalar("-st_cayley_antishift","Value of the antishift","STCayleySetAntishift",ctx->nu,&nu,&flg);CHKERRQ(ierr);
-  if (flg) {
-    ierr = STCayleySetAntishift(st,nu);CHKERRQ(ierr);
-  }
+
+    ierr = PetscOptionsScalar("-st_cayley_antishift","Value of the antishift","STCayleySetAntishift",ctx->nu,&nu,&flg);CHKERRQ(ierr);
+    if (flg) { ierr = STCayleySetAntishift(st,nu);CHKERRQ(ierr); }
+
   ierr = PetscOptionsTail();CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "STCayleySetAntishift_Cayley"
 static PetscErrorCode STCayleySetAntishift_Cayley(ST st,PetscScalar newshift)
 {
   PetscErrorCode ierr;
   ST_CAYLEY *ctx = (ST_CAYLEY*)st->data;
 
   PetscFunctionBegin;
-  if (st->setupcalled && st->shift_matrix!=ST_MATMODE_INPLACE) {
+  if (st->state && st->shift_matrix!=ST_MATMODE_INPLACE) {
     ierr = STMatMAXPY_Private(st,newshift,ctx->nu,0,NULL,PETSC_FALSE,&st->T[0]);CHKERRQ(ierr);
   }
   ctx->nu     = newshift;
@@ -275,8 +249,6 @@ static PetscErrorCode STCayleySetAntishift_Cayley(ST st,PetscScalar newshift)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "STCayleySetAntishift"
 /*@
    STCayleySetAntishift - Sets the value of the anti-shift for the Cayley
    spectral transformation.
@@ -309,8 +281,7 @@ PetscErrorCode STCayleySetAntishift(ST st,PetscScalar nu)
   ierr = PetscTryMethod(st,"STCayleySetAntishift_C",(ST,PetscScalar),(st,nu));CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
-#undef __FUNCT__
-#define __FUNCT__ "STCayleyGetAntishift_Cayley"
+
 static PetscErrorCode STCayleyGetAntishift_Cayley(ST st,PetscScalar *nu)
 {
   ST_CAYLEY *ctx = (ST_CAYLEY*)st->data;
@@ -320,8 +291,6 @@ static PetscErrorCode STCayleyGetAntishift_Cayley(ST st,PetscScalar *nu)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "STCayleyGetAntishift"
 /*@
    STCayleyGetAntishift - Gets the value of the anti-shift used in the Cayley
    spectral transformation.
@@ -345,38 +314,26 @@ PetscErrorCode STCayleyGetAntishift(ST st,PetscScalar *nu)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidScalarPointer(nu,2);
-  ierr = PetscTryMethod(st,"STCayleyGetAntishift_C",(ST,PetscScalar*),(st,nu));CHKERRQ(ierr);
+  ierr = PetscUseMethod(st,"STCayleyGetAntishift_C",(ST,PetscScalar*),(st,nu));CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "STView_Cayley"
 PetscErrorCode STView_Cayley(ST st,PetscViewer viewer)
 {
   PetscErrorCode ierr;
   char           str[50];
   ST_CAYLEY      *ctx = (ST_CAYLEY*)st->data;
+  PetscBool      isascii;
 
   PetscFunctionBegin;
-  ierr = SlepcSNPrintfScalar(str,50,ctx->nu,PETSC_FALSE);CHKERRQ(ierr);
-  ierr = PetscViewerASCIIPrintf(viewer,"  Cayley: antishift: %s\n",str);CHKERRQ(ierr);
+  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
+  if (isascii) {
+    ierr = SlepcSNPrintfScalar(str,50,ctx->nu,PETSC_FALSE);CHKERRQ(ierr);
+    ierr = PetscViewerASCIIPrintf(viewer,"  antishift: %s\n",str);CHKERRQ(ierr);
+  }
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "STReset_Cayley"
-PetscErrorCode STReset_Cayley(ST st)
-{
-  PetscErrorCode ierr;
-  ST_CAYLEY      *ctx = (ST_CAYLEY*)st->data;
-
-  PetscFunctionBegin;
-  ierr = VecDestroy(&ctx->w2);CHKERRQ(ierr);
-  PetscFunctionReturn(0);
-}
-
-#undef __FUNCT__
-#define __FUNCT__ "STDestroy_Cayley"
 PetscErrorCode STDestroy_Cayley(ST st)
 {
   PetscErrorCode ierr;
@@ -388,9 +345,7 @@ PetscErrorCode STDestroy_Cayley(ST st)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "STCreate_Cayley"
-PETSC_EXTERN PetscErrorCode STCreate_Cayley(ST st)
+SLEPC_EXTERN PetscErrorCode STCreate_Cayley(ST st)
 {
   PetscErrorCode ierr;
   ST_CAYLEY      *ctx;
@@ -408,9 +363,9 @@ PETSC_EXTERN PetscErrorCode STCreate_Cayley(ST st)
   st->ops->setup           = STSetUp_Cayley;
   st->ops->setshift        = STSetShift_Cayley;
   st->ops->destroy         = STDestroy_Cayley;
-  st->ops->reset           = STReset_Cayley;
   st->ops->view            = STView_Cayley;
   st->ops->checknullspace  = STCheckNullSpace_Default;
+  st->ops->setdefaultksp   = STSetDefaultKSP_Default;
   ierr = PetscObjectComposeFunction((PetscObject)st,"STCayleySetAntishift_C",STCayleySetAntishift_Cayley);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)st,"STCayleyGetAntishift_C",STCayleyGetAntishift_Cayley);CHKERRQ(ierr);
   PetscFunctionReturn(0);
