@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -490,7 +490,8 @@ PetscErrorCode STScaleShift(ST st,PetscScalar factor)
 -  D  - the diagonal matrix (represented as a vector)
 
    Notes:
-   If this matrix is set, STApply will effectively apply D*OP*D^{-1}.
+   If this matrix is set, STApply will effectively apply D*OP*D^{-1}. Use NULL
+   to reset a previously passed D.
 
    Balancing is usually set via EPSSetBalance, but the advanced user may use
    this function to bypass the usual balancing methods.
@@ -505,9 +506,11 @@ PetscErrorCode STSetBalanceMatrix(ST st,Vec D)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  PetscValidHeaderSpecific(D,VEC_CLASSID,2);
-  PetscCheckSameComm(st,1,D,2);
-  ierr = PetscObjectReference((PetscObject)D);CHKERRQ(ierr);
+  if (D) {
+    PetscValidHeaderSpecific(D,VEC_CLASSID,2);
+    PetscCheckSameComm(st,1,D,2);
+    ierr = PetscObjectReference((PetscObject)D);CHKERRQ(ierr);
+  }
   ierr = VecDestroy(&st->D);CHKERRQ(ierr);
   st->D = D;
   st->state = ST_STATE_INITIAL;
@@ -766,19 +769,18 @@ PetscErrorCode STView(ST st,PetscViewer viewer)
   const char*    pat=NULL;
   char           str[50];
   PetscBool      isascii,isstring,flg;
-  PetscInt       tabs;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  if (!viewer) viewer = PETSC_VIEWER_STDOUT_(PetscObjectComm((PetscObject)st));
+  if (!viewer) {
+    ierr = PetscViewerASCIIGetStdout(PetscObjectComm((PetscObject)st),&viewer);CHKERRQ(ierr);
+  }
   PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,2);
   PetscCheckSameComm(st,1,viewer,2);
 
   ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
   ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERSTRING,&isstring);CHKERRQ(ierr);
   if (isascii) {
-    ierr = PetscViewerASCIIGetTab(viewer,&tabs);CHKERRQ(ierr);
-    ierr = PetscViewerASCIISetTab(viewer,((PetscObject)st)->tablevel);CHKERRQ(ierr);
     ierr = PetscObjectPrintClassNamePrefixType((PetscObject)st,viewer);CHKERRQ(ierr);
     if (st->ops->view) {
       ierr = PetscViewerASCIIPushTab(viewer);CHKERRQ(ierr);
@@ -809,16 +811,17 @@ PetscErrorCode STView(ST st,PetscViewer viewer)
     if (st->transform && st->nmat>2) {
       ierr = PetscViewerASCIIPrintf(viewer,"  computing transformed matrices\n");CHKERRQ(ierr);
     }
-    ierr = PetscViewerASCIISetTab(viewer,tabs);CHKERRQ(ierr);
   } else if (isstring) {
     ierr = STGetType(st,&cstr);CHKERRQ(ierr);
     ierr = PetscViewerStringSPrintf(viewer," %-7.7s",cstr);CHKERRQ(ierr);
     if (st->ops->view) { ierr = (*st->ops->view)(st,viewer);CHKERRQ(ierr); }
   }
-  ierr = PetscObjectTypeCompare((PetscObject)st,STSHIFT,&flg);CHKERRQ(ierr);
+  ierr = PetscObjectTypeCompareAny((PetscObject)st,&flg,STSHIFT,STSHELL,"");CHKERRQ(ierr);
   if (st->nmat>1 || !flg) {
     if (!st->ksp) { ierr = STGetKSP(st,&st->ksp);CHKERRQ(ierr); }
+    ierr = PetscViewerASCIIPushTab(viewer);CHKERRQ(ierr);
     ierr = KSPView(st->ksp,viewer);CHKERRQ(ierr);
+    ierr = PetscViewerASCIIPopTab(viewer);CHKERRQ(ierr);
   }
   PetscFunctionReturn(0);
 }
