@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -134,17 +134,17 @@ static PetscErrorCode SlepcLoadDynamicLibrary(const char *name,PetscBool *found)
 #endif
 
 #if defined(PETSC_HAVE_THREADSAFETY)
-PETSC_EXTERN PetscErrorCode STInitializePackage(void);
-PETSC_EXTERN PetscErrorCode DSInitializePackage(void);
-PETSC_EXTERN PetscErrorCode FNInitializePackage(void);
-PETSC_EXTERN PetscErrorCode BVInitializePackage(void);
-PETSC_EXTERN PetscErrorCode RGInitializePackage(void);
-PETSC_EXTERN PetscErrorCode EPSInitializePackage(void);
-PETSC_EXTERN PetscErrorCode SVDInitializePackage(void);
-PETSC_EXTERN PetscErrorCode PEPInitializePackage(void);
-PETSC_EXTERN PetscErrorCode NEPInitializePackage(void);
-PETSC_EXTERN PetscErrorCode MFNInitializePackage(void);
-PETSC_EXTERN PetscErrorCode LMEInitializePackage(void);
+SLEPC_EXTERN PetscErrorCode STInitializePackage(void);
+SLEPC_EXTERN PetscErrorCode DSInitializePackage(void);
+SLEPC_EXTERN PetscErrorCode FNInitializePackage(void);
+SLEPC_EXTERN PetscErrorCode BVInitializePackage(void);
+SLEPC_EXTERN PetscErrorCode RGInitializePackage(void);
+SLEPC_EXTERN PetscErrorCode EPSInitializePackage(void);
+SLEPC_EXTERN PetscErrorCode SVDInitializePackage(void);
+SLEPC_EXTERN PetscErrorCode PEPInitializePackage(void);
+SLEPC_EXTERN PetscErrorCode NEPInitializePackage(void);
+SLEPC_EXTERN PetscErrorCode MFNInitializePackage(void);
+SLEPC_EXTERN PetscErrorCode LMEInitializePackage(void);
 #endif
 
 /*
@@ -221,9 +221,9 @@ PetscErrorCode SlepcCitationsInitialize()
   ierr = PetscCitationsRegister("@TechReport{slepc-manual,\n"
     "   author = \"J. E. Roman and C. Campos and E. Romero and A. Tomas\",\n"
     "   title = \"{SLEPc} Users Manual\",\n"
-    "   number = \"DSIC-II/24/02 - Revision 3.10\",\n"
+    "   number = \"DSIC-II/24/02 - Revision 3.11\",\n"
     "   institution = \"D. Sistemes Inform\\`atics i Computaci\\'o, Universitat Polit\\`ecnica de Val\\`encia\",\n"
-    "   year = \"2018\"\n"
+    "   year = \"2019\"\n"
     "}\n",NULL);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
