@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -55,7 +55,7 @@ PetscErrorCode VecNormalizeComplex(Vec xr,Vec xi,PetscBool iscomplex,PetscReal *
 }
 
 /*@C
-   VecCheckOrthogonality - Checks (or prints) the level of orthogonality
+   VecCheckOrthogonality - Checks (or prints) the level of (bi-)orthogonality
    of a set of vectors.
 
    Collective on Vec
@@ -79,7 +79,8 @@ PetscErrorCode VecNormalizeComplex(Vec xr,Vec xi,PetscBool iscomplex,PetscReal *
    If matrix B is provided then the check uses the B-inner product, W'*B*V.
 
    If lev is not NULL, it will contain the maximum entry of matrix
-   W'*V - I (in absolute value). Otherwise, the matrix W'*V is printed.
+   W'*V - I (in absolute value) omitting the diagonal. Otherwise, the matrix W'*V
+   is printed.
 
    Level: developer
 @*/
@@ -96,7 +97,9 @@ PetscErrorCode VecCheckOrthogonality(Vec *V,PetscInt nv,Vec *W,PetscInt nw,Mat B
   PetscValidPointer(V,1);
   PetscValidHeaderSpecific(*V,VEC_CLASSID,1);
   if (!lev) {
-    if (!viewer) viewer = PETSC_VIEWER_STDOUT_(PetscObjectComm((PetscObject)*V));
+    if (!viewer) {
+      ierr = PetscViewerASCIIGetStdout(PetscObjectComm((PetscObject)*V),&viewer);CHKERRQ(ierr);
+    }
     PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,2);
     PetscCheckSameComm(*V,1,viewer,6);
     ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
@@ -121,8 +124,9 @@ PetscErrorCode VecCheckOrthogonality(Vec *V,PetscInt nv,Vec *W,PetscInt nw,Mat B
     }
     ierr = VecMDot(w,nv,V,vals);CHKERRQ(ierr);
     for (j=0;j<nv;j++) {
-      if (lev) *lev = PetscMax(*lev,PetscAbsScalar((j==i)? (vals[j]-1.0): vals[j]));
-      else {
+      if (lev) {
+        if (i!=j) *lev = PetscMax(*lev,PetscAbsScalar(vals[j]));
+      } else {
 #if !defined(PETSC_USE_COMPLEX)
         ierr = PetscViewerASCIIPrintf(viewer," %12g  ",(double)vals[j]);CHKERRQ(ierr);
 #else
@@ -177,7 +181,7 @@ PetscErrorCode VecDuplicateEmpty(Vec v,Vec *newv)
   ierr = VecGetBlockSize(v,&bs);CHKERRQ(ierr);
 
   if (cuda) {
-#if defined(PETSC_HAVE_VECCUDA)
+#if defined(PETSC_HAVE_CUDA)
     if (mpi) {
       ierr = VecCreateMPICUDAWithArray(PetscObjectComm((PetscObject)v),bs,nloc,N,NULL,newv);CHKERRQ(ierr);
     } else {
